@@ -849,15 +849,14 @@ int bSolveUnitTriangular(PRECISION *a, PRECISION *b, int m, int n, int u, int at
    Assumes
      x : m x n matrix
      y : m x n matrix
-     p : integer array of length m representing permutation matrix.
+     p : integer array of length n representing (n x n) permutation matrix.
      m : positive
      n : positive
-     py: 0 or 1
-     pt: 0 or 1
      yt: 0 or 1
+     pt: 0 or 1
 
    Results
-     y = y * p  or  (2) y = y * p'
+     x = y * p  or  x = y * p'
 
    Returns
      NO_ERR
@@ -866,37 +865,33 @@ int bSolveUnitTriangular(PRECISION *a, PRECISION *b, int m, int n, int u, int at
      The array p defines the permutation that maps i to p[i].
 
      If yt is one, then both x and y are in column major format.  If yt is zero
-     then both x and y are in column major format.
+     then both x and y are in row major format.
 
-     If pt is one, then x = y * p and if pt is zero then x = y * p'.  
+     If pt is one, then x = y * p' and if pt is zero then x = y * p.  
 */
 int bPermuteMatrix(PRECISION *x, PRECISION *y, int *p, int m, int n, int yt, int pt)
 {
   int j, kx, ky;
-  if (yt)
+  if (m == 1)
     if (pt)
-      if (m == 1)
-	for (j=n-1; j >= 0; j--) x[j]=y[p[j]];
-      else
-	for (j=n-1; j >= 0; j--) memcpy(x+j*m,y+p[j]*m,m*sizeof(PRECISION));
+      for (j=n-1; j >= 0; j--) x[p[j]]=y[j];
     else
-      if (m == 1)
-	for (j=n-1; j >= 0; j--) x[p[j]]=y[j];
-      else
-	for (j=n-1; j >= 0; j--) memcpy(x+p[j]*m,y+j*m,m*sizeof(PRECISION));
+      for (j=n-1; j >= 0; j--) x[j]=y[p[j]];
   else
-    if (pt)
-      if (m == 1)
-	for (j=n-1; j >= 0; j--) x[j]=y[p[j]];
+    if (yt)
+      if (pt)
+	for (j=n-1; j >= 0; j--) 
+	  memcpy(x+p[j]*m,y+j*m,m*sizeof(PRECISION));
+      else
+	for (j=n-1; j >= 0; j--) 
+	  memcpy(x+j*m,y+p[j]*m,m*sizeof(PRECISION));
+    else
+      if (pt)
+	for (m=(m-1)*n, j=n-1; j >= 0; j--)
+	  for (ky=m+j, kx=m+p[j]; kx >= 0; ky-=n, kx-=n) x[kx]=y[ky];
       else
 	for (m=(m-1)*n, j=n-1; j >= 0; j--)
 	  for (ky=m+p[j], kx=m+j; kx >= 0; ky-=n, kx-=n) x[kx]=y[ky];
-    else
-      if (m == 1)
-	for (j=n-1; j >= 0; j--) x[p[j]]=y[j];
-      else
-	for (m=(m-1)*n, j=n-1; j >= 0; j--)
-	  for (ky=m+j, kx=m+p[j]; kx >= 0; ky-=n, kx-=n) x[kx]=y[ky];
   return NO_ERR;
 }
 
