@@ -1,23 +1,24 @@
-function [ys,check] = NK_baseline_steadystate(ys,exo)
-% function [ys,check] = NK_baseline_steadystate(ys,exo)
+function [ys,params,check] = NK_baseline_steadystate(ys,exo,M_,options_)
+% function [ys,params,check] = NK_baseline_steadystate(ys,exo,M_,options_)
 % computes the steady state for the NK_baseline.mod and uses a numerical
 % solver to do so
 % Inputs: 
 %   - ys        [vector] vector of initial values for the steady state of
 %                   the endogenous variables
 %   - exo       [vector] vector of values for the exogenous variables
+%   - M_        [structure] Dynare model structure
+%   - options   [structure] Dynare options structure
 %
 % Output: 
-%   - ys        [vector] vector of steady state values fpr the the endogenous variables
+%   - ys        [vector] vector of steady state values for the the endogenous variables
+%   - params    [vector] vector of parameter values
 %   - check     [scalar] set to 0 if steady state computation worked and to
-%                    1 of not (allows to impos restriction on parameters)
-
-global M_ 
+%                    1 of not (allows to impose restrictions on parameters)
 
 % read out parameters to access them with their name
 NumberOfParameters = M_.param_nbr;
 for ii = 1:NumberOfParameters
-  paramname = deblank(M_.param_names(ii,:));
+  paramname = M_.param_names{ii};
   eval([ paramname ' = M_.params(' int2str(ii) ');']);
 end
 % initialize indicator
@@ -28,7 +29,7 @@ check = 0;
 
 options=optimset(); % set options for numerical solver
 
-% the steady state computation follows FV (2006), section 4.1
+% the steady state computation follows FVRR (2006), section 4.1
 PI=PIbar;
 u=1;
 q=1;
@@ -95,12 +96,13 @@ g2=epsilon/(epsilon-1)*g1;
 
 %% end own model equations
 
+params=NaN(NumberOfParameters,1);
 for iter = 1:length(M_.params) %update parameters set in the file
-  eval([ 'M_.params(' num2str(iter) ') = ' M_.param_names(iter,:) ';' ])
+  eval([ 'params(' num2str(iter) ') = ' M_.param_names{iter} ';' ])
 end
 
 NumberOfEndogenousVariables = M_.orig_endo_nbr; %auxiliary variables are set automatically
 for ii = 1:NumberOfEndogenousVariables
-  varname = deblank(M_.endo_names(ii,:));
+  varname = M_.endo_names{ii};
   eval(['ys(' int2str(ii) ') = ' varname ';']);
 end
