@@ -1,6 +1,6 @@
 function mexpath = add_path_to_mex_files(dynareroot, modifypath)
 
-% Copyright (C) 2015-2017 Dynare Team
+% Copyright (C) 2015-2019 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -21,19 +21,40 @@ if nargin<2
     modifypath = true;
 end
 
-if exist('OCTAVE_VERSION')
-    if ispc() && strcmpi(computer(), 'i686-w64-mingw32')
-        mexpath = {[dynareroot '../mex/octave32/']};
+if isoctave
+    % Add specific paths for Dynare Windows package
+    if ispc
+        if strcmpi(computer(), 'i686-w64-mingw32')
+            tmp = [dynareroot '../mex/octave/win32/'];
+            if exist(tmp, 'dir')
+                mexpath = tmp;
+                if modifypath
+                    addpath(mexpath);
+                end
+            end
+        else
+            tmp = [dynareroot '../mex/octave/win64/'];
+            if exist(tmp, 'dir')
+                mexpath = tmp;
+                if modifypath
+                    addpath(mexpath);
+                end
+            end
+        end
+    end
+    % Add generic MATLAB path (with higher priority than the previous ones)
+    if exist('mexpath')
+        mexpath = { mexpath; [dynareroot '../mex/octave/'] };
     else
-        mexpath = {[dynareroot '../mex/octave/']};
+        mexpath = { [dynareroot '../mex/octave/'] };
     end
     if modifypath
-        addpath(mexpath{1});
+        addpath([dynareroot '../mex/octave/']);
     end
 else
     % Add win32 specific paths for Dynare Windows package
     if strcmp(computer, 'PCWIN')
-        tmp = [dynareroot '../mex/matlab/win32-7.5-8.6/'];
+        tmp = [dynareroot '../mex/matlab/win32-7.9-8.6/'];
         if exist(tmp, 'dir')
             mexpath = tmp;
             if modifypath
@@ -43,16 +64,8 @@ else
     end
     % Add win64 specific paths for Dynare Windows package
     if strcmp(computer, 'PCWIN64')
-        if matlab_ver_less_than('7.8')
-            tmp = [dynareroot '../mex/matlab/win64-7.5-7.7/'];
-            if exist(tmp, 'dir')
-                mexpath = tmp;
-                if modifypath
-                    addpath(mexpath);
-                end
-            end
-        elseif matlab_ver_less_than('9.4')
-            tmp = [dynareroot '../mex/matlab/win64-7.8-9.3/'];
+        if matlab_ver_less_than('9.4')
+            tmp = [dynareroot '../mex/matlab/win64-7.9-9.3/'];
             if exist(tmp, 'dir')
                 mexpath = tmp;
                 if modifypath
@@ -60,7 +73,7 @@ else
                 end
             end
         else
-            tmp = [dynareroot '../mex/matlab/win64-9.4-9.5/'];
+            tmp = [dynareroot '../mex/matlab/win64-9.4-9.7/'];
             if exist(tmp, 'dir')
                 mexpath = tmp;
                 if modifypath
@@ -69,13 +82,23 @@ else
             end
         end
     end
-    % Add OS X 64bits specific paths for Dynare Mac package
+    % Add macOS paths for Dynare Mac package
     if strcmp(computer, 'MACI64')
-        tmp = [dynareroot '../mex/matlab/osx/'];
-        if exist(tmp, 'dir')
-            mexpath = tmp;
-            if modifypath && exist(mexpath, 'dir')
-                addpath(mexpath);
+        if matlab_ver_less_than('9.4')
+            tmp = [dynareroot '../mex/matlab/maci64-7.9-9.3/'];
+            if exist(tmp, 'dir')
+                mexpath = tmp;
+                if modifypath
+                    addpath(mexpath);
+                end
+            end
+        else
+            tmp = [dynareroot '../mex/matlab/maci64-9.4-9.7'];
+            if exist(tmp, 'dir')
+                mexpath = tmp;
+                if modifypath
+                    addpath(mexpath);
+                end
             end
         end
     end
@@ -88,4 +111,4 @@ else
     if modifypath
         addpath([dynareroot '../mex/matlab/']);
     end
-end
\ No newline at end of file
+end
