@@ -387,7 +387,7 @@ if ~strcmp(posterior_sampler_options.posterior_sampling_method,'slice')
 end
 
 if options_.load_mh_file && posterior_sampler_options.use_mh_covariance_matrix
-    [junk, invhess] = compute_mh_covariance_matrix;
+    [~, invhess] = compute_mh_covariance_matrix;
     posterior_sampler_options.invhess = invhess;
 end
 
@@ -409,7 +409,7 @@ if strcmp(posterior_sampler_options.posterior_sampling_method,'slice')
                 error('check_posterior_sampler_options:: This error should not occur, please contact developers.')
             end
             % % %             if options_.load_mh_file && options_.use_mh_covariance_matrix,
-            % % %                 [junk, invhess] = compute_mh_covariance_matrix;
+            % % %                 [~, invhess] = compute_mh_covariance_matrix;
             % % %                 posterior_sampler_options.invhess = invhess;
             % % %             end
             [V1, D]=eig(invhess);
