@@ -10,7 +10,7 @@ function oo_=display_estimation_results_table(xparam1,stdh,M_,options_,estim_par
 %   o options_                  Matlab's structure describing the options (initialized by dynare, see @ref{options_}).
 %   o bayestopt_                Matlab's structure describing the priors (initialized by dynare, see @ref{bayesopt_}).
 %   o oo_                       Matlab's structure gathering the results (initialized by dynare, see @ref{oo_}).
-%   o pnames        [string]    Character Array storing the names for prior distributions
+%   o pnames        [string]    Cell of strings storing the names for prior distributions
 %   o table_title   [string]    Title of the Table
 %   o field_name    [string]    String storing the name of the fields for oo_ where the parameters are stored
 %
@@ -20,7 +20,7 @@ function oo_=display_estimation_results_table(xparam1,stdh,M_,options_,estim_par
 % SPECIAL REQUIREMENTS
 %   None.
 
-% Copyright (C) 2014-2017 Dynare Team
+% Copyright (C) 2014-2018 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -49,12 +49,12 @@ disp(['RESULTS FROM ' upper(table_title) ' ESTIMATION'])
 LaTeXtitle=strrep(table_title,' ','_');
 tstath = abs(xparam1)./stdh;
 
-header_width = row_header_width(M_,estim_params_,bayestopt_);
+header_width = row_header_width(M_, estim_params_, bayestopt_);
 if strcmp(field_name,'posterior')
-    tit1 = sprintf('%-*s %7s %8s %7s %4s %6s\n',header_width-2,' ','prior mean', ...
-                   'mode','s.d.','prior','pstdev');
+    tit1 = sprintf('%-*s %7s %8s %7s %4s %6s\n', header_width-2, ' ', 'prior mean', ...
+                   'mode', 's.d.', 'prior', 'pstdev');
 else
-    tit1 = sprintf('%-*s %10s %7s %6s\n',header_width-2,' ','Estimate','s.d.','t-stat');
+    tit1 = sprintf('%-*s %10s %7s %6s\n', header_width-2, ' ', 'Estimate', 's.d.', 't-stat');
 end
 if np
     ip = nvx+nvn+ncx+ncn+1;
@@ -66,11 +66,11 @@ if np
             fprintf('%-*s %7.3f %8.4f %7.4f %4s %6.4f \n', ...
                     header_width,name, ...
                     bayestopt_.p1(ip),xparam1(ip),stdh(ip), ...
-                    pnames(bayestopt_.pshape(ip)+1,:), ...
+                    pnames{bayestopt_.pshape(ip)+1}, ...
                     bayestopt_.p2(ip));
         else
             fprintf('%-*s %8.4f %7.4f %7.4f \n', ...
-                    header_width,name,xparam1(ip),stdh(ip),tstath(ip));
+                    header_width, name, xparam1(ip), stdh(ip), tstath(ip));
         end
         eval(['oo_.' field_name '_mode.parameters.' name ' = xparam1(ip);']);
         eval(['oo_.' field_name '_std_at_mode.parameters.' name ' = stdh(ip);']);
@@ -84,14 +84,14 @@ if nvx
     disp(tit1)
     for i=1:nvx
         k = estim_params_.var_exo(i,1);
-        name = deblank(M_.exo_names(k,:));
+        name = M_.exo_names{k};
         if strcmp(field_name,'posterior')
             fprintf('%-*s %7.3f %8.4f %7.4f %4s %6.4f \n', ...
-                    header_width,name,bayestopt_.p1(ip),xparam1(ip), ...
-                    stdh(ip),pnames(bayestopt_.pshape(ip)+1,:), ...
+                    header_width, name, bayestopt_.p1(ip), xparam1(ip), ...
+                    stdh(ip), pnames{bayestopt_.pshape(ip)+1}, ...
                     bayestopt_.p2(ip));
         else
-            fprintf('%-*s %8.4f %7.4f %7.4f \n',header_width,name,xparam1(ip),stdh(ip),tstath(ip));
+            fprintf('%-*s %8.4f %7.4f %7.4f \n', header_width, name, xparam1(ip), stdh(ip), tstath(ip));
         end
         M_.Sigma_e(k,k) = xparam1(ip)*xparam1(ip);
         eval(['oo_.' field_name '_mode.shocks_std.' name ' = xparam1(ip);']);
@@ -108,12 +108,13 @@ if nvn
         name = options_.varobs{estim_params_.nvn_observable_correspondence(i,1)};
         if strcmp(field_name,'posterior')
             fprintf('%-*s %7.3f %8.4f %7.4f %4s %6.4f \n', ...
-                    header_width,name,bayestopt_.p1(ip), ...
-                    xparam1(ip),stdh(ip), ...
-                    pnames(bayestopt_.pshape(ip)+1,:), ...
+                    header_width, name, bayestopt_.p1(ip), ...
+                    xparam1(ip), stdh(ip), ...
+                    pnames{bayestopt_.pshape(ip)+1}, ...
                     bayestopt_.p2(ip));
         else
-            fprintf('%-*s %8.4f %7.4f %7.4f \n',header_width,name,xparam1(ip),stdh(ip),tstath(ip))
+            fprintf('%-*s %8.4f %7.4f %7.4f \n', header_width, name, xparam1(ip), ...
+                    stdh(ip), tstath(ip))
         end
         eval(['oo_.' field_name '_mode.measurement_errors_std.' name ' = xparam1(ip);']);
         eval(['oo_.' field_name '_std_at_mode.measurement_errors_std.' name ' = stdh(ip);']);
@@ -129,14 +130,15 @@ if ncx
     for i=1:ncx
         k1 = estim_params_.corrx(i,1);
         k2 = estim_params_.corrx(i,2);
-        name = [deblank(M_.exo_names(k1,:)) ',' deblank(M_.exo_names(k2,:))];
-        NAME = [deblank(M_.exo_names(k1,:)) '_' deblank(M_.exo_names(k2,:))];
-        if strcmp(field_name,'posterior')
+        name = sprintf('%s,%s', M_.exo_names{k1}, M_.exo_names{k2});
+        NAME = sprintf('%s_%s', M_.exo_names{k1}, M_.exo_names{k2});
+        if strcmp(field_name, 'posterior')
             fprintf('%-*s %7.3f %8.4f %7.4f %4s %6.4f \n', ...
-                    header_width,name,bayestopt_.p1(ip),xparam1(ip),stdh(ip),  ...
-                    pnames(bayestopt_.pshape(ip)+1,:), bayestopt_.p2(ip));
+                    header_width, name, bayestopt_.p1(ip), xparam1(ip), stdh(ip),  ...
+                    pnames{bayestopt_.pshape(ip)+1}, bayestopt_.p2(ip));
         else
-            fprintf('%-*s %8.4f %7.4f %7.4f \n', header_width,name,xparam1(ip),stdh(ip),tstath(ip));
+            fprintf('%-*s %8.4f %7.4f %7.4f \n', header_width,name, xparam1(ip), ...
+                    stdh(ip), tstath(ip));
         end
         M_.Sigma_e(k1,k2) = xparam1(ip)*sqrt(M_.Sigma_e(k1,k1)*M_.Sigma_e(k2,k2));
         M_.Sigma_e(k2,k1) = M_.Sigma_e(k1,k2);
@@ -154,14 +156,15 @@ if ncn
     for i=1:ncn
         k1 = estim_params_.corrn(i,1);
         k2 = estim_params_.corrn(i,2);
-        name = [deblank(M_.endo_names(k1,:)) ',' deblank(M_.endo_names(k2,:))];
-        NAME = [deblank(M_.endo_names(k1,:)) '_' deblank(M_.endo_names(k2,:))];
+        name = sprintf('%s,%s', M_.endo_names{k1}, M_.endo_names{k2});
+        NAME = sprintf('%s_%s', M_.endo_names{k1}, M_.endo_names{k2});
         if strcmp(field_name,'posterior')
             fprintf('%-*s %7.3f %8.4f %7.4f %4s %6.4f \n', ...
-                    header_width,name,bayestopt_.p1(ip),xparam1(ip),stdh(ip), ...
-                    pnames(bayestopt_.pshape(ip)+1,:), bayestopt_.p2(ip));
+                    header_width, name, bayestopt_.p1(ip), xparam1(ip), stdh(ip), ...
+                    pnames{bayestopt_.pshape(ip)+1}, bayestopt_.p2(ip));
         else
-            fprintf('%-*s %8.4f %7.4f %7.4f \n',header_width,name,xparam1(ip),stdh(ip),tstath(ip));
+            fprintf('%-*s %8.4f %7.4f %7.4f \n',header_width, name, xparam1(ip), ...
+                    stdh(ip), tstath(ip));
         end
         eval(['oo_.' field_name '_mode.measurement_errors_corr.' NAME ' = xparam1(ip);']);
         eval(['oo_.' field_name '_std_at_mode.measurement_errors_corr.' NAME ' = stdh(ip);']);
@@ -169,6 +172,7 @@ if ncn
     end
     skipline()
 end
+
 if any(xparam1(1:nvx+nvn)<0)
     warning('Some estimated standard deviations are negative. Dynare internally works with variances so that the sign does not matter. Nevertheless, it is recommended to impose either prior restrictions (Bayesian Estimation) or a lower bound (ML) to assure positive values.')
 end
@@ -183,11 +187,11 @@ if any(bayestopt_.pshape > 0) && options_.TeX %% Bayesian estimation (posterior
         ip = nvx+nvn+ncx+ncn+1;
         for i=1:np
             fprintf(fidTeX,'$%s$ & %s & %7.3f & %6.4f & %8.4f & %7.4f \\\\ \n',...
-                    M_.param_names_tex(estim_params_.param_vals(i,1),:),...
-                    deblank(pnames(bayestopt_.pshape(ip)+1,:)),...
-                    bayestopt_.p1(ip),...
-                    bayestopt_.p2(ip),...
-                    xparam1(ip),...
+                    M_.param_names_tex{estim_params_.param_vals(i,1)}, ...
+                    pnames{bayestopt_.pshape(ip)+1}, ...
+                    bayestopt_.p1(ip), ...
+                    bayestopt_.p2(ip), ...
+                    xparam1(ip), ...
                     stdh(ip));
             ip = ip + 1;
         end
@@ -201,8 +205,8 @@ if any(bayestopt_.pshape > 0) && options_.TeX %% Bayesian estimation (posterior
         for i=1:nvx
             k = estim_params_.var_exo(i,1);
             fprintf(fidTeX,[ '$%s$ & %4s & %7.3f & %6.4f & %8.4f & %7.4f \\\\ \n'],...
-                    deblank(M_.exo_names_tex(k,:)),...
-                    deblank(pnames(bayestopt_.pshape(ip)+1,:)),...
+                    M_.exo_names_tex{k},...
+                    pnames{bayestopt_.pshape(ip)+1},...
                     bayestopt_.p1(ip),...
                     bayestopt_.p2(ip),...
                     xparam1(ip), ...
@@ -217,10 +221,10 @@ if any(bayestopt_.pshape > 0) && options_.TeX %% Bayesian estimation (posterior
         TeXBegin_Bayesian(fidTeX,3,'standard deviation of measurement errors')
         ip = nvx+1;
         for i=1:nvn
-            idx = strmatch(options_.varobs{estim_params_.nvn_observable_correspondence(i,1)},M_.endo_names);
+            idx = strmatch(options_.varobs{estim_params_.nvn_observable_correspondence(i,1)}, M_.endo_names);
             fprintf(fidTeX,'$%s$ & %4s & %7.3f & %6.4f & %8.4f & %7.4f \\\\ \n',...
-                    deblank(M_.endo_names_tex(idx,:)), ...
-                    deblank(pnames(bayestopt_.pshape(ip)+1,:)), ...
+                    M_.endo_names_tex{idx}, ...
+                    pnames{bayestopt_.pshape(ip)+1}, ...
                     bayestopt_.p1(ip), ...
                     bayestopt_.p2(ip),...
                     xparam1(ip),...
@@ -238,8 +242,8 @@ if any(bayestopt_.pshape > 0) && options_.TeX %% Bayesian estimation (posterior
             k1 = estim_params_.corrx(i,1);
             k2 = estim_params_.corrx(i,2);
             fprintf(fidTeX,[ '$%s$ & %s & %7.3f & %6.4f & %8.4f & %7.4f \\\\ \n'],...
-                    [deblank(M_.exo_names_tex(k1,:)) ',' deblank(M_.exo_names_tex(k2,:))], ...
-                    deblank(pnames(bayestopt_.pshape(ip)+1,:)), ...
+                    [M_.exo_names_tex{k1} ',' M_.exo_names_tex{k2}], ...
+                    pnames{bayestopt_.pshape(ip)+1}, ...
                     bayestopt_.p1(ip), ...
                     bayestopt_.p2(ip), ...
                     xparam1(ip), ...
@@ -257,8 +261,8 @@ if any(bayestopt_.pshape > 0) && options_.TeX %% Bayesian estimation (posterior
             k1 = estim_params_.corrn(i,1);
             k2 = estim_params_.corrn(i,2);
             fprintf(fidTeX,'$%s$ & %s & %7.3f & %6.4f & %8.4f & %7.4f \\\\ \n',...
-                    [deblank(M_.endo_names_tex(k1,:)) ',' deblank(M_.endo_names_tex(k2,:))], ...
-                    pnames(bayestopt_.pshape(ip)+1,:), ...
+                    [ M_.endo_names_tex{k1} ',' M_.endo_names_tex{k2}], ...
+                    pnames{bayestopt_.pshape(ip)+1}, ...
                     bayestopt_.p1(ip), ...
                     bayestopt_.p2(ip), ...
                     xparam1(ip), ...
@@ -270,14 +274,14 @@ if any(bayestopt_.pshape > 0) && options_.TeX %% Bayesian estimation (posterior
 elseif all(bayestopt_.pshape == 0) && options_.TeX %% MLE and GMM Latex output
     if np
         filename = [OutputDirectoryName '/' M_.fname '_' LaTeXtitle '_Mode_1.tex'];
-        fidTeX = fopen(filename,'w');
-        TeXBegin_ML(fidTeX,1,'parameters',table_title,LaTeXtitle)
+        fidTeX = fopen(filename, 'w');
+        TeXBegin_ML(fidTeX, 1, 'parameters', table_title, LaTeXtitle)
         ip = nvx+nvn+ncx+ncn+1;
         for i=1:np
             fprintf(fidTeX,'$%s$ & %8.4f & %7.4f & %7.4f\\\\ \n',...
-                    M_.param_names_tex(estim_params_.param_vals(i,1),:),...
-                    xparam1(ip),...
-                    stdh(ip),...
+                    M_.param_names_tex{estim_params_.param_vals(i,1)}, ...
+                    xparam1(ip), ...
+                    stdh(ip), ...
                     tstath(ip));
             ip = ip + 1;
         end
@@ -285,15 +289,15 @@ elseif all(bayestopt_.pshape == 0) && options_.TeX %% MLE and GMM Latex output
     end
     if nvx
         filename = [OutputDirectoryName '/' M_.fname '_' LaTeXtitle '_Mode_2.tex'];
-        fidTeX = fopen(filename,'w');
-        TeXBegin_ML(fidTeX,2,'standard deviation of structural shocks',table_title,LaTeXtitle)
+        fidTeX = fopen(filename, 'w');
+        TeXBegin_ML(fidTeX, 2, 'standard deviation of structural shocks', table_title, LaTeXtitle)
         ip = 1;
         for i=1:nvx
             k = estim_params_.var_exo(i,1);
-            fprintf(fidTeX,[ '$%s$ & %8.4f & %7.4f & %7.4f\\\\ \n'],...
-                    deblank(M_.exo_names_tex(k,:)),...
+            fprintf(fidTeX,[ '$%s$ & %8.4f & %7.4f & %7.4f\\\\ \n'], ...
+                    M_.exo_names_tex{k}, ...
                     xparam1(ip), ...
-                    stdh(ip),...
+                    stdh(ip), ...
                     tstath(ip));
             ip = ip+1;
         end
@@ -301,15 +305,15 @@ elseif all(bayestopt_.pshape == 0) && options_.TeX %% MLE and GMM Latex output
     end
     if nvn
         filename = [OutputDirectoryName '/' M_.fname '_' LaTeXtitle '_Mode_3.tex'];
-        fidTeX = fopen(filename,'w');
-        TeXBegin_ML(fidTeX,3,'standard deviation of measurement errors',table_title,LaTeXtitle)
+        fidTeX = fopen(filename, 'w');
+        TeXBegin_ML(fidTeX, 3, 'standard deviation of measurement errors', table_title, LaTeXtitle)
         ip = nvx+1;
         for i=1:nvn
-            idx = strmatch(options_.varobs{estim_params_.nvn_observable_correspondence(i,1)},M_.endo_names);
-            fprintf(fidTeX,'$%s$ & %8.4f & %7.4f & %7.4f \\\\ \n',...
-                    deblank(M_.endo_names_tex(idx,:)), ...
-                    xparam1(ip),...
-                    stdh(ip),...
+            idx = strmatch(options_.varobs{estim_params_.nvn_observable_correspondence(i,1)}, M_.endo_names);
+            fprintf(fidTeX, '$%s$ & %8.4f & %7.4f & %7.4f \\\\ \n', ...
+                    M_.endo_names_tex{idx}, ...
+                    xparam1(ip), ...
+                    stdh(ip), ...
                     tstath(ip));
             ip = ip+1;
         end
@@ -317,16 +321,16 @@ elseif all(bayestopt_.pshape == 0) && options_.TeX %% MLE and GMM Latex output
     end
     if ncx
         filename = [OutputDirectoryName '/' M_.fname '_' LaTeXtitle '_Mode_4.tex'];
-        fidTeX = fopen(filename,'w');
-        TeXBegin_ML(fidTeX,4,'correlation of structural shocks',table_title,LaTeXtitle)
+        fidTeX = fopen(filename, 'w');
+        TeXBegin_ML(fidTeX, 4, 'correlation of structural shocks', table_title,LaTeXtitle)
         ip = nvx+nvn+1;
         for i=1:ncx
             k1 = estim_params_.corrx(i,1);
             k2 = estim_params_.corrx(i,2);
-            fprintf(fidTeX,[ '$%s$  & %8.4f & %7.4f & %7.4f \\\\ \n'],...
-                    [deblank(M_.exo_names_tex(k1,:)) ',' deblank(M_.exo_names_tex(k2,:))], ...
+            fprintf(fidTeX,[ '$%s$  & %8.4f & %7.4f & %7.4f \\\\ \n'], ...
+                    [M_.exo_names_tex{k1} ',' M_.exo_names_tex{k2}], ...
                     xparam1(ip), ...
-                    stdh(ip),...
+                    stdh(ip), ...
                     tstath(ip));
             ip = ip+1;
         end
@@ -334,16 +338,16 @@ elseif all(bayestopt_.pshape == 0) && options_.TeX %% MLE and GMM Latex output
     end
     if ncn
         filename = [OutputDirectoryName '/' M_.fname '_' LaTeXtitle '_Mode_5.tex'];
-        fidTeX = fopen(filename,'w');
-        TeXBegin_ML(fidTeX,5,'correlation of measurement errors',table_title,LaTeXtitle)
+        fidTeX = fopen(filename, 'w');
+        TeXBegin_ML(fidTeX, 5, 'correlation of measurement errors', table_title, LaTeXtitle)
         ip = nvx+nvn+ncx+1;
         for i=1:ncn
             k1 = estim_params_.corrn(i,1);
             k2 = estim_params_.corrn(i,2);
-            fprintf(fidTeX,'$%s$  & %8.4f & %7.4f & %7.4f \\\\ \n',...
-                    [deblank(M_.endo_names_tex(k1,:)) ',' deblank(M_.endo_names_tex(k2,:))], ...
+            fprintf(fidTeX, '$%s$  & %8.4f & %7.4f & %7.4f \\\\ \n', ...
+                    [ M_.endo_names_tex{k1} ',' M_.endo_names_tex{k2}], ...
                     xparam1(ip), ...
-                    stdh(ip),...
+                    stdh(ip), ...
                     tstath(ip));
             ip = ip+1;
         end
@@ -355,7 +359,7 @@ end
 
 %% subfunctions:
 %
-function TeXBegin_Bayesian(fid,fnum,title)
+function TeXBegin_Bayesian(fid, fnum, title)
 fprintf(fid,'%% TeX-table generated by dynare_estimation (Dynare).\n');
 fprintf(fid,['%% RESULTS FROM POSTERIOR MAXIMIZATION (' title ')\n']);
 fprintf(fid,['%% ' datestr(now,0)]);
@@ -379,7 +383,7 @@ fprintf(fid,'\\midrule \\endhead \n');
 fprintf(fid,'\\bottomrule \\multicolumn{6}{r}{(Continued on next page)}\\endfoot \n');
 fprintf(fid,'\\bottomrule\\endlastfoot \n');
 
-function TeXBegin_ML(fid,fnum,title,table_title,LaTeXtitle)
+function TeXBegin_ML(fid, fnum, title, table_title, LaTeXtitle)
 fprintf(fid,'%% TeX-table generated by dynare_estimation (Dynare).\n');
 fprintf(fid,['%% RESULTS FROM ' table_title ' MAXIMIZATION (' title ')\n']);
 fprintf(fid,['%% ' datestr(now,0)]);
