@@ -73,7 +73,7 @@ end
 if (options_.bytecode)
     [chck, zz, data]= bytecode('dynamic','evaluate', z, zx, M_.params, dr.ys, 1, data);
 else
-    [r, data] = feval([M_.fname '_dynamic'], options_, M_, oo_, z', zx, M_.params, dr.ys, M_.maximum_lag+1, data);
+    [r, data] = feval([M_.fname '.dynamic'], options_, M_, oo_, z', zx, M_.params, dr.ys, M_.maximum_lag+1, data);
     chck = 0;
 end
 mexErrCheck('bytecode', chck);
@@ -409,7 +409,7 @@ for i = 1:Size
         index_c = lead_lag_incidence(2,:);             % Index of all endogenous variables present at time=t
         index_s = lead_lag_incidence(2,1:n_static);    % Index of all static endogenous variables present at time=t
         if n_static > 0
-            [Q, junk] = qr(jacob(:,index_s));
+            [Q, ~] = qr(jacob(:,index_s));
             aa = Q'*jacob;
         else
             aa = jacob;
@@ -425,7 +425,7 @@ for i = 1:Size
 
         row_indx = n_static+1:n;
 
-        if task ~= 1 && options_.dr_cycle_reduction == 1
+        if task ~= 1 && options_.dr_cycle_reduction
             A1 = [aa(row_indx,index_m ) zeros(n_dynamic,n_fwrd)];
             B1 = [aa(row_indx,index_0m) aa(row_indx,index_0p) ];
             C1 = [zeros(n_dynamic,n_pred) aa(row_indx,index_p)];
@@ -436,7 +436,7 @@ for i = 1:Size
             gx = ghx(1+n_pred:end,:);
         end
 
-        if (task ~= 1 && ((options_.dr_cycle_reduction == 1 && info ==1) || options_.dr_cycle_reduction == 0)) || task == 1
+        if (task ~= 1 && ((options_.dr_cycle_reduction && info ==1) || ~options_.dr_cycle_reduction)) || task == 1
             D = [[aa(row_indx,index_0m) zeros(n_dynamic,n_both) aa(row_indx,index_p)] ; [zeros(n_both, n_pred) eye(n_both) zeros(n_both, n_both + n_fwrd)]];
             E = [-aa(row_indx,[index_m index_0p])  ; [zeros(n_both, n_both + n_pred) eye(n_both, n_both + n_fwrd) ] ];
 
@@ -476,7 +476,7 @@ for i = 1:Size
                     if isfield(options_,'indeterminacy_continuity')
                         if options_.indeterminacy_msv == 1
                             [ss,tt,w,q] = qz(E',D');
-                            [ss,tt,w,junk] = reorder(ss,tt,w,q);
+                            [ss,tt,w,~] = reorder(ss,tt,w,q);
                             ss = ss';
                             tt = tt';
                             w  = w';
@@ -588,12 +588,12 @@ for i = 1:Size
                 if block_type == 5
                     vghx_other = - inv(kron(eye(size(D_,2)), A_) + kron(C_', B_)) * vec(D_);
                     ghx_other = reshape(vghx_other, size(D_,1), size(D_,2));
-                elseif options_.sylvester_fp == 1
+                elseif options_.sylvester_fp
                     ghx_other = gensylv_fp(A_, B_, C_, D_, i, options_.sylvester_fixed_point_tol);
                 else
                     [err, ghx_other] = gensylv(1, A_, B_, C_, -D_);
                 end
-                if options_.aim_solver ~= 1 && options_.use_qzdiv
+                if options_.aim_solver ~= 1
                     % Necessary when using Sims' routines for QZ
                     ghx_other = real(ghx_other);
                 end
@@ -650,7 +650,7 @@ for i = 1:Size
             end
 
 
-            if options_.aim_solver ~= 1 && options_.use_qzdiv
+            if options_.aim_solver ~= 1
                 % Necessary when using Sims' routines for QZ
                 ghx = real(ghx);
                 ghu = real(ghu);
