@@ -53,7 +53,7 @@ function [fval,info,exit_flag,DLIK,Hess,SteadyState,trend_coeff,Model,DynareOpti
 %! @item info==6
 %! The jacobian evaluated at the deterministic steady state is complex.
 %! @item info==19
-%! The steadystate routine thrown an exception (inconsistent deep parameters).
+%! The steadystate routine has thrown an exception (inconsistent deep parameters).
 %! @item info==20
 %! Cannot find the steady state, info(4) contains the sum of square residuals (of the static equations).
 %! @item info==21
@@ -111,11 +111,11 @@ function [fval,info,exit_flag,DLIK,Hess,SteadyState,trend_coeff,Model,DynareOpti
 %! @sp 2
 %! @strong{This function calls:}
 %! @sp 1
-%! @ref{dynare_resolve}, @ref{lyapunov_symm}, @ref{lyapunov_solver}, @ref{compute_Pinf_Pstar}, @ref{kalman_filter_d}, @ref{missing_observations_kalman_filter_d}, @ref{univariate_kalman_filter_d}, @ref{kalman_steady_state}, @ref{getH}, @ref{kalman_filter}, @ref{score}, @ref{AHessian}, @ref{missing_observations_kalman_filter}, @ref{univariate_kalman_filter}, @ref{priordens}
+%! @ref{dynare_resolve}, @ref{lyapunov_symm}, @ref{lyapunov_solver}, @ref{compute_Pinf_Pstar}, @ref{kalman_filter_d}, @ref{missing_observations_kalman_filter_d}, @ref{univariate_kalman_filter_d}, @ref{kalman_steady_state}, @ref{get_perturbation_params_deriv}, @ref{kalman_filter}, @ref{score}, @ref{AHessian}, @ref{missing_observations_kalman_filter}, @ref{univariate_kalman_filter}, @ref{priordens}
 %! @end deftypefn
 %@eod:
 
-% Copyright (C) 2004-2018 Dynare Team
+% Copyright (C) 2004-2019 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -146,6 +146,20 @@ Hess        = [];
 % Ensure that xparam1 is a column vector.
 xparam1 = xparam1(:);
 
+if DynareOptions.estimation_dll
+    [fval,exit_flag,SteadyState,trend_coeff,info,params,H,Q] ...
+        = logposterior(xparam1,DynareDataset, DynareOptions,Model, ...
+                       EstimatedParameters,BayesInfo,DynareResults);
+    mexErrCheck('logposterior', exit_flag);
+    Model.params = params;
+    if ~isequal(Model.H,0)
+        Model.H = H;
+    end
+    Model.Sigma_e = Q;
+    DynareResults.dr.ys = SteadyState;
+    return
+end
+
 % Set flag related to analytical derivatives.
 analytic_derivation = DynareOptions.analytic_derivation;
 
@@ -508,12 +522,29 @@ if analytic_derivation
         else
             indparam=[];
         end
-        if full_Hess
-            [dum, DT, DOm, DYss, dum2, D2T, D2Om, D2Yss] = getH(A, B, EstimatedParameters, Model,DynareResults,DynareOptions,kron_flag,indparam,indexo,iv);
-            clear dum dum2;
-        else
-            [dum, DT, DOm, DYss] = getH(A, B, EstimatedParameters, Model,DynareResults,DynareOptions,kron_flag,indparam,indexo,iv);
+        old_order = DynareOptions.order;
+        if DynareOptions.order > 1%not sure whether this check is necessary
+            DynareOptions.order = 1; fprintf('Reset order to 1 for analytical parameter derivatives.\n');
         end
+        old_analytic_derivation_mode = DynareOptions.analytic_derivation_mode;
+        DynareOptions.analytic_derivation_mode = kron_flag;
+        if full_Hess
+            DERIVS = get_perturbation_params_derivs(Model, DynareOptions, EstimatedParameters, DynareResults, indparam, indexo, [], true);
+            indD2T = reshape(1:Model.endo_nbr^2, Model.endo_nbr, Model.endo_nbr);
+            indD2Om = dyn_unvech(1:Model.endo_nbr*(Model.endo_nbr+1)/2);
+            D2T = DERIVS.d2KalmanA(indD2T(iv,iv),:);
+            D2Om = DERIVS.d2Om(dyn_vech(indD2Om(iv,iv)),:);
+            D2Yss = DERIVS.d2Yss(iv,:,:);
+        else
+            DERIVS = get_perturbation_params_derivs(Model, DynareOptions, EstimatedParameters, DynareResults, indparam, indexo, [], false);
+        end
+        DT = zeros(Model.endo_nbr, Model.endo_nbr, size(DERIVS.dghx,3));
+        DT(:,Model.nstatic+(1:Model.nspred),:) = DERIVS.dghx;
+        DT = DT(iv,iv,:);
+        DOm = DERIVS.dOm(iv,iv,:);
+        DYss = DERIVS.dYss(iv,:);
+        DynareOptions.order = old_order; %make sure order is reset (not sure if necessary)
+        DynareOptions.analytic_derivation_mode = old_analytic_derivation_mode;%make sure analytic_derivation_mode is reset (not sure if necessary)
     else
         DT = derivatives_info.DT(iv,iv,:);
         DOm = derivatives_info.DOm(iv,iv,:);
