@@ -18,7 +18,7 @@ function [steady_state,params,check] = dyn_ramsey_static(ys_init,M,options_,oo)
 % SPECIAL REQUIREMENTS
 %    none
 
-% Copyright (C) 2003-2017 Dynare Team
+% Copyright (C) 2003-2018 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -50,8 +50,7 @@ elseif options_.steadystate_flag
     k_inst = [];
     inst_nbr = size(options_.instruments,1);
     for i = 1:inst_nbr
-        k_inst = [k_inst; strmatch(options_.instruments(i,:), ...
-                                   M.endo_names,'exact')];
+        k_inst = [k_inst; strmatch(options_.instruments{i}, M.endo_names, 'exact')];
     end
     if inst_nbr == 1
         %solve for instrument, using univariate solver, starting at initial value for instrument
@@ -66,7 +65,7 @@ elseif options_.steadystate_flag
         %solve for instrument, using multivariate solver, starting at
         %initial value for instrument
         opt = options_;
-        opt.jacobian_flag = 0;
+        opt.jacobian_flag = false;
         [inst_val,info1] = dynare_solve(nl_func,ys_init(k_inst), ...
                                         opt);
         if info1~=0
@@ -76,17 +75,17 @@ elseif options_.steadystate_flag
     ys_init(k_inst) = inst_val;
     exo_ss = [oo.exo_steady_state oo.exo_det_steady_state];
     [xx,params] = evaluate_steady_state_file(ys_init,exo_ss,M,options_,~options_.steadystate.nocheck); %run steady state file again to update parameters
-    [junk,junk,steady_state] = nl_func(inst_val); %compute and return steady state
+    [~,~,steady_state] = nl_func(inst_val); %compute and return steady state
 else
     n_var = M.orig_endo_nbr;
     xx = oo.steady_state(1:n_var);
     opt = options_;
-    opt.jacobian_flag = 0;
+    opt.jacobian_flag = false;
     [xx,info1] = dynare_solve(nl_func,xx,opt);
     if info1~=0
         check=81;
     end
-    [junk,junk,steady_state] = nl_func(xx);
+    [~,~,steady_state] = nl_func(xx);
 end
 
 
@@ -113,8 +112,7 @@ if options_.steadystate_flag
     k_inst = [];
     instruments = options_.instruments;
     for i = 1:size(instruments,1)
-        k_inst = [k_inst; strmatch(instruments(i,:), ...
-                                   endo_names,'exact')];
+        k_inst = [k_inst; strmatch(instruments{i}, endo_names, 'exact')];
     end
     ys_init=zeros(size(oo.steady_state)); %create starting vector for steady state computation as only instrument value is handed over
     ys_init(k_inst) = x; %set instrument, the only value required for steady state computation, to current value
@@ -136,11 +134,15 @@ xx(1:M.orig_endo_nbr) = x(1:M.orig_endo_nbr); %set values of original endogenous
 % setting steady state of auxiliary variables that depends on original endogenous variables
 if any([M.aux_vars.type] ~= 6) %auxiliary variables other than multipliers
     needs_set_auxiliary_variables = 1;
-    fh = str2func([M.fname '_set_auxiliary_variables']);
-    s_a_v_func = @(z) fh(z,...
-                         [oo.exo_steady_state,...
-                        oo.exo_det_steady_state],...
-                         params);
+    if M.set_auxiliary_variables
+        fh = str2func([M.fname '.set_auxiliary_variables']);
+        s_a_v_func = @(z) fh(z,...
+            [oo.exo_steady_state,...
+            oo.exo_det_steady_state],...
+            params);
+    else
+        s_a_v_func = z;
+    end
     xx = s_a_v_func(xx);
 else
     needs_set_auxiliary_variables = 0;
@@ -148,7 +150,7 @@ end
 
 % value and Jacobian of objective function
 ex = zeros(1,M.exo_nbr);
-[U,Uy,Uyy] = feval([fname '_objective_static'],x,ex, params);
+[U,Uy,Uyy] = feval([fname '.objective.static'],x,ex, params);
 Uyy = reshape(Uyy,endo_nbr,endo_nbr);
 
 % set multipliers and auxiliary variables that
@@ -158,7 +160,7 @@ if (options_.bytecode)
                                  params, 'evaluate');
     fJ = junk.g1;
 else
-    [res,fJ] = feval([fname '_static'],xx,[oo.exo_steady_state oo.exo_det_steady_state], ...
+    [res,fJ] = feval([fname '.static'],xx,[oo.exo_steady_state oo.exo_det_steady_state], ...
                      params);
 end
 % index of multipliers and corresponding equations
@@ -192,10 +194,10 @@ end
 function result = check_static_model(ys,M,options_,oo)
 result = false;
 if (options_.bytecode)
-    [chck, res, junk] = bytecode('static',ys,[oo.exo_steady_state oo.exo_det_steady_state], ...
-                                 M.params, 'evaluate');
+    [chck, res, ~] = bytecode('static',ys,[oo.exo_steady_state oo.exo_det_steady_state], ...
+                              M.params, 'evaluate');
 else
-    res = feval([M.fname '_static'],ys,[oo.exo_steady_state oo.exo_det_steady_state], ...
+    res = feval([M.fname '.static'],ys,[oo.exo_steady_state oo.exo_det_steady_state], ...
                 M.params);
 end
 if norm(res) < options_.solve_tolf
