@@ -12,7 +12,7 @@ function dynare_estimation_1(var_list_,dname)
 % SPECIAL REQUIREMENTS
 %   none
 
-% Copyright (C) 2003-2017 Dynare Team
+% Copyright (C) 2003-2018 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -52,7 +52,7 @@ end
 
 % Set particle filter flag.
 if options_.order > 1
-    if options_.particle.status && options_.order==2
+    if options_.particle.status
         skipline()
         disp('Estimation using a non linear filter!')
         skipline()
@@ -78,12 +78,8 @@ if options_.order > 1
                 end
             end
         end
-    elseif options_.particle.status && options_.order>2
-        error(['Non linear filter are not implemented with order ' int2str(options_.order) ' approximation of the model!'])
-    elseif ~options_.particle.status && options_.order==2
-        error('For estimating the model with a second order approximation using a non linear filter, one should have options_.particle.status=1;')
     else
-        error(['Cannot estimate a model with an order ' int2str(options_.order) ' approximation!'])
+        error('For estimating the model with a second order approximation using a non linear filter, one should have options_.particle.status=true;')
     end
 end
 
@@ -129,9 +125,9 @@ if options_.dsge_var
 end
 
 % Set sigma_e_is_diagonal flag (needed if the shocks block is not declared in the mod file).
-M_.sigma_e_is_diagonal = 1;
+M_.sigma_e_is_diagonal = true;
 if estim_params_.ncx || any(nnz(tril(M_.Correlation_matrix,-1))) || isfield(estim_params_,'calibrated_covariances')
-    M_.sigma_e_is_diagonal = 0;
+    M_.sigma_e_is_diagonal = false;
 end
 
 data = dataset_.data;
@@ -141,8 +137,10 @@ missing_value = dataset_info.missing.state;
 
 % Set number of observations
 gend = dataset_.nobs;
+
 % Set the number of observed variables.
 n_varobs = length(options_.varobs);
+
 % Get the number of parameters to be estimated.
 nvx = estim_params_.nvx;  % Variance of the structural innovations (number of parameters).
 nvn = estim_params_.nvn;  % Variance of the measurement innovations (number of parameters).
@@ -150,8 +148,9 @@ ncx = estim_params_.ncx;  % Covariance of the structural innovations (number of
 ncn = estim_params_.ncn;  % Covariance of the measurement innovations (number of parameters).
 np  = estim_params_.np ;  % Number of deep parameters.
 nx  = nvx+nvn+ncx+ncn+np; % Total number of parameters to be estimated.
-%% Set the names of the priors.
-pnames = ['     '; 'beta '; 'gamm '; 'norm '; 'invg '; 'unif '; 'invg2'; '     '; 'weibl'];
+
+% Set the names of the priors.
+pnames = {''; 'beta'; 'gamm'; 'norm'; 'invg'; 'unif'; 'invg2'; ''; 'weibl'};
 
 dr = oo_.dr;
 
@@ -178,7 +177,7 @@ catch % if check fails, provide info on using calibration if present
 end
 
 if isequal(options_.mode_compute,0) && isempty(options_.mode_file) && options_.mh_posterior_mode_estimation==0
-    if options_.smoother == 1
+    if options_.smoother
         [atT,innov,measurement_error,updated_variables,ys,trend_coeff,aK,T,R,P,PK,decomp,Trend,state_uncertainty,M_,oo_,options_,bayestopt_] = DsgeSmoother(xparam1,gend,transpose(data),data_index,missing_value,M_,oo_,options_,bayestopt_,estim_params_);
         [oo_]=store_smoother_results(M_,oo_,options_,bayestopt_,dataset_,dataset_info,atT,innov,measurement_error,updated_variables,ys,trend_coeff,aK,P,PK,decomp,Trend,state_uncertainty);
     end
@@ -225,15 +224,15 @@ if ~isequal(options_.mode_compute,0) && ~options_.mh_posterior_mode_estimation
     elseif isnumeric(options_.mode_compute) && options_.mode_compute==6 %save scaling factor
         save([M_.fname '_optimal_mh_scale_parameter.mat'],'Scale');
         options_.mh_jscale = Scale;
-        bayestopt_.jscale = ones(length(xparam1),1)*Scale;
+        bayestopt_.jscale(:) = options_.mh_jscale;
     end
     if ~isnumeric(options_.mode_compute) || ~isequal(options_.mode_compute,6) %always already computes covariance matrix
         if options_.cova_compute == 1 %user did not request covariance not to be computed
             if options_.analytic_derivation && strcmp(func2str(objective_function),'dsge_likelihood')
                 ana_deriv_old = options_.analytic_derivation;
                 options_.analytic_derivation = 2;
-                [junk1, junk2,junk3, junk4, hh] = feval(objective_function,xparam1, ...
-                                                        dataset_,dataset_info,options_,M_,estim_params_,bayestopt_,bounds,oo_);
+                [~,~,~,~,hh] = feval(objective_function,xparam1, ...
+                                     dataset_,dataset_info,options_,M_,estim_params_,bayestopt_,bounds,oo_);
                 options_.analytic_derivation = ana_deriv_old;
             elseif ~isnumeric(options_.mode_compute) || ~(isequal(options_.mode_compute,5) && newratflag~=1 && strcmp(func2str(objective_function),'dsge_likelihood'))
                 % with flag==0, we force to use the hessian from outer product gradient of optimizer 5
@@ -317,7 +316,7 @@ if ~options_.mh_posterior_mode_estimation && options_.cova_compute
     end
 end
 
-if options_.mode_check.status == 1 && ~options_.mh_posterior_mode_estimation
+if options_.mode_check.status && ~options_.mh_posterior_mode_estimation
     ana_deriv_old = options_.analytic_derivation;
     options_.analytic_derivation = 0;
     mode_check(objective_function,xparam1,hh,dataset_,dataset_info,options_,M_,estim_params_,bayestopt_,bounds,oo_);
@@ -358,25 +357,28 @@ end
 
 if any(bayestopt_.pshape > 0) && ~options_.mh_posterior_mode_estimation
     % display results table and store parameter estimates and standard errors in results
-    oo_=display_estimation_results_table(xparam1,stdh,M_,options_,estim_params_,bayestopt_,oo_,pnames,'Posterior','posterior');
+    oo_ = display_estimation_results_table(xparam1, stdh, M_, options_, estim_params_, bayestopt_, oo_, pnames, 'Posterior', 'posterior');
     % Laplace approximation to the marginal log density:
     if options_.cova_compute
         estim_params_nbr = size(xparam1,1);
-        log_det_invhess = log(det(invhess./(stdh*stdh')))+2*sum(log(stdh));
-        likelihood = feval(objective_function,xparam1,dataset_,dataset_info,options_,M_,estim_params_,bayestopt_,bounds,oo_);
-        oo_.MarginalDensity.LaplaceApproximation = .5*estim_params_nbr*log(2*pi) + .5*log_det_invhess - likelihood;
+        if ispd(invhess)
+            log_det_invhess = log(det(invhess./(stdh*stdh')))+2*sum(log(stdh));
+            likelihood = feval(objective_function,xparam1,dataset_,dataset_info,options_,M_,estim_params_,bayestopt_,bounds,oo_);
+            oo_.MarginalDensity.LaplaceApproximation = .5*estim_params_nbr*log(2*pi) + .5*log_det_invhess - likelihood;
+        else
+            oo_.MarginalDensity.LaplaceApproximation = NaN;
+        end
         skipline()
         disp(sprintf('Log data density [Laplace approximation] is %f.',oo_.MarginalDensity.LaplaceApproximation))
         skipline()
     end
     if options_.dsge_var
-        [junk1,junk2,junk3,junk4,junk5,junk6,junk7,oo_.dsge_var.posterior_mode.PHI_tilde,oo_.dsge_var.posterior_mode.SIGMA_u_tilde,oo_.dsge_var.posterior_mode.iXX,oo_.dsge_var.posterior_mode.prior] =...
+        [~,~,~,~,~,~,~,oo_.dsge_var.posterior_mode.PHI_tilde,oo_.dsge_var.posterior_mode.SIGMA_u_tilde,oo_.dsge_var.posterior_mode.iXX,oo_.dsge_var.posterior_mode.prior] =...
             feval(objective_function,xparam1,dataset_,dataset_info,options_,M_,estim_params_,bayestopt_,bounds,oo_);
-        clear('junk1','junk2','junk3','junk4','junk5','junk6','junk7');
     end
 
 elseif ~any(bayestopt_.pshape > 0) && ~options_.mh_posterior_mode_estimation
-    oo_=display_estimation_results_table(xparam1,stdh,M_,options_,estim_params_,bayestopt_,oo_,pnames,'Maximum Likelihood','mle');
+    oo_=display_estimation_results_table(xparam1, stdh, M_, options_, estim_params_, bayestopt_, oo_, pnames, 'Maximum Likelihood', 'mle');
 end
 
 if np > 0
@@ -435,6 +437,21 @@ if (any(bayestopt_.pshape  >0 ) && options_.mh_replic) || ...
             error(['Estimation:: Mode value(s) of ', disp_string ,' are outside parameter bounds.'])
         end
     end
+    % Tunes the jumping distribution's scale parameter
+    if options_.mh_tune_jscale.status
+        if options_.posterior_sampler_options.posterior_sampling_method=='random_walk_metropolis_hastings'
+            options = options_.mh_tune_jscale;
+            options.rwmh = options_.posterior_sampler_options.rwmh;
+            options_.mh_jscale = calibrate_mh_scale_parameter(objective_function, ...
+                                                              invhess, xparam1, [bounds.lb,bounds.ub], ...
+                                                              options, dataset_, dataset_info, options_, M_, estim_params_, bayestopt_, bounds, oo_);
+            bayestopt_.jscale(:) = options_.mh_jscale;
+            disp(sprintf('mh_jscale has been set equal to %s', num2str(options_.mh_jscale)))
+            skipline()
+        else
+            warning('mh_tune_jscale is only available with Random Walk Metropolis Hastings!')
+        end
+    end
     % runs MCMC
     if options_.mh_replic || options_.load_mh_file
         posterior_sampler_options = options_.posterior_sampler_options.current_options;
@@ -501,24 +518,28 @@ if (any(bayestopt_.pshape  >0 ) && options_.mh_replic) || ...
                 oo_.posterior.metropolis=oo_load_mh.oo_.posterior.metropolis;
             end
         end
-        [error_flag,junk,options_]= metropolis_draw(1,options_,estim_params_,M_);
-        if options_.bayesian_irf
-            if error_flag
-                error('Estimation::mcmc: I cannot compute the posterior IRFs!')
+        [error_flag,~,options_]= metropolis_draw(1,options_,estim_params_,M_);
+        if ~(~isempty(options_.sub_draws) && options_.sub_draws==0)
+            if options_.bayesian_irf
+                if error_flag
+                    error('Estimation::mcmc: I cannot compute the posterior IRFs!')
+                end
+                PosteriorIRF('posterior');
             end
-            PosteriorIRF('posterior');
-        end
-        if options_.moments_varendo
-            if error_flag
-                error('Estimation::mcmc: I cannot compute the posterior moments for the endogenous variables!')
+            if options_.moments_varendo
+                if error_flag
+                    error('Estimation::mcmc: I cannot compute the posterior moments for the endogenous variables!')
+                end
+                oo_ = compute_moments_varendo('posterior',options_,M_,oo_,var_list_);
             end
-            oo_ = compute_moments_varendo('posterior',options_,M_,oo_,var_list_);
-        end
-        if options_.smoother || ~isempty(options_.filter_step_ahead) || options_.forecast
-            if error_flag
-                error('Estimation::mcmc: I cannot compute the posterior statistics!')
+            if options_.smoother || ~isempty(options_.filter_step_ahead) || options_.forecast
+                if error_flag
+                    error('Estimation::mcmc: I cannot compute the posterior statistics!')
+                end
+                prior_posterior_statistics('posterior',dataset_,dataset_info);
             end
-            prior_posterior_statistics('posterior',dataset_,dataset_info);
+        else
+            fprintf('Estimation:mcmc: sub_draws was set to 0. Skipping posterior computations.')
         end
         xparam1 = get_posterior_parameters('mean',M_,estim_params_,oo_,options_);
         M_ = set_all_parameters(xparam1,estim_params_,M_);
@@ -532,15 +553,18 @@ if options_.particle.status
 end
 
 if (~((any(bayestopt_.pshape > 0) && options_.mh_replic) || (any(bayestopt_.pshape> 0) && options_.load_mh_file)) ...
-    || ~options_.smoother ) && options_.partial_information == 0  % to be fixed
+    || ~options_.smoother ) && ~options_.partial_information  % to be fixed
     %% ML estimation, or posterior mode without Metropolis-Hastings or Metropolis without Bayesian smoothes variables
     [atT,innov,measurement_error,updated_variables,ys,trend_coeff,aK,T,R,P,PK,decomp,Trend,state_uncertainty,M_,oo_,options_,bayestopt_] = DsgeSmoother(xparam1,dataset_.nobs,transpose(dataset_.data),dataset_info.missing.aindex,dataset_info.missing.state,M_,oo_,options_,bayestopt_,estim_params_);
     [oo_,yf]=store_smoother_results(M_,oo_,options_,bayestopt_,dataset_,dataset_info,atT,innov,measurement_error,updated_variables,ys,trend_coeff,aK,P,PK,decomp,Trend,state_uncertainty);
 
     if ~options_.nograph
         [nbplt,nr,nc,lr,lc,nstar] = pltorg(M_.exo_nbr);
+        if ~exist([M_.fname '/graphs'],'dir')
+            mkdir(M_.fname,'graphs');
+        end
         if options_.TeX && any(strcmp('eps',cellstr(options_.graph_format)))
-            fidTeX = fopen([M_.fname '_SmoothedShocks.tex'],'w');
+            fidTeX = fopen([M_.fname, '/graphs/' M_.fname '_SmoothedShocks.tex'],'w');
             fprintf(fidTeX,'%% TeX eps-loader file generated by dynare_estimation_1.m (Dynare).\n');
             fprintf(fidTeX,['%% ' datestr(now,0) '\n']);
             fprintf(fidTeX,' \n');
@@ -564,7 +588,7 @@ if (~((any(bayestopt_.pshape > 0) && options_.mh_replic) || (any(bayestopt_.psha
                 hold on
                 plot(1:gend,innov(k,:),marker_string{2,1},'linewidth',1)
                 hold off
-                name = deblank(M_.exo_names(k,:));
+                name = M_.exo_names{k};
                 if isempty(NAMES)
                     NAMES = name;
                 else
@@ -578,7 +602,7 @@ if (~((any(bayestopt_.pshape > 0) && options_.mh_replic) || (any(bayestopt_.psha
                     xlim([1 gend])
                 end
                 if options_.TeX
-                    texname = M_.exo_names_tex(k,:);
+                    texname = M_.exo_names_tex{k};
                     if isempty(TeXNAMES)
                         TeXNAMES = ['$ ' deblank(texname) ' $'];
                     else
@@ -587,14 +611,14 @@ if (~((any(bayestopt_.pshape > 0) && options_.mh_replic) || (any(bayestopt_.psha
                 end
                 title(name,'Interpreter','none')
             end
-            dyn_saveas(fh,[M_.fname '_SmoothedShocks' int2str(plt)],options_.nodisplay,options_.graph_format);
+            dyn_saveas(fh,[M_.fname, '/graphs/' M_.fname '_SmoothedShocks' int2str(plt)],options_.nodisplay,options_.graph_format);
             if options_.TeX && any(strcmp('eps',cellstr(options_.graph_format)))
                 fprintf(fidTeX,'\\begin{figure}[H]\n');
                 for jj = 1:nstar0
                     fprintf(fidTeX,'\\psfrag{%s}[1][][0.5][0]{%s}\n',deblank(NAMES(jj,:)),deblank(TeXNAMES(jj,:)));
                 end
                 fprintf(fidTeX,'\\centering \n');
-                fprintf(fidTeX,'\\includegraphics[width=%2.2f\\textwidth]{%s_SmoothedShocks%s}\n',options_.figures.textwidth*min(i/nc,1),M_.fname,int2str(plt));
+                fprintf(fidTeX,'\\includegraphics[width=%2.2f\\textwidth]{%s_SmoothedShocks%s}\n',options_.figures.textwidth*min(i/nc,1),[M_.fname, '/graphs/' M_.fname],int2str(plt));
                 fprintf(fidTeX,'\\caption{Smoothed shocks.}');
                 fprintf(fidTeX,'\\label{Fig:SmoothedShocks:%s}\n',int2str(plt));
                 fprintf(fidTeX,'\\end{figure}\n');
@@ -611,7 +635,7 @@ if (~((any(bayestopt_.pshape > 0) && options_.mh_replic) || (any(bayestopt_.psha
         number_of_plots_to_draw = 0;
         index = [];
         for obs_iter=1:n_varobs
-            if max(abs(measurement_error(obs_iter,:))) > 0.0000001
+            if max(abs(measurement_error(obs_iter,:))) > options_.ME_plot_tol;
                 number_of_plots_to_draw = number_of_plots_to_draw + 1;
                 index = cat(1,index,obs_iter);
             end
@@ -619,7 +643,7 @@ if (~((any(bayestopt_.pshape > 0) && options_.mh_replic) || (any(bayestopt_.psha
         if ~options_.nograph
             [nbplt,nr,nc,lr,lc,nstar] = pltorg(number_of_plots_to_draw);
             if options_.TeX && any(strcmp('eps',cellstr(options_.graph_format)))
-                fidTeX = fopen([M_.fname '_SmoothedObservationErrors.tex'],'w');
+                fidTeX = fopen([M_.fname, '/graphs/' M_.fname '_SmoothedObservationErrors.tex'],'w');
                 fprintf(fidTeX,'%% TeX eps-loader file generated by dynare_estimation_1.m (Dynare).\n');
                 fprintf(fidTeX,['%% ' datestr(now,0) '\n']);
                 fprintf(fidTeX,' \n');
@@ -657,24 +681,24 @@ if (~((any(bayestopt_.pshape > 0) && options_.mh_replic) || (any(bayestopt_.psha
                         set(gca,'XTickLabel',options_.XTickLabel)
                     end
                     if options_.TeX
-                        idx = strmatch(options_.varobs{index(k)},M_.endo_names,'exact');
-                        texname = M_.endo_names_tex(idx,:);
+                        idx = strmatch(options_.varobs{index(k)}, M_.endo_names, 'exact');
+                        texname = M_.endo_names_tex{idx};
                         if isempty(TeXNAMES)
-                            TeXNAMES = ['$ ' deblank(texname) ' $'];
+                            TeXNAMES = ['$ ' texname ' $'];
                         else
-                            TeXNAMES = char(TeXNAMES,['$ ' deblank(texname) ' $']);
+                            TeXNAMES = char(TeXNAMES,['$ ' texname ' $']);
                         end
                     end
                     title(name,'Interpreter','none')
                 end
-                dyn_saveas(fh,[M_.fname '_SmoothedObservationErrors' int2str(plt)],options_.nodisplay,options_.graph_format);
+                dyn_saveas(fh,[M_.fname, '/graphs/' M_.fname '_SmoothedObservationErrors' int2str(plt)],options_.nodisplay,options_.graph_format);
                 if options_.TeX && any(strcmp('eps',cellstr(options_.graph_format)))
                     fprintf(fidTeX,'\\begin{figure}[H]\n');
                     for jj = 1:nstar0
                         fprintf(fidTeX,'\\psfrag{%s}[1][][0.5][0]{%s}\n',deblank(NAMES(jj,:)),deblank(TeXNAMES(jj,:)));
                     end
                     fprintf(fidTeX,'\\centering \n');
-                    fprintf(fidTeX,'\\includegraphics[width=%2.2f\\textwidth]{%s_SmoothedObservationErrors%s}\n',options_.figures.textwidth*min(i/nc,1),M_.fname,int2str(plt));
+                    fprintf(fidTeX,'\\includegraphics[width=%2.2f\\textwidth]{%s_SmoothedObservationErrors%s}\n',options_.figures.textwidth*min(i/nc,1),[M_.fname, '/graphs/' M_.fname],int2str(plt));
                     fprintf(fidTeX,'\\caption{Smoothed observation errors.}');
                     fprintf(fidTeX,'\\label{Fig:SmoothedObservationErrors:%s}\n',int2str(plt));
                     fprintf(fidTeX,'\\end{figure}\n');
@@ -694,7 +718,7 @@ if (~((any(bayestopt_.pshape > 0) && options_.mh_replic) || (any(bayestopt_.psha
     if ~options_.nograph
         [nbplt,nr,nc,lr,lc,nstar] = pltorg(n_varobs);
         if options_.TeX && any(strcmp('eps',cellstr(options_.graph_format)))
-            fidTeX = fopen([M_.fname '_HistoricalAndSmoothedVariables.tex'],'w');
+            fidTeX = fopen([M_.fname, '/graphs/' M_.fname '_HistoricalAndSmoothedVariables.tex'],'w');
             fprintf(fidTeX,'%% TeX eps-loader file generated by dynare_estimation_1.m (Dynare).\n');
             fprintf(fidTeX,['%% ' datestr(now,0) '\n']);
             fprintf(fidTeX,' \n');
@@ -732,24 +756,24 @@ if (~((any(bayestopt_.pshape > 0) && options_.mh_replic) || (any(bayestopt_.psha
                     xlim([1 gend])
                 end
                 if options_.TeX
-                    idx = strmatch(options_.varobs{k},M_.endo_names,'exact');
-                    texname = M_.endo_names_tex(idx,:);
+                    idx = strmatch(options_.varobs{k}, M_.endo_names,'exact');
+                    texname = M_.endo_names_tex{idx};
                     if isempty(TeXNAMES)
-                        TeXNAMES = ['$ ' deblank(texname) ' $'];
+                        TeXNAMES = ['$ ' texname ' $'];
                     else
-                        TeXNAMES = char(TeXNAMES,['$ ' deblank(texname) ' $']);
+                        TeXNAMES = char(TeXNAMES,['$ ' texname ' $']);
                     end
                 end
                 title(name,'Interpreter','none')
             end
-            dyn_saveas(fh,[M_.fname '_HistoricalAndSmoothedVariables' int2str(plt)],options_.nodisplay,options_.graph_format);
+            dyn_saveas(fh,[M_.fname, '/graphs/' M_.fname '_HistoricalAndSmoothedVariables' int2str(plt)],options_.nodisplay,options_.graph_format);
             if options_.TeX && any(strcmp('eps',cellstr(options_.graph_format)))
                 fprintf(fidTeX,'\\begin{figure}[H]\n');
                 for jj = 1:nstar0
                     fprintf(fidTeX,'\\psfrag{%s}[1][][0.5][0]{%s}\n',deblank(NAMES(jj,:)),deblank(TeXNAMES(jj,:)));
                 end
                 fprintf(fidTeX,'\\centering \n');
-                fprintf(fidTeX,'\\includegraphics[width=%2.2f\\textwidth]{%s_HistoricalAndSmoothedVariables%s}\n',options_.figures.textwidth*min(i/nc,1),M_.fname,int2str(plt));
+                fprintf(fidTeX,'\\includegraphics[width=%2.2f\\textwidth]{%s_HistoricalAndSmoothedVariables%s}\n',options_.figures.textwidth*min(i/nc,1),[M_.fname, '/graphs/' M_.fname],int2str(plt));
                 fprintf(fidTeX,'\\caption{Historical and smoothed variables.}');
                 fprintf(fidTeX,'\\label{Fig:HistoricalAndSmoothedVariables:%s}\n',int2str(plt));
                 fprintf(fidTeX,'\\end{figure}\n');
@@ -782,4 +806,4 @@ if reset_options_related_to_estimation
 end
 if first_obs_nan_indicator
     options_.first_obs=NaN;
-end
\ No newline at end of file
+end
