@@ -32,7 +32,7 @@ function [dataset_, dataset_info, xparam1, hh, M_, options_, oo_, estim_params_,
 % SPECIAL REQUIREMENTS
 %   none
 
-% Copyright (C) 2003-2017 Dynare Team
+% Copyright (C) 2003-2020 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -53,15 +53,22 @@ hh = [];
 xparam1 = [];
 
 if isempty(gsa_flag)
-    gsa_flag = 0;
+    gsa_flag = false;
 else
     % Decide if a DSGE or DSGE-VAR has to be estimated.
-    if ~isempty(strmatch('dsge_prior_weight',M_.param_names))
+    if ~isempty(strmatch('dsge_prior_weight', M_.param_names))
         options_.dsge_var = 1;
     end
-    % Get the list of the endogenous variables for which posterior statistics wil be computed
-    var_list_ = check_list_of_variables(options_, M_, var_list_);
-    options_.varlist = var_list_;
+    if isempty(var_list_)
+        var_list_ = check_list_of_variables(options_, M_, var_list_);
+        options_.varlist = var_list_;
+    end
+    if gsa_flag
+        % Get the list of the endogenous variables for which posterior statistics wil be computed.
+        options_.varlist = var_list_;
+    else
+        % This was done in dynare_estimation_1
+    end
 end
 
 if options_.dsge_var && options_.presample~=0
@@ -93,9 +100,17 @@ if length(unique(options_.varobs))<length(options_.varobs)
     end
 end
 
-% Check the perturbation order (nonlinear filters with third order perturbation, or higher order, are not yet implemented).
-if options_.order>2
-    error(['I cannot estimate a model with a ' int2str(options_.order) ' order approximation of the model!'])
+if options_.discretionary_policy
+    if options_.order>1
+        error('discretionary_policy does not support order>1');
+    else
+        M_=discretionary_policy_initialization(M_,options_);
+    end
+end
+
+% Check the perturbation order (k order perturbation based nonlinear filters are not yet implemented for k>1).
+if options_.order>2 && options_.particle.pruning
+    error('Higher order nonlinear filters are not compatible with pruning option.')
 end
 
 % analytical derivation is not yet available for kalman_filter_fast
@@ -418,8 +433,8 @@ nspred = M_.nspred;            % Number of predetermined variables in the state
 var_obs_index_dr = [];
 k1 = [];
 for i=1:options_.number_of_observed_variables
-    var_obs_index_dr = [var_obs_index_dr; strmatch(options_.varobs{i},M_.endo_names(dr.order_var,:),'exact')];
-    k1 = [k1; strmatch(options_.varobs{i},M_.endo_names, 'exact')];
+    var_obs_index_dr = [var_obs_index_dr; strmatch(options_.varobs{i}, M_.endo_names(dr.order_var), 'exact')];
+    k1 = [k1; strmatch(options_.varobs{i}, M_.endo_names, 'exact')];
 end
 
 k3 = [];
@@ -430,9 +445,9 @@ if options_.selected_variables_only
         k3 = (1:M_.endo_nbr)';
         k3p = (1:M_.endo_nbr)';
     else
-        for i=1:size(var_list_,1)
-            k3 = [k3; strmatch(var_list_(i,:),M_.endo_names(dr.order_var,:), 'exact')];
-            k3p = [k3; strmatch(var_list_(i,:),M_.endo_names, 'exact')];
+        for i=1:length(var_list_)
+            k3 = [k3; strmatch(var_list_{i}, M_.endo_names(dr.order_var), 'exact')];
+            k3p = [k3; strmatch(var_list_{i}, M_.endo_names, 'exact')];
         end
     end
 else
@@ -441,44 +456,44 @@ else
 end
 
 % Define union of observed and state variables
-if options_.block == 1
+if options_.block
     k1 = k1';
     [k2, i_posA, i_posB] = union(k1', M_.state_var', 'rows');
     % Set restrict_state to postion of observed + state variables in expanded state vector.
     oo_.dr.restrict_var_list  = [k1(i_posA) M_.state_var(sort(i_posB))];
     % set mf0 to positions of state variables in restricted state vector for likelihood computation.
-    [junk,bayestopt_.mf0] = ismember(M_.state_var',oo_.dr.restrict_var_list);
+    [~,bayestopt_.mf0] = ismember(M_.state_var',oo_.dr.restrict_var_list);
     % Set mf1 to positions of observed variables in restricted state vector for likelihood computation.
-    [junk,bayestopt_.mf1] = ismember(k1,oo_.dr.restrict_var_list);
+    [~,bayestopt_.mf1] = ismember(k1,oo_.dr.restrict_var_list);
     % Set mf2 to positions of observed variables in expanded state vector for filtering and smoothing.
     bayestopt_.mf2  = var_obs_index_dr;
     bayestopt_.mfys = k1;
     oo_.dr.restrict_columns = [size(i_posA,1)+(1:size(M_.state_var,2))];
     [k2, i_posA, i_posB] = union(k3p, M_.state_var', 'rows');
     bayestopt_.smoother_var_list = [k3p(i_posA); M_.state_var(sort(i_posB))'];
-    [junk,junk,bayestopt_.smoother_saved_var_list] = intersect(k3p,bayestopt_.smoother_var_list(:));
-    [junk,ic] = intersect(bayestopt_.smoother_var_list,M_.state_var);
+    [~,~,bayestopt_.smoother_saved_var_list] = intersect(k3p,bayestopt_.smoother_var_list(:));
+    [~,ic] = intersect(bayestopt_.smoother_var_list,M_.state_var);
     bayestopt_.smoother_restrict_columns = ic;
-    [junk,bayestopt_.smoother_mf] = ismember(k1, bayestopt_.smoother_var_list);
+    [~,bayestopt_.smoother_mf] = ismember(k1, bayestopt_.smoother_var_list);
 else
     % Define union of observed and state variables
     k2 = union(var_obs_index_dr,[M_.nstatic+1:M_.nstatic+M_.nspred]', 'rows');
     % Set restrict_state to postion of observed + state variables in expanded state vector.
     oo_.dr.restrict_var_list = k2;
     % set mf0 to positions of state variables in restricted state vector for likelihood computation.
-    [junk,bayestopt_.mf0] = ismember([M_.nstatic+1:M_.nstatic+M_.nspred]',k2);
+    [~,bayestopt_.mf0] = ismember([M_.nstatic+1:M_.nstatic+M_.nspred]',k2);
     % Set mf1 to positions of observed variables in restricted state vector for likelihood computation.
-    [junk,bayestopt_.mf1] = ismember(var_obs_index_dr,k2);
+    [~,bayestopt_.mf1] = ismember(var_obs_index_dr,k2);
     % Set mf2 to positions of observed variables in expanded state vector for filtering and smoothing.
     bayestopt_.mf2  = var_obs_index_dr;
     bayestopt_.mfys = k1;
-    [junk,ic] = intersect(k2,nstatic+(1:npred)');
+    [~,ic] = intersect(k2,nstatic+(1:npred)');
     oo_.dr.restrict_columns = [ic; length(k2)+(1:nspred-npred)'];
     bayestopt_.smoother_var_list = union(k2,k3);
-    [junk,junk,bayestopt_.smoother_saved_var_list] = intersect(k3,bayestopt_.smoother_var_list(:));
-    [junk,ic] = intersect(bayestopt_.smoother_var_list,nstatic+(1:npred)');
+    [~,~,bayestopt_.smoother_saved_var_list] = intersect(k3,bayestopt_.smoother_var_list(:));
+    [~,ic] = intersect(bayestopt_.smoother_var_list,nstatic+(1:npred)');
     bayestopt_.smoother_restrict_columns = ic;
-    [junk,bayestopt_.smoother_mf] = ismember(var_obs_index_dr, bayestopt_.smoother_var_list);
+    [~,bayestopt_.smoother_mf] = ismember(var_obs_index_dr, bayestopt_.smoother_var_list);
 end
 
 if options_.analytic_derivation
@@ -486,10 +501,6 @@ if options_.analytic_derivation
         error('analytic derivation is incompatible with diffuse filter')
     end
     options_.analytic_derivation = 1;
-    if ~(exist('sylvester3','file')==2)
-        dynareroot = strrep(which('dynare'),'dynare.m','');
-        addpath([dynareroot 'gensylv'])
-    end
     if estim_params_.np
         % check if steady state changes param values
         M=M_;
@@ -506,11 +517,11 @@ if options_.analytic_derivation
             skipline()
             if any(isnan(params))
                 disp('After computing the steadystate, the following parameters are still NaN: '),
-                disp(M.param_names(isnan(params),:))
+                disp(char(M.param_names(isnan(params))))
             end
             if any(find(params(~isnan(params))-M.params(~isnan(params))))
                 disp('The steadystate file changed the values for the following parameters: '),
-                disp(M.param_names(find(params(~isnan(params))-M.params(~isnan(params))),:))
+                disp(char(M.param_names(find(params(~isnan(params))-M.params(~isnan(params))))))
             end
             disp('The derivatives of jacobian and steady-state will be computed numerically'),
             disp('(re-set options_.analytic_derivation_mode= -2)'),
@@ -549,7 +560,7 @@ else
     steadystate_check_flag = 1;
 end
 
-% If the steady state of the observed variables is non zero, set noconstant equal 0 ()
+%check steady state at initial parameters
 M = M_;
 nvx = estim_params_.nvx;
 ncx = estim_params_.ncx;
@@ -562,9 +573,37 @@ end
 
 if info(1)
     fprintf('\ndynare_estimation_init:: The steady state at the initial parameters cannot be computed.\n')
+    if options_.debug
+        M.params=params;
+        plist = list_of_parameters_calibrated_as_NaN(M);
+        if ~isempty(plist)
+            message = ['dynare_estimation_init:: Some of the parameters are NaN (' ];
+            for i=1:length(plist)
+                if i<length(plist)
+                    message = [message, plist{i} ', '];
+                else
+                    message = [message, plist{i} ')'];
+                end
+            end
+        end
+        fprintf('%s\n',message)
+        plist = list_of_parameters_calibrated_as_Inf(M);
+        if ~isempty(plist)
+            message = ['dynare_estimation_init:: Some of the parameters are Inf (' ];
+            for i=1:length(plist)
+                if i<size(plist)
+                    message = [message, plist{i} ', '];
+                else
+                    message = [message, plist{i} ')'];
+                end
+            end
+        end
+        fprintf('%s\n',message)
+    end
     print_info(info, 0, options_);
 end
 
+% If the steady state of the observed variables is non zero, set noconstant equal 0 ()
 if (~options_.loglinear && all(abs(oo_.steady_state(bayestopt_.mfys))<1e-9)) || (options_.loglinear && all(abs(log(oo_.steady_state(bayestopt_.mfys)))<1e-9))
     options_.noconstant = 1;
 else
