@@ -1,7 +1,7 @@
-function B = dynare_squeeze(A);
+function B = dynare_squeeze(A)
 % Same as matlab's squeeze function except that it also affects 2D arrays.
 
-% Copyright (C) 2009 Dynare Team
+% Copyright (C) 2009-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -18,7 +18,7 @@ function B = dynare_squeeze(A);
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
-sizA = size(A); 
+sizA = size(A);
 dimA = length(sizA);
 switch dimA
   case 1
