@@ -19,7 +19,7 @@ function [ys,params,info] = evaluate_steady_state_file(ys_init,exo_ss,M,options,
 % SPECIAL REQUIREMENTS
 %   none
 
-% Copyright (C) 2001-2017 Dynare Team
+% Copyright (C) 2001-2019 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -36,9 +36,6 @@ function [ys,params,info] = evaluate_steady_state_file(ys_init,exo_ss,M,options,
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
-debug = false;
-
-ys = [];
 params = M.params;
 info = 0;
 
@@ -49,11 +46,10 @@ if options.steadystate_flag == 1
     assignin('base','tmp_00_',params);
     evalin('base','M_.params=tmp_00_; clear(''tmp_00_'')');
     h_steadystate = str2func([fname '_steadystate']);
-    [ys,check] = h_steadystate(ys_init, exo_ss);
-    params1 = evalin('base','M_.params');
+    [ys,params1,check] = h_steadystate(ys_init, exo_ss,M,options);
 else % steadystate_flag == 2
      % new format
-    h_steadystate = str2func([fname '_steadystate2']);
+    h_steadystate = str2func([fname '.steadystate']);
     [ys,params1,check] = h_steadystate(ys_init, exo_ss, params);
 end
 
@@ -75,20 +71,24 @@ if M.set_auxiliary_variables
     % variables only if the model has auxiliary variables. Otherwise
     % Octave may crash (see https://savannah.gnu.org/bugs/?52568) because
     % the function does not exist in the path.
-    h_set_auxiliary_variables = str2func([M.fname '_set_auxiliary_variables']);
+    h_set_auxiliary_variables = str2func([M.fname '.set_auxiliary_variables']);
 end
 
 if  isnan(updated_params_flag) || (updated_params_flag  && any(isnan(params(~isnan(params))-params1(~isnan(params))))) %checks if new NaNs were added
     info(1) = 24;
     info(2) = NaN;
-    ys = h_set_auxiliary_variables(ys,exo_ss,params);
+    if M.set_auxiliary_variables
+        ys = h_set_auxiliary_variables(ys,exo_ss,params);
+    end
     return
 end
 
 if updated_params_flag && ~isreal(params1)
     info(1) = 23;
     info(2) = sum(imag(params).^2);
-    ys = h_set_auxiliary_variables(ys,exo_ss,params);
+    if M.set_auxiliary_variables
+        ys = h_set_auxiliary_variables(ys,exo_ss,params);
+    end
     return
 end
 
@@ -97,44 +97,12 @@ if updated_params_flag
 end
 
 % adding values for auxiliary variables
-if length(M.aux_vars) > 0 && ~options.ramsey_policy
-    if debug
-        ys0 = ys;
-    end
-    ys = h_set_auxiliary_variables(ys,exo_ss,params);
-    if debug
-        ys1 = ys;
-    end
-    ys = h_set_auxiliary_variables(ys,exo_ss,params);
-    if debug
-        ys2 = ys;
-    end
-    if debug
+if ~isempty(M.aux_vars) && ~options.ramsey_policy
+    if M.set_auxiliary_variables
         ys = h_set_auxiliary_variables(ys,exo_ss,params);
-        ys3 = ys;
-        idx = find(abs(ys0-ys1(1:M.orig_endo_nbr))>0);
-        if ~isempty(idx)
-            M.endo_names(idx,:)
-        else
-            disp('1-invariant')
-        end
-        idx = find(abs(ys2-ys1)>0);
-        if ~isempty(idx)
-            M.endo_names(idx,:)
-        else
-            disp('2-invariant')
-        end
-        idx = find(abs(ys3-ys2)>0);
-        if ~isempty(idx)
-            M.endo_names(idx,:)
-        else
-            disp('3-invariant')
-        end
-        pause
     end
 end
 
-check1 = 0;
 if steady_state_checkflag
     % Check whether the steady state obtained from the _steadystate file is a steady state.
     [residuals, check] = evaluate_static_model(ys, exo_ss, params, M, options);
@@ -157,9 +125,7 @@ elseif ~isempty(options.steadystate_partial)
     nov   = length(ssvar);
     indv  = zeros(nov,1);
     for i = 1:nov
-        indv(i) = strmatch(ssvar(i),M.endo_names,'exact');
+        indv(i) = strmatch(ssvar(i), M.endo_names, 'exact');
     end
-    [ys,check] = dynare_solve('restricted_steadystate',...
-                              ys(indv),...
-                              options, exo_ss,indv);
+    [ys,~] = dynare_solve('restricted_steadystate', ys(indv), options, exo_ss,indv);
 end
