@@ -34,22 +34,11 @@ oo = evalin('base','oo_');
 options = evalin('base','options_');
 mydata=get(findobj(gcf,'tag',['group' int2str(ic)]),'userdata');
 if isfield(mydata,'shock_decomp')
-    if isfield(mydata,'plot_shock_decomp')
-        options.plot_shock_decomp=mydata.plot_shock_decomp;
-        options.shock_decomp=mydata.shock_decomp;
-    else
-        options.plot_shock_decomp=mydata.shock_decomp;
-    end
-else
-    options.plot_shock_decomp=mydata.plot_shock_decomp;
-
-end
-if isfield(mydata,'first_obs')
-    options.first_obs=mydata.first_obs;
-end
-if isfield(mydata,'nobs')
-    options.nobs=mydata.nobs;
+    options.shock_decomp=mydata.shock_decomp;
 end
+options.plot_shock_decomp=mydata.plot_shock_decomp;
+options.first_obs=mydata.first_obs;
+options.nobs=mydata.nobs;
 % define expanded group
 label = mydata.shock_group.label;
 label = strrep(label,' ','_');
@@ -62,6 +51,7 @@ for j=1:length(shocks)
     M.shock_groups.(options.plot_shock_decomp.use_shock_groups).(['group' int2str(j)]).label=shocks{j};
     M.shock_groups.(options.plot_shock_decomp.use_shock_groups).(['group' int2str(j)]).shocks=shocks(j);
 end
+M.exo_names = mydata.exo_names;
 
 options.plot_shock_decomp.interactive=0;
 options.plot_shock_decomp.expand=1;
@@ -74,9 +64,7 @@ MAP(end,:) = [0.7 0.7 0.7];
 
 options.plot_shock_decomp.colormap = MAP;
 
-if isfield(mydata,'endo_names')
-    options.plot_shock_decomp.endo_names = mydata.endo_names;
-    options.plot_shock_decomp.endo_names_tex = mydata.endo_names_tex;
-end
+options.plot_shock_decomp.endo_names = mydata.endo_names;
+options.plot_shock_decomp.endo_names_tex = mydata.endo_names_tex;
 
-plot_shock_decomposition(M,oo,options,var_list_);
+plot_shock_decomposition(M,oo,options,{var_list_});
