@@ -15,20 +15,20 @@ function imcforecast(constrained_paths, constrained_vars, options_cond_fcst)
 %                                                                                               'prior_mode' or
 %                                                                                               'prior mean'.
 %                                                            [double]     np*1 array, values of the estimated parameters.
-%                                      + controlled_varexo   [char]       m*n char array, list of controlled exogenous variables (n is the length of the longest name).
+%                                      + controlled_varexo   [cell]       m*1 cell of row char array, list of controlled exogenous variables.
 %                                      + conf_sig            [double]     scalar in [0,1], probability mass covered by the confidence bands.
 %
 % OUTPUTS
 % None.
-%  (n is the length of the longest name)
+%
 % SPECIAL REQUIREMENTS
 % This routine has to be called after an estimation statement or an estimated_params block.
 %
 % REMARKS
-% [1] Results are stored in a structure which is saved in a mat file called conditional_forecasts.mat.
+% [1] Results are stored in oo_.conditional_forecast.
 % [2] Use the function plot_icforecast to plot the results.
 
-% Copyright (C) 2006-2017 Dynare Team
+% Copyright (C) 2006-2020 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -126,7 +126,8 @@ if estimated_model
     qz_criterium_old=options_.qz_criterium;
     options_=select_qz_criterium_value(options_);
     options_smoothed_state_uncertainty_old = options_.smoothed_state_uncertainty;
-    [atT,innov,measurement_error,filtered_state_vector,ys,trend_coeff,aK,T,R,P,PK,decomp,trend_addition,state_uncertainty,M_,oo_,options_,bayestopt_] = DsgeSmoother(xparam,gend,data,data_index,missing_value,M_,oo_,options_,bayestopt_,estim_params_);
+    [atT, ~, ~, ~,ys, ~, ~, ~, ~, ~, ~, ~, ~, ~,M_,oo_,options_,bayestopt_] = ...
+        DsgeSmoother(xparam, gend, data, data_index, missing_value, M_, oo_, options_, bayestopt_, estim_params_);
     options_.smoothed_state_uncertainty = options_smoothed_state_uncertainty_old;
     %get constant part
     if options_.noconstant
@@ -148,8 +149,8 @@ if estimated_model
     end
     % add trend to constant
     for obs_iter=1:length(options_.varobs)
-        j = strmatch(options_.varobs{obs_iter},M_.endo_names,'exact');
-        constant(j,:) = constant(j,:)+trend_addition(obs_iter,:);
+        j = strcmp(options_.varobs{obs_iter}, M_.endo_names);
+        constant(j,:) = constant(j,:) + trend_addition(obs_iter,:);
     end
     trend = constant(oo_.dr.order_var,:);
     InitState(:,1) = atT(:,end);
@@ -170,7 +171,7 @@ if options_.logged_steady_state %if steady state was previously logged, undo thi
     options_.logged_steady_state=0;
 end
 
-[T,R,ys,info,M_,options_,oo_] = dynare_resolve(M_,options_,oo_);
+[T, R, ys, ~, M_, options_, oo_] = dynare_resolve(M_, options_, oo_);
 
 if options_.loglinear && isfield(oo_.dr,'ys') && options_.logged_steady_state==0 %log steady state
     oo_.dr.ys=log_variable(1:M_.endo_nbr,oo_.dr.ys,M_);
@@ -179,7 +180,7 @@ if options_.loglinear && isfield(oo_.dr,'ys') && options_.logged_steady_state==0
     options_.logged_steady_state=1; %set option for use in stoch_simul
 end
 
-if ~isdiagonal(M_.Sigma_e)
+if ~isdiag(M_.Sigma_e)
     warning(sprintf('The innovations are correlated (the covariance matrix has non zero off diagonal elements), the results of the conditional forecasts will\ndepend on the ordering of the innovations (as declared after varexo) because a Cholesky decomposition is used to factorize the covariance matrix.\n\n=> It is preferable to declare the correlations in the model block (explicitly imposing the identification restrictions), unless you are satisfied\nwith the implicit identification restrictions implied by the Cholesky decomposition.'))
     sQ = chol(M_.Sigma_e,'lower');
 else
@@ -203,9 +204,6 @@ if ~estimated_model
     trend = repmat(ys(oo_.dr.order_var,:),1,options_cond_fcst.periods+1); %trend needs to contain correct steady state
 end
 
-
-
-
 NumberOfStates = length(InitState);
 FORCS1 = zeros(NumberOfStates,options_cond_fcst.periods+1,options_cond_fcst.replic);
 
@@ -216,25 +214,21 @@ ExoSize = M_.exo_nbr;
 
 n1 = size(constrained_vars,1);
 n2 = size(options_cond_fcst.controlled_varexo,1);
-constrained_vars(:,1)=oo_.dr.inv_order_var(constrained_vars); % must be in decision rule order
+
+constrained_vars = oo_.dr.inv_order_var(constrained_vars); % must be in decision rule order
 
 if n1 ~= n2
-    error(['imcforecast:: The number of constrained variables doesn''t match the number of controlled shocks'])
+    error('imcforecast:: The number of constrained variables doesn''t match the number of controlled shocks')
 end
 
-idx = [];
-jdx = [];
+% Get indices of controlled varexo.
+[~, controlled_varexo] =  ismember(options_cond_fcst.controlled_varexo,M_.exo_names);
 
-for i = 1:n1
-    idx = [idx ; constrained_vars(i,:)];
-    %     idx = [idx ; oo_.dr.inv_order_var(constrained_vars(i,:))];
-    jdx = [jdx ; strmatch(deblank(options_cond_fcst.controlled_varexo(i,:)),M_.exo_names,'exact')];
-end
-mv = zeros(n1,NumberOfStates);
-mu = zeros(ExoSize,n2);
+mv = zeros(n1, NumberOfStates);
+mu = zeros(ExoSize, n2);
 for i=1:n1
-    mv(i,idx(i)) = 1;
-    mu(jdx(i),i) = 1;
+    mv(i,constrained_vars(i)) = 1;
+    mu(controlled_varexo(i),i) = 1;
 end
 
 % number of periods with constrained values
@@ -243,7 +237,7 @@ cL = size(constrained_paths,2);
 %transform constrained periods into deviations from steady state; note that
 %trend includes last actual data point and therefore we need to start in
 %period 2
-constrained_paths = bsxfun(@minus,constrained_paths,trend(idx,2:1+cL));
+constrained_paths = bsxfun(@minus,constrained_paths,trend(constrained_vars,2:1+cL));
 
 FORCS1_shocks = zeros(n1,cL,options_cond_fcst.replic);
 
@@ -251,31 +245,43 @@ FORCS1_shocks = zeros(n1,cL,options_cond_fcst.replic);
 
 for b=1:options_cond_fcst.replic %conditional forecast using cL set to constrained values
     shocks = sQ*randn(ExoSize,options_cond_fcst.periods);
-    shocks(jdx,:) = zeros(length(jdx),options_cond_fcst.periods);
+    shocks(controlled_varexo,:) = zeros(n1, options_cond_fcst.periods);
     [FORCS1(:,:,b), FORCS1_shocks(:,:,b)] = mcforecast3(cL,options_cond_fcst.periods,constrained_paths,shocks,FORCS1(:,:,b),T,R,mv, mu);
     FORCS1(:,:,b)=FORCS1(:,:,b)+trend; %add trend
 end
-
+if max(max(max(abs(bsxfun(@minus,FORCS1(constrained_vars,1:cL,:),constrained_paths)))))>1e-4
+    fprintf('\nconditional_forecasts: controlling of variables was not successful.\n')
+    fprintf('This can be due to numerical imprecision (e.g. explosive simulations)\n')
+    fprintf('or because the instrument(s) do not allow controlling the variable(s).\n')
+end
 mFORCS1 = mean(FORCS1,3);
 mFORCS1_shocks = mean(FORCS1_shocks,3);
 
 tt = (1-options_cond_fcst.conditional_forecast.conf_sig)/2;
-t1 = round(options_cond_fcst.replic*tt);
-t2 = round(options_cond_fcst.replic*(1-tt));
+t1 = max(1,round(options_cond_fcst.replic*tt));
+t2 = min(options_cond_fcst.replic,round(options_cond_fcst.replic*(1-tt)));
 
 forecasts.controlled_variables = constrained_vars;
 forecasts.instruments = options_cond_fcst.controlled_varexo;
 
 for i = 1:EndoSize
-    forecasts.cond.Mean.(deblank(M_.endo_names(oo_.dr.order_var(i),:)))= mFORCS1(i,:)';
-    tmp = sort(squeeze(FORCS1(i,:,:))');
-    forecasts.cond.ci.(deblank(M_.endo_names(oo_.dr.order_var(i),:))) = [tmp(t1,:)' ,tmp(t2,:)' ]';
+    forecasts.cond.Mean.(M_.endo_names{oo_.dr.order_var(i)}) = mFORCS1(i,:)';
+    if size(FORCS1,2)>1
+        tmp = sort(squeeze(FORCS1(i,:,:))');
+    else
+        tmp = sort(squeeze(FORCS1(i,:,:)));
+    end
+    forecasts.cond.ci.(M_.endo_names{oo_.dr.order_var(i)}) = [tmp(t1,:)' ,tmp(t2,:)' ]';
 end
 
 for i = 1:n1
-    forecasts.controlled_exo_variables.Mean.(deblank(options_cond_fcst.controlled_varexo(i,:))) = mFORCS1_shocks(i,:)';
-    tmp = sort(squeeze(FORCS1_shocks(i,:,:))');
-    forecasts.controlled_exo_variables.ci.(deblank(options_cond_fcst.controlled_varexo(i,:))) = [tmp(t1,:)' ,tmp(t2,:)' ]';
+    forecasts.controlled_exo_variables.Mean.(options_cond_fcst.controlled_varexo{i}) = mFORCS1_shocks(i,:)';
+    if size(FORCS1_shocks,2)>1
+        tmp = sort(squeeze(FORCS1_shocks(i,:,:))');
+    else
+        tmp = sort(squeeze(FORCS1_shocks(i,:,:)));
+    end
+    forecasts.controlled_exo_variables.ci.(options_cond_fcst.controlled_varexo{i}) = [tmp(t1,:)' ,tmp(t2,:)' ]';
 end
 
 clear FORCS1 mFORCS1_shocks;
@@ -283,25 +289,26 @@ clear FORCS1 mFORCS1_shocks;
 FORCS2 = zeros(NumberOfStates,options_cond_fcst.periods+1,options_cond_fcst.replic);
 FORCS2(:,1,:) = repmat(InitState,1,options_cond_fcst.replic); %set initial steady state to deviations from steady state in first period
 
-%randn('state',0);
-
 for b=1:options_cond_fcst.replic %conditional forecast using cL set to 0
     shocks = sQ*randn(ExoSize,options_cond_fcst.periods);
-    shocks(jdx,:) = zeros(length(jdx),options_cond_fcst.periods);
+    shocks(controlled_varexo,:) = zeros(n1, options_cond_fcst.periods);
     FORCS2(:,:,b) = mcforecast3(0,options_cond_fcst.periods,constrained_paths,shocks,FORCS2(:,:,b),T,R,mv, mu)+trend;
 end
 
 mFORCS2 = mean(FORCS2,3);
 
 for i = 1:EndoSize
-    forecasts.uncond.Mean.(deblank(M_.endo_names(oo_.dr.order_var(i),:)))= mFORCS2(i,:)';
-    tmp = sort(squeeze(FORCS2(i,:,:))');
-    forecasts.uncond.ci.(deblank(M_.endo_names(oo_.dr.order_var(i),:))) = [tmp(t1,:)' ,tmp(t2,:)' ]';
+    forecasts.uncond.Mean.(M_.endo_names{oo_.dr.order_var(i)})= mFORCS2(i,:)';
+    if size(FORCS2,2)>1
+        tmp = sort(squeeze(FORCS2(i,:,:))');
+    else
+        tmp = sort(squeeze(FORCS2(i,:,:)));
+    end
+    forecasts.uncond.ci.(M_.endo_names{oo_.dr.order_var(i)}) = [tmp(t1,:)' ,tmp(t2,:)' ]';
 end
-forecasts.graph.title=graph_title;
-forecasts.graph.fname=M_.fname;
+forecasts.graph.title = graph_title;
+forecasts.graph.fname = M_.fname;
 
 %reset qz_criterium
 options_.qz_criterium=qz_criterium_old;
-
-save('conditional_forecasts.mat','forecasts');
\ No newline at end of file
+oo_.conditional_forecast = forecasts;
