@@ -13,7 +13,7 @@ function initvalf(fname_)
 %    All variables local to this function have an underscore appended to
 %    their name, to minimize clashes with model variables loaded by this function.
 
-% Copyright (C) 2003-2017 Dynare Team
+% Copyright (C) 2003-2018 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -69,42 +69,42 @@ switch (extension)
     error(['Unsupported extension for datafile: ' extension])
 end
 
-options_.initval_file = 1;
+options_.initval_file = true;
 oo_.endo_simul = [];
 oo_.exo_simul = [];
 
-for i_=1:size(M_.endo_names,1)
+for i_=1:length(M_.endo_names)
     if series_ == 1
-        x_ = eval(M_.endo_names(i_,:));
+        x_ = eval(M_.endo_names{i_});
         if size(x_,2)>size(x_,1) %oo_.endo_simul must be collection of row vectors
             oo_.endo_simul = [oo_.endo_simul; x_];
         else %transpose if column vector
             oo_.endo_simul = [oo_.endo_simul; x_'];
         end
     else
-        k_ = strmatch(deblank(M_.endo_names(i_,:)),names_v_,'exact');
+        k_ = strmatch(M_.endo_names{i_}, names_v_, 'exact');
         if isempty(k_)
-            error(['INITVAL_FILE: ' deblank(M_.endo_names(i_,:)) ' not found'])
+            error(['INITVAL_FILE: ' M_.endo_names{i_} ' not found'])
         end
         x_ = data_(:,k_);
         oo_.endo_simul = [oo_.endo_simul; x_'];
     end
 end
 
-for i_=1:size(M_.exo_names,1)
+for i_=1:length(M_.exo_names)
     if series_ == 1
-        x_ = eval(M_.exo_names(i_,:) );
+        x_ = eval(M_.exo_names{i_});
         if size(x_,2)>size(x_,1) %oo_.endo_simul must be collection of row vectors
             oo_.exo_simul = [oo_.exo_simul x_'];
         else %if column vector
             oo_.exo_simul = [oo_.exo_simul x_];
         end
     else
-        k_ = strmatch(deblank(M_.exo_names(i_,:)),names_v_,'exact');
+        k_ = strmatch(M_.exo_names{i_}, names_v_, 'exact');
         if isempty(k_)
-            error(['INITVAL_FILE: ' deblank(M_.exo_names(i_,:)) ' not found'])
+            error(['INITVAL_FILE: ' M_.exo_names{i_} ' not found'])
         end
         x_ = data_(:,k_);
         oo_.exo_simul = [oo_.exo_simul x_];
     end
-end
\ No newline at end of file
+end
