@@ -77,8 +77,11 @@ end
 
 [nbplt,nr,nc,lr,lc,nstar] = pltorg(length(x));
 
+if ~exist([Model.fname filesep 'graphs'],'dir')
+    mkdir(Model.fname,'graphs');
+end
 if TeX && any(strcmp('eps',cellstr(DynareOptions.graph_format)))
-    fidTeX = fopen([Model.fname '_CheckPlots.tex'],'w');
+    fidTeX = fopen([Model.fname, '/graphs/', Model.fname '_CheckPlots.tex'],'w');
     fprintf(fidTeX,'%% TeX eps-loader file generated by mode_check.m (Dynare).\n');
     fprintf(fidTeX,['%% ' datestr(now,0) '\n']);
     fprintf(fidTeX,' \n');
@@ -86,7 +89,7 @@ end
 
 ll = DynareOptions.mode_check.neighbourhood_size;
 if isinf(ll)
-    DynareOptions.mode_check.symmetric_plots = 0;
+    DynareOptions.mode_check.symmetric_plots = false;
 end
 
 mcheck = struct('cross',struct(),'emode',struct());
@@ -127,7 +130,7 @@ for plt = 1:nbplt
             end
             l1 = max(lower_bound,-BayesInfo.p2(kk)); m1 = 0; %lower bound
             l2 = min(upper_bound,BayesInfo.p2(kk)); %upper bound
-        end            
+        end
         binding_lower_bound=0;
         binding_upper_bound=0;
         if isequal(x(kk),BoundsInfo.lb(kk))
@@ -149,7 +152,7 @@ for plt = 1:nbplt
         z1 = l1:((x(kk)-l1)/(DynareOptions.mode_check.number_of_points/2)):x(kk);
         z2 = x(kk):((l2-x(kk))/(DynareOptions.mode_check.number_of_points/2)):l2;
         z  = union(z1,z2);
-        if DynareOptions.mode_check.nolik==0
+        if ~DynareOptions.mode_check.nolik
             y = zeros(length(z),2);
             dy = priordens(xx,BayesInfo.pshape,BayesInfo.p6,BayesInfo.p7,BayesInfo.p3,BayesInfo.p4);
         end
@@ -164,7 +167,7 @@ for plt = 1:nbplt
                     fprintf('mode_check:: could not solve model for parameter %s at value %4.3f, error code: %u\n',name,z(i),info(1))
                 end
             end
-            if DynareOptions.mode_check.nolik==0
+            if ~DynareOptions.mode_check.nolik
                 lnprior = priordens(xx,BayesInfo.pshape,BayesInfo.p6,BayesInfo.p7,BayesInfo.p3,BayesInfo.p4);
                 y(i,2)  = (y(i,1)+lnprior-dy);
             end
@@ -189,7 +192,7 @@ for plt = 1:nbplt
         hold off
         drawnow
     end
-    if DynareOptions.mode_check.nolik==0
+    if ~DynareOptions.mode_check.nolik
         if isoctave
             axes('outerposition',[0.3 0.93 0.42 0.07],'box','on'),
         else
@@ -202,7 +205,7 @@ for plt = 1:nbplt
         text(0.25,0.5,'log-post')
         text(0.69,0.5,'log-lik kernel')
     end
-    dyn_saveas(hh,[ Model.fname '_CheckPlots' int2str(plt) ],DynareOptions.nodisplay,DynareOptions.graph_format);
+    dyn_saveas(hh,[Model.fname, '/graphs/', Model.fname '_CheckPlots' int2str(plt) ],DynareOptions.nodisplay,DynareOptions.graph_format);
     if TeX && any(strcmp('eps',cellstr(DynareOptions.graph_format)))
         % TeX eps loader file
         fprintf(fidTeX,'\\begin{figure}[H]\n');
@@ -210,7 +213,7 @@ for plt = 1:nbplt
             fprintf(fidTeX,'\\psfrag{%s}[1][][0.5][0]{%s}\n',deblank(NAMES(jj,:)),deblank(TeXNAMES(jj,:)));
         end
         fprintf(fidTeX,'\\centering \n');
-        fprintf(fidTeX,'\\includegraphics[width=%2.2f\\textwidth]{%s_CheckPlots%s}\n',DynareOptions.figures.textwidth*min(k/nc,1),Model.fname,int2str(plt));
+        fprintf(fidTeX,'\\includegraphics[width=%2.2f\\textwidth]{%s_CheckPlots%s}\n',DynareOptions.figures.textwidth*min(k/nc,1),[Model.fname, '/graphs/',Model.fname],int2str(plt));
         fprintf(fidTeX,'\\caption{Check plots.}');
         fprintf(fidTeX,'\\label{Fig:CheckPlots:%s}\n',int2str(plt));
         fprintf(fidTeX,'\\end{figure}\n');
