@@ -16,7 +16,7 @@ function model_diagnostics(M,options,oo)
 %   none.
 %
 
-% Copyright (C) 1996-2017 Dynare Team
+% Copyright (C) 1996-2018 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -50,7 +50,7 @@ if ~isempty(k)
     disp(['MODEL_DIAGNOSTICS: The following endogenous variables aren''t present at ' ...
           'the current period in the model:'])
     for i=1:length(k)
-        disp(endo_names(k(i),:))
+        disp(endo_names{k(i)})
     end
 end
 
@@ -115,7 +115,7 @@ for b=1:nb
                                 int2str(b)]);
         end
     else
-        [res,jacob]=feval([M.fname '_static'],dr.ys,exo,M.params);
+        [res,jacob]=feval([M.fname '.static'],dr.ys,exo,M.params);
     end
     if any(any(isinf(jacob) | isnan(jacob)))
         problem_dummy=1;
@@ -154,7 +154,7 @@ for b=1:nb
                     break
                 end
             end
-            disp(endo_names(k,:))
+            fprintf('%s\n',endo_names{k})
         end
         neq = null(jacob');
         n_rel = size(neq,2);
@@ -204,22 +204,22 @@ z = repmat(dr.ys,1,klen);
 if ~options.block
     if options.order == 1
         if (options.bytecode)
-            [chck, junk, loc_dr] = bytecode('dynamic','evaluate', z,exo_simul, ...
-                                            M.params, dr.ys, 1);
+            [chck, ~, loc_dr] = bytecode('dynamic','evaluate', z,exo_simul, ...
+                                         M.params, dr.ys, 1);
             jacobia_ = [loc_dr.g1 loc_dr.g1_x loc_dr.g1_xd];
         else
-            [junk,jacobia_] = feval([M.fname '_dynamic'],z(iyr0),exo_simul, ...
-                                    M.params, dr.ys, it_);
+            [~,jacobia_] = feval([M.fname '.dynamic'],z(iyr0),exo_simul, ...
+                                 M.params, dr.ys, it_);
         end
     elseif options.order >= 2
         if (options.bytecode)
-            [chck, junk, loc_dr] = bytecode('dynamic','evaluate', z,exo_simul, ...
-                                            M.params, dr.ys, 1);
+            [chck, ~, loc_dr] = bytecode('dynamic','evaluate', z,exo_simul, ...
+                                         M.params, dr.ys, 1);
             jacobia_ = [loc_dr.g1 loc_dr.g1_x];
         else
-            [junk,jacobia_,hessian1] = feval([M.fname '_dynamic'],z(iyr0),...
-                                             exo_simul, ...
-                                             M.params, dr.ys, it_);
+            [~,jacobia_,hessian1] = feval([M.fname '.dynamic'],z(iyr0),...
+                                          exo_simul, ...
+                                          M.params, dr.ys, it_);
         end
         if options.use_dll
             % In USE_DLL mode, the hessian is in the 3-column sparse representation
