@@ -45,7 +45,7 @@ switch length(S)
             idBracket.open = strfind(element, '[');
             idBracket.close = strfind(element, ']');
             if ~isequal(length(idBracket.open),length(idBracket.open))
-                error('dseries::subsasgn: (Matlab/Octave''s regular expressions) Check opening and closing square brackets!')
+                error('dseries::subsasgn: (MATLAB/Octave''s regular expressions) Check opening and closing square brackets!')
             end
             % Loops and regular expressions are not compatible
             if length(idArobase) && length(idBracket.open)
@@ -56,7 +56,7 @@ switch length(S)
                 S(1).subs = replace_object_in_a_one_dimensional_cell_array(S(1).subs, elements(:), i);
             end
             if ~isempty(idBracket.open)
-                elements = build_list_of_variables_with_regexp(A.name, idBracket, element, {});
+                elements = build_list_of_variables_with_regexp(A.name, element(2:end-1), false);
                 S(1).subs = replace_object_in_a_one_dimensional_cell_array(S(1).subs, elements(:), i);
             end
         end
@@ -95,7 +95,7 @@ switch length(S)
             % Overwrite the dates member
             A.dates = B;
             return
-        elseif ismember(S(1).subs,{'data','name','tex'})
+        elseif ismember(S(1).subs,{'data','name','tex','ops'})
             error(['dseries::subsasgn: You cannot overwrite ' S(1).subs ' member!'])
         elseif ~isequal(S(1).subs,B.name)
             % Single variable selection.
@@ -120,9 +120,9 @@ switch length(S)
             else
                 Dates = S(1).subs{1};
             end
-            [junk, tdx] = intersect(A.dates.time,Dates.time,'rows');
+            [~, tdx] = intersect(A.dates.time,Dates.time,'rows');
             if isdseries(B)
-                [junk, tdy] = intersect(B.dates.time,Dates.time,'rows');
+                [~, tdy] = intersect(B.dates.time,Dates.time,'rows');
                 if isempty(tdy)
                     error('dseries::subsasgn: Periods of the dseries objects on the left and right hand sides must intersect!')
                 end
@@ -147,29 +147,24 @@ switch length(S)
             end
         elseif ischar(S(1).subs{1}) && isequal(S(1).subs{1},':') && isempty(A)
             if isnumeric(B)
-                if isequal(rows(B),1)
-                    A.data = repmat(B,A.dates.ndat,1);
-                elseif isequal(rows(B),A.dates.ndat)
-                    A.data = B;
+                A.data = B;
+                A.name = default_name(vobs(A));
+                A.tex = name2tex(A.name);
+                if isempty(A.dates)
+                    if isempty(A.dates.freq)
+                        init = dates('1Y')
+                    else
+                        init = dates(A.dates.freq, 1, 1);
+                    end
                 else
-                    error('dseries::subsasgn: Wrong syntax!')
-                end
-                if isempty(A.name)
-                    A.name = default_name(vobs(A));
-                    A.tex = name2tex(A.name);
+                    init = A.dates(1);
                 end
+                A.dates = init:(init+rows(B)-1);
             elseif isdseries(B)
-                if isequal(nobs(B), 1)
-                    A.data = repmat(B.data,A.dates.ndat,1);
-                elseif isequal(nobs(B), A.dates.ndat)
-                    A.data = B;
-                else
-                    error('dseries::subsasgn: Wrong syntax!')
-                end
-                if isempty(A.name)
-                    A.name = B.name;
-                    A.tex = B.tex;
-                end
+                A.data = B.data;
+                A.name = B.name;
+                A.tex = N.tex;
+                A.dates = B.dates;
             end
             return
         else
@@ -188,9 +183,9 @@ switch length(S)
         end
         if (isdseries(B) && isequal(vobs(sA), vobs(B))) || (isnumeric(B) && isequal(vobs(sA),columns(B))) || (isnumeric(B) && isequal(columns(B),1))
             if isdates(S(2).subs{1})
-                [junk, tdx] = intersect(sA.dates.time,S(2).subs{1}.time,'rows');
+                [~, tdx] = intersect(sA.dates.time,S(2).subs{1}.time,'rows');
                 if isdseries(B)
-                    [junk, tdy] = intersect(B.dates.time,S(2).subs{1}.time,'rows');
+                    [~, tdy] = intersect(B.dates.time,S(2).subs{1}.time,'rows');
                     if isempty(tdy)
                         error('dseries::subsasgn: Periods of the dseries objects on the left and right hand sides must intersect!')
                     end
@@ -274,17 +269,22 @@ end
 %$ % Instantiate two dseries object.
 %$ ts1 = dseries(A,[],{'A1';'A2';'A3'},[]);
 %$
-%$ % Apply the exponential function to the second variable.
-%$ ts1{'A2'} = ts1{'A2'}.exp;
+%$ try
+%$     % Apply the exponential function to the second variable.
+%$     ts1{'A2'} = ts1{'A2'}.exp;
+%$     t(1) = 1;
+%$ catch
+%$     t(1) = 0;
+%$ end
 %$
-%$ % Instantiate a time series object.
-%$
-%$    t(1) = dassert(ts1.vobs,3);
-%$    t(2) = dassert(ts1.nobs,10);
-%$    t(3) = dassert(ts1.name{2},'A2');
-%$    t(4) = dassert(ts1.name{1},'A1');
-%$    t(5) = dassert(ts1.name{3},'A3');
-%$    t(6) = dassert(ts1.data,[A(:,1), exp(A(:,2)), A(:,3)],1e-15);
+%$ if t(1)
+%$     t(2) = dassert(ts1.vobs,3);
+%$     t(3) = dassert(ts1.nobs,10);
+%$     t(4) = dassert(ts1.name{2},'A2');
+%$     t(5) = dassert(ts1.name{1},'A1');
+%$     t(6) = dassert(ts1.name{3},'A3');
+%$     t(7) = dassert(ts1.data,[A(:,1), exp(A(:,2)), A(:,3)],1e-15);
+%$ end
 %$ T = all(t);
 %@eof:2
 
@@ -295,18 +295,23 @@ end
 %$ % Instantiate two dseries object.
 %$ ts1 = dseries(A,[],{'A1';'A2';'A3'},[]);
 %$
-%$ % Apply the logarithm function to the first and third variables.
-%$ ts1{'A1'} = ts1{'A1'}.log;
-%$ ts1{'A3'} = ts1{'A3'}.log;
+%$ try
+%$     % Apply the logarithm function to the first and third variables.
+%$     ts1{'A1'} = ts1{'A1'}.log;
+%$     ts1{'A3'} = ts1{'A3'}.log;
+%$     t(1) = 1;
+%$ catch
+%$     t(1) = 0;
+%$ end
 %$
-%$ % Instantiate a time series object.
-%$
-%$    t(1) = dassert(ts1.vobs,3);
-%$    t(2) = dassert(ts1.nobs,10);
-%$    t(3) = dassert(ts1.name{2},'A2');
-%$    t(4) = dassert(ts1.name{1},'A1');
-%$    t(5) = dassert(ts1.name{3},'A3');
-%$    t(6) = dassert(ts1.data,[log(A(:,1)), A(:,2), log(A(:,3))],1e-15);
+%$ if t(1)
+%$     t(2) = dassert(ts1.vobs,3);
+%$     t(3) = dassert(ts1.nobs,10);
+%$     t(4) = dassert(ts1.name{2},'A2');
+%$     t(5) = dassert(ts1.name{1},'A1');
+%$     t(6) = dassert(ts1.name{3},'A3');
+%$     t(7) = dassert(ts1.data,[log(A(:,1)), A(:,2), log(A(:,3))],1e-15);
+%$ end
 %$ T = all(t);
 %@eof:3
 
@@ -317,13 +322,20 @@ end
 %$ % Instantiate two dseries object.
 %$ ts1 = dseries(A,[],{'A1';'A2';'A3'},[]);
 %$
-%$ % Apply the logarithm function to the first and third variables of ts1.
-%$ ts1{'A1','A3'} = ts1{'A1','A3'}.log;
+%$ try
+%$     % Apply the logarithm function to the first and third variables of ts1.
+%$     ts1{'A1','A3'} = ts1{'A1','A3'}.log;
+%$     t(1) = 1;
+%$ catch
+%$     t(1) = 0;
+%$ end
 %$
-%$ t(1) = dassert(ts1.vobs,3);
-%$ t(2) = dassert(ts1.nobs,10);
-%$ t(3) = dassert(ts1.name{1},'A1') && dassert(ts1.name{2},'A2') && dassert(ts1.name{3},'A3');
-%$ t(4) = dassert(ts1.data,[log(A(:,1)), A(:,2), log(A(:,3))],1e-15);
+%$ if t(1)
+%$     t(2) = dassert(ts1.vobs,3);
+%$     t(3) = dassert(ts1.nobs,10);
+%$     t(4) = dassert(ts1.name{1},'A1') && dassert(ts1.name{2},'A2') && dassert(ts1.name{3},'A3');
+%$     t(5) = dassert(ts1.data,[log(A(:,1)), A(:,2), log(A(:,3))],1e-15);
+%$ end
 %$ T = all(t);
 %@eof:4
 
@@ -335,16 +347,20 @@ end
 %$ ts1 = dseries(A,[],{'A1';'A2';'A3'},[]);
 %$ ts2 = dseries(B,[],{'A1';'B2';'B3'},[]);
 %$
-%$ % Apply the logarithm function to the first and third variables.
-%$ ts1.A1 = ts2.A1;
+%$ try
+%$     ts1.A1 = ts2.A1;
+%$     t(1) = 1;
+%$ catch
+%$     t(1) = 0;
+%$ end
 %$
-%$ % Instantiate a time series object.
-%$
-%$ t(1) = dassert(ts1.vobs,3);
-%$ t(2) = dassert(ts1.nobs,10);
-%$ t(3) = dassert(ts1.name{1},'A1');
-%$ t(4) = dassert(ts1.data(:,1),B(:,1), 1e-15);
-%$ t(5) = dassert(ts1.data(:,2:3),A(:,2:3), 1e-15);
+%$ if t(1)
+%$     t(2) = dassert(ts1.vobs,3);
+%$     t(3) = dassert(ts1.nobs,10);
+%$     t(4) = dassert(ts1.name{1},'A1');
+%$     t(5) = dassert(ts1.data(:,1),B(:,1), 1e-15);
+%$     t(6) = dassert(ts1.data(:,2:3),A(:,2:3), 1e-15);
+%$ end
 %$ T = all(t);
 %@eof:5
 
@@ -364,7 +380,6 @@ end
 %$     t(1) = 0;
 %$ end
 %$
-%$ % Instantiate a time series object.
 %$ if t(1)
 %$    t(2) = dassert(ts1.vobs,4);
 %$    t(3) = dassert(ts1.nobs,10);
@@ -385,10 +400,14 @@ end
 %$ ts1 = dseries(A,[],{'A1';'A2';'A3'},[]);
 %$ ts2 = dseries(B,[],{'B1';'B2'},[]);
 %$
-%$ % Append B2 to the first object.
-%$ ts1{'B2'} = ts2{'B2'};
-%$ t(1) = 1;
-%$ % Instantiate a time series object.
+%$ try
+%$     % Append B2 to the first object.
+%$     ts1{'B2'} = ts2{'B2'};
+%$     t(1) = 1;
+%$ catch
+%$     t(1) = 0;
+%$ end
+%$
 %$ if t(1)
 %$    t(2) = dassert(ts1.vobs,4);
 %$    t(3) = dassert(ts1.nobs,10);
@@ -417,7 +436,6 @@ end
 %$     t(1) = 0;
 %$ end
 %$
-%$ % Instantiate a time series object.
 %$ if t(1)
 %$    t(2) = dassert(ts1.vobs,4);
 %$    t(3) = dassert(ts1.nobs,10);
@@ -446,7 +464,6 @@ end
 %$     t(1) = 0;
 %$ end
 %$
-%$ % Instantiate a time series object.
 %$ if t(1)
 %$    t(2) = dassert(ts1.vobs,4);
 %$    t(3) = dassert(ts1.nobs,10);
@@ -534,7 +551,6 @@ end
 %$     t(1) = 0;
 %$ end
 %$
-%$ % Instantiate a time series object.
 %$ if t(1)
 %$    t(2) = dassert(ts1.vobs,3);
 %$    t(3) = dassert(ts1.nobs,40);
@@ -559,13 +575,12 @@ end
 %$     d1 = dates('1950Q3');
 %$     d2 = dates('1951Q3');
 %$     rg = d1:d2;
-%$     ts1{'A1'}(rg) = B(3:7);
+%$     ts1.A1(rg) = B(3:7);
 %$     t(1) = 1;
 %$ catch
 %$     t(1) = 0;
 %$ end
 %$
-%$ % Instantiate a time series object.
 %$ if t(1)
 %$    t(2) = dassert(ts1.vobs,3);
 %$    t(3) = dassert(ts1.nobs,40);
@@ -797,6 +812,30 @@ end
 %@eof:20
 
 %@test:21
+%$ % Define a datasets.
+%$ A = rand(4,3);
+%$
+%$ % Instantiate an empty dseries object.
+%$ ts = dseries(dates('1950Q1'));
+%$
+%$ % Populate ts
+%$ try
+%$     ts(:) = A;
+%$     t(1) = 1;
+%$ catch
+%$     t(1) = 0;
+%$ end
+%$
+%$ % Instantiate a time series object.
+%$ if t(1)
+%$    t(2) = dassert(ts.vobs,3);
+%$    t(3) = dassert(ts.nobs,4);
+%$    t(4) = dassert(ts.data,A,1e-15);
+%$ end
+%$ T = all(t);
+%@eof:21
+
+%@test:22
 %$ % Instantiate a dseries object.
 %$ ts0 = dseries(randn(10,6), '1999y');
 %$
@@ -818,4 +857,4 @@ end
 %$    end
 %$ end
 %$ T = all(t);
-%@eof:21
\ No newline at end of file
+%@eof:22
