@@ -1,6 +1,6 @@
 function from(varargin)   % --*-- Unitary tests --*--
 
-% Copyright (C) 2014-2017 Dynare Team
+% Copyright (C) 2014-2018 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -203,7 +203,7 @@ for i=1:number_of_variables
         try
             eval(sprintf('var = var.%s;',current_variable(idvar+1:end)))
         catch
-            error(sprintf('dseries::from: Variable %s is not a member of dseries oject %s!', current_variable(idvar+1:end), current_variable_0))
+            error(sprintf('dseries::from: Variable %s is not a member of dseries object %s!', current_variable(idvar+1:end), current_variable_0))
         end
     end
     if ~isdseries(var)
