@@ -1,11 +1,10 @@
 function o = addTable(o, varargin)
 %function o = addTable(o, varargin)
-% Add a report_table to the Cell Array of report_tables in the report
+% Add a report_table
 %
 % INPUTS
-%   1 args => add empty report_table
-%   2 args => add given report_table
-%   3 args => add report_table at index
+%   o          [section] section object
+%   varargin             arguments to report_table()
 %
 % OUTPUTS
 %   updated section object
@@ -13,7 +12,7 @@ function o = addTable(o, varargin)
 % SPECIAL REQUIREMENTS
 %   none
 
-% Copyright (C) 2013-2015 Dynare Team
+% Copyright (C) 2013-2019 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -30,9 +29,9 @@ function o = addTable(o, varargin)
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
-for i=1:length(o.elements)
-    assert(~isa(o.elements{i}, 'paragraph'), ...
-           '@addTable: A Section that contains a Paratable cannot contain a Table');
+if ~isempty(o.elements)
+    assert(~isa(o.elements{1}, 'paragraph'), ...
+        '@section.addSeries: A section that contains a paragraph cannot contain a graph or a table');
 end
 o.elements{end+1} = report_table(varargin{:});
 end
