@@ -1,4 +1,4 @@
-% Copyright (C) 2017 Dynare Team
+% Copyright (C) 2017-2019 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -15,17 +15,12 @@
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
-addpath('~/builds/dynare/matlab/utilities/general')
-addpath('~/builds/dynare/matlab/modules/dates/src')
-addpath('~/builds/dynare/matlab/modules/dseries/src')
-addpath('../src')
-
-initialize_dates_toolbox;
-initialize_dseries_toolbox;
+initialize_dseries_class();
+initialize_reporting_toolbox();
 
 db_a = dseries('db_a.csv');
 db_q = dseries('db_q.csv');
 dc_a = dseries('dc_a.csv');
 dc_q = dseries('dc_q.csv');
 
-createReport(dc_a, dc_q, db_a, db_q);
\ No newline at end of file
+createReport(dc_a, dc_q, db_a, db_q);
