@@ -11,7 +11,7 @@ function delete_dir_if_exists(dirname)
 % SPECIAL REQUIREMENTS
 %    none
 
-% Copyright (C) 2011-2014 Dynare Team
+% Copyright (C) 2011-2016 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -28,6 +28,10 @@ function delete_dir_if_exists(dirname)
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
+if isoctave
+    confirm_recursive_rmdir(false)
+end
+
 if exist(dirname, 'dir')
     rmdir(dirname, 's');
 end
