@@ -27,7 +27,7 @@ for i=1:n+1
                                [exo_steady_state; ...
                             exo_det_steady_state],params);
     else
-        res = feval([fname '_static'],ys1,...
+        res = feval([fname '.static'],ys1,...
                     [exo_steady_state; ...
                      exo_det_steady_state],params);
     end
