@@ -1,4 +1,4 @@
-function IncrementalWeights = gaussian_densities(obs,mut_t,sqr_Pss_t_t,st_t_1,sqr_Pss_t_t_1,particles,H,normconst,weigths1,weigths2,ReducedForm,ThreadsOptions)
+function IncrementalWeights = gaussian_densities(obs,mut_t,sqr_Pss_t_t,st_t_1,sqr_Pss_t_t_1,particles,H,normconst,weigths1,weigths2,ReducedForm,ThreadsOptions,DynareOptions, Model)
 %
 % Elements to calculate the importance sampling ratio
 %
@@ -19,7 +19,8 @@ function IncrementalWeights = gaussian_densities(obs,mut_t,sqr_Pss_t_t,st_t_1,sq
 %
 % NOTES
 %   The vector "lik" is used to evaluate the jacobian of the likelihood.
-% Copyright (C) 2009-2017 Dynare Team
+
+% Copyright (C) 2009-2019 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -37,17 +38,13 @@ function IncrementalWeights = gaussian_densities(obs,mut_t,sqr_Pss_t_t,st_t_1,sq
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
 % proposal density
-proposal = probability2(mut_t,sqr_Pss_t_t,particles) ;
+proposal = probability2(mut_t, sqr_Pss_t_t, particles);
+
 % prior density
-prior = probability2(st_t_1,sqr_Pss_t_t_1,particles) ;
+prior = probability2(st_t_1, sqr_Pss_t_t_1, particles);
+
 % likelihood
-yt_t_1_i = measurement_equations(particles,ReducedForm,ThreadsOptions) ;
-%eta_t_i = bsxfun(@minus,obs,yt_t_1_i)' ;
-%yt_t_1 = sum(yt_t_1_i*weigths1,2) ;
-%tmp = bsxfun(@minus,yt_t_1_i,yt_t_1) ;
-%Pyy = bsxfun(@times,weigths2',tmp)*tmp' + H ;
-%sqr_det = sqrt(det(Pyy)) ;
-%foo = (eta_t_i/Pyy).*eta_t_i ;
-%likelihood = exp(-0.5*sum(foo,2))/(normconst*sqr_det) + 1e-99 ;
-likelihood = probability2(obs,sqrt(H),yt_t_1_i) ;
-IncrementalWeights = likelihood.*prior./proposal ;
+yt_t_1_i = measurement_equations(particles, ReducedForm, ThreadsOptions, DynareOptions, Model);
+likelihood = probability2(obs, sqrt(H), yt_t_1_i);
+
+IncrementalWeights = likelihood.*prior./proposal;
