@@ -1,25 +1,22 @@
 function [residuals,JJacobian] = linear_perfect_foresight_problem(y, dynamicjacobian, Y0, YT, ...
-                                                  exo_simul, params, steady_state, ...
-                                                  maximum_lag, T, ny, i_cols, ...
-                                                  i_cols_J1, i_cols_1, i_cols_T, ...
-                                                  i_cols_j,nnzJ,jendo,jexog)
-% function [residuals,JJacobian] = perfect_foresight_problem(x, model_dynamic, Y0, YT,exo_simul,
-% params, steady_state, maximum_lag, periods, ny, i_cols,i_cols_J1, i_cols_1,
-% i_cols_T, i_cols_j, nnzA)
-% computes the residuals and th Jacobian matrix
-% for a perfect foresight problem over T periods.
+                                                  exo_simul, params, steady_state, maximum_lag, T, ny, i_cols, ...
+                                                  i_cols_J1, i_cols_1, i_cols_T, i_cols_j, i_cols_0, i_cols_J0, jendo, jexog)
+
+% Computes the residuals and the Jacobian matrix for a linear perfect foresight problem over T periods.
 %
 % INPUTS
-%   ...
+% ...
+%
 % OUTPUTS
-%   ...
+% ...
+%
 % ALGORITHM
-%   ...
+% ...
 %
 % SPECIAL REQUIREMENTS
 %   None.
 
-% Copyright (C) 2015-2017 Dynare Team
+% Copyright (C) 2015-2019 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -44,26 +41,39 @@ residuals = zeros(T*ny,1);
 z = zeros(columns(dynamicjacobian), 1);
 
 if nargout == 2
-    JJacobian = sparse([],[],[],T*ny,T*ny,T*nnzJ);
+    iJacobian = cell(T,1);
 end
 
 i_rows = 1:ny;
 i_cols_J = i_cols;
+offset = 0;
 
 for it = maximum_lag+(1:T)
     z(jendo) = YY(i_cols);
     z(jexog) = transpose(exo_simul(it,:));
     residuals(i_rows) = dynamicjacobian*z;
     if nargout == 2
-        if it == maximum_lag+1
-            JJacobian(i_rows,i_cols_J1) = dynamicjacobian(:,i_cols_1);
+        if T==1 && it==maximum_lag+1
+            [rows, cols, vals] = find(dynamicjacobian(:,i_cols_0));
+            iJacobian{1} = [rows, i_cols_J0(cols), vals];
+        elseif it == maximum_lag+1
+            [rows,cols,vals] = find(dynamicjacobian(:,i_cols_1));
+            iJacobian{1} = [offset+rows, i_cols_J1(cols), vals];
         elseif it == maximum_lag+T
-            JJacobian(i_rows,i_cols_J(i_cols_T)) = dynamicjacobian(:,i_cols_T);
+            [rows,cols,vals] = find(dynamicjacobian(:,i_cols_T));
+            iJacobian{T} = [offset+rows, i_cols_J(i_cols_T(cols)), vals];
         else
-            JJacobian(i_rows,i_cols_J) = dynamicjacobian(:,i_cols_j);
+            [rows,cols,vals] = find(dynamicjacobian(:,i_cols_j));
+            iJacobian{it-maximum_lag} = [offset+rows, i_cols_J(cols), vals];
             i_cols_J = i_cols_J + ny;
         end
+        offset = offset + ny;
     end
     i_rows = i_rows + ny;
     i_cols = i_cols + ny;
-end
\ No newline at end of file
+end
+
+if nargout == 2
+    iJacobian = cat(1,iJacobian{:});
+    JJacobian = sparse(iJacobian(:,1), iJacobian(:,2), iJacobian(:,3), T*ny, T*ny);
+end
