@@ -107,7 +107,7 @@ if verbose
     skipline()
 end
 
-dynamicmodel = str2func([M.fname,'_dynamic']);
+dynamicmodel = str2func([M.fname,'.dynamic']);
 
 z = steadystate_y([ip; ic; in]);
 x = repmat(transpose(steadystate_x), 1+M.maximum_exo_lag+M.maximum_exo_lead, 1);
@@ -116,7 +116,7 @@ x = repmat(transpose(steadystate_x), 1+M.maximum_exo_lag+M.maximum_exo_lead, 1);
 [d1, jacobian] = dynamicmodel(z, x, params, steadystate_y, M.maximum_exo_lag+1);
 
 % Check that the dynamic model was evaluated at the steady state.
-if max(abs(d1))>1e-12
+if max(abs(d1))>options.solve_tolf
     error('Jacobian is not evaluated at the steady state!')
 end
 
@@ -142,7 +142,7 @@ i_cols_A = ipcn;
 i_cols = ipcn+(maximum_lag-1)*ny;
 m = 0;
 for it = (maximum_lag+1):(maximum_lag+periods)
-    if isequal(it, maximum_lag+periods) && isequal(it, maximum_lag+1)
+    if periods==1 && isequal(it, maximum_lag+1)
         nv = length(v0);
         iA(iv0+m,:) = [i_rows(r0),ic(c0),v0];
     elseif isequal(it, maximum_lag+periods)
