@@ -1,5 +1,6 @@
 function oo_ = posterior_analysis(type,arg1,arg2,arg3,options_,M_,oo_)
-% Copyright (C) 2008-2017 Dynare Team
+
+% Copyright (C) 2008-2018 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -63,6 +64,17 @@ switch type
     end
     oo_ = variance_decomposition_mc_analysis(SampleSize,'posterior',M_.dname,M_.fname,...
                                              M_.exo_names,arg2,vartan,arg1,options_.mh_conf_sig,oo_,options_);
+    if ~all(M_.H==0)
+        if strmatch(arg1,options_.varobs,'exact')
+            if isoctave || matlab_ver_less_than('8.1')
+                [observable_name_requested_vars,index_subset,index_observables]=intersect_stable(vartan,options_.varobs);
+            else
+                [observable_name_requested_vars,index_subset,index_observables]=intersect(vartan,options_.varobs,'stable');
+            end
+            oo_ = variance_decomposition_ME_mc_analysis(SampleSize,'posterior',M_.dname,M_.fname,...
+                                                        M_.exo_names,arg2,observable_name_requested_vars,arg1,options_.mh_conf_sig,oo_,options_);
+        end
+    end
   case 'correlation'
     if nargin==narg1
         [nvar,vartan,NumberOfFiles] = ...
@@ -77,6 +89,12 @@ switch type
     end
     oo_ = conditional_variance_decomposition_mc_analysis(SampleSize,'posterior',M_.dname,M_.fname,...
                                                       arg3,M_.exo_names,arg2,vartan,arg1,options_.mh_conf_sig,oo_,options_);
+    if ~all(M_.H==0)
+        if strmatch(arg1,options_.varobs,'exact')
+            oo_ = conditional_variance_decomposition_ME_mc_analysis(SampleSize,'posterior',M_.dname,M_.fname,...
+                                                              arg3,M_.exo_names,arg2,vartan,arg1,options_.mh_conf_sig,oo_,options_);
+        end
+    end
   otherwise
     disp('Not yet implemented')
-end
\ No newline at end of file
+end
