@@ -78,6 +78,12 @@ switch type
     end
     oo_ = conditional_variance_decomposition_mc_analysis(SampleSize,'prior',M_.dname,M_.fname,...
                                                       arg3,M_.exo_names,arg2,vartan,arg1,options_.mh_conf_sig,oo_,options_);
+    if ~all(M_.H==0)
+        if strmatch(vartan(arg1,:),options_.varobs,'exact')
+            oo_ = conditional_variance_decomposition_ME_mc_analysis(SampleSize,'prior',M_.dname,M_.fname,...
+                                                              arg3,M_.exo_names,arg2,vartan,arg1,options_.mh_conf_sig,oo_,options_);
+        end
+    end
   otherwise
     disp('Not yet implemented')
 end
\ No newline at end of file
