@@ -22,7 +22,7 @@ function oo_ = realtime_shock_decomposition(M_,oo_,options_,varlist,bayestopt_,e
 % SPECIAL REQUIREMENTS
 %    none
 
-% Copyright (C) 2009-2017 Dynare Team
+% Copyright (C) 2009-2019 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -39,13 +39,27 @@ function oo_ = realtime_shock_decomposition(M_,oo_,options_,varlist,bayestopt_,e
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
-% indices of endogenous variables
-if size(varlist,1) == 0
-    varlist = M_.endo_names(1:M_.orig_endo_nbr,:);
+
+if isfield(oo_,'shock_decomposition_info') && isfield(oo_.shock_decomposition_info,'i_var')
+    if isfield (oo_,'realtime_conditional_shock_decomposition') ...
+            || isfield (oo_,'realtime_forecast_shock_decomposition') ...
+            || isfield (oo_,'realtime_shock_decomposition') ...
+            || isfield (oo_,'shock_decomposition') ...
+            || isfield (oo_,'conditional_shock_decomposition') ...
+            || isfield (oo_,'initval_decomposition')
+        error('realtime_shock_decomposition::squeezed shock decompositions are already stored in oo_')
+    end
 end
 
-[i_var,nvar,index_uniques] = varlist_indices(varlist,M_.endo_names);
-varlist=varlist(index_uniques,:);
+with_epilogue = options_.shock_decomp.with_epilogue;
+
+% indices of endogenous variables
+if isempty(varlist)
+    varlist = M_.endo_names(1:M_.orig_endo_nbr);
+end
+
+[~, ~, index_uniques] = varlist_indices(varlist,M_.endo_names);
+varlist = varlist(index_uniques);
 
 % number of variables
 endo_nbr = M_.endo_nbr;
@@ -68,9 +82,10 @@ if isempty(parameter_set)
     end
 end
 
-presample = max(1,options_.presample);
+presample = max(1,options_.presample-1);
 if isfield(options_.shock_decomp,'presample')
-    presample = max(presample,options_.shock_decomp.presample);
+    my_presample = max(1,options_.shock_decomp.presample);
+    presample = min(presample,my_presample);
 end
 % forecast_=0;
 forecast_ = options_.shock_decomp.forecast;
@@ -78,18 +93,17 @@ forecast_params=0;
 if forecast_ && isfield(options_.shock_decomp,'forecast_params')
     forecast_params = options_.shock_decomp.forecast_params;
 end
+fast_realtime = 0;
+if isfield(options_.shock_decomp,'fast_realtime')
+    fast_realtime = options_.shock_decomp.fast_realtime;
+end
 
 % save_realtime=0;
 save_realtime = options_.shock_decomp.save_realtime;
 % array of time points in the range options_.presample+1:options_.nobs
 
-zreal = zeros(endo_nbr,nshocks+2,options_.nobs+forecast_);
-zcond = zeros(endo_nbr,nshocks+2,options_.nobs);
-skipline()
-skipline()
-running_text = 'Realtime shock decomposition ';
-newString=sprintf(running_text);
-fprintf(['\b%s'],newString);
+zreal = zeros(endo_nbr+length(M_.epilogue_names)*with_epilogue,nshocks+2,options_.nobs+forecast_);
+zcond = zeros(endo_nbr+length(M_.epilogue_names)*with_epilogue,nshocks+2,options_.nobs);
 
 options_.selected_variables_only = 0; %make sure all variables are stored
 options_.plot_priors=0;
@@ -99,15 +113,60 @@ nobs = options_.nobs;
 if forecast_ && any(forecast_params)
     M1=M_;
     M1.params = forecast_params;
-    [junk1,junk2,junk3,junk4,junk5,junk6,oo1] = dynare_resolve(M1,options_,oo_);
-    clear junk1 junk2 junk3 junk4 junk5 junk6
+    [~,~,~,~,~,~,oo1] = dynare_resolve(M1,options_,oo_);
 end
 
+if fast_realtime
+    skipline()
+    skipline()
+    running_text = 'Fast realtime shock decomposition ';
+    newString=sprintf(running_text);
+    fprintf(['%s'],newString);
+    options_.nobs=fast_realtime;
+    [oo0,M_,~,~,Smoothed_Variables_deviation_from_mean0] = evaluate_smoother(parameter_set,varlist,M_,oo_,options_,bayestopt_,estim_params_);
+    gend0 = size(oo0.SmoothedShocks.(M_.exo_names{1}),1);
+    prctdone=0.5;
+    if isoctave
+        printf([running_text,' %3.f%% done\r'], prctdone*100);
+    else
+        s0=repmat('\b',1,length(newString)+1);
+        newString=sprintf([running_text,' %3.1f%% done'], prctdone*100);
+        fprintf([s0,'%s'],newString);
+    end
+    options_.nobs=nobs;
+    [oo2,M_,~,~,Smoothed_Variables_deviation_from_mean2] = evaluate_smoother(parameter_set,varlist,M_,oo_,options_,bayestopt_,estim_params_);
+    prctdone=1;
+    if isoctave
+        printf([running_text,' %3.f%% done\r'], prctdone*100);
+    else
+        s0=repmat('\b',1,length(newString)+1);
+        newString=sprintf([running_text,' %3.1f%% done'], prctdone*100);
+        fprintf([s0,'%s'],newString);
+    end
+end
+
+skipline()
+skipline()
+running_text = 'Realtime shock decomposition ';
+newString=sprintf(running_text);
+fprintf(['%s'],newString);
+
 for j=presample+1:nobs
     %    evalin('base',['options_.nobs=' int2str(j) ';'])
     options_.nobs=j;
-    [oo, M_, junk2, junk3, Smoothed_Variables_deviation_from_mean] = evaluate_smoother(parameter_set,varlist,M_,oo_,options_,bayestopt_,estim_params_);
-
+    if ~fast_realtime
+        [oo,M_,~,~,Smoothed_Variables_deviation_from_mean] = evaluate_smoother(parameter_set,varlist,M_,oo_,options_,bayestopt_,estim_params_);
+        gend = size(oo.SmoothedShocks.(M_.exo_names{1}),1);
+    else
+        gend = gend0+j-fast_realtime;
+        if j>fast_realtime
+            oo=oo2;
+            Smoothed_Variables_deviation_from_mean = Smoothed_Variables_deviation_from_mean2(:,1:gend);
+        else
+            oo=oo0;
+            Smoothed_Variables_deviation_from_mean = Smoothed_Variables_deviation_from_mean0(:,1:gend);
+        end
+    end
     % reduced form
     dr = oo.dr;
 
@@ -131,10 +190,9 @@ for j=presample+1:nobs
     end
 
     % initialization
-    gend = size(oo.SmoothedShocks.(deblank(M_.exo_names(1,:))),1);
     epsilon=NaN(nshocks,gend);
-    for i=1:nshocks
-        epsilon(i,:) = oo.SmoothedShocks.(deblank(M_.exo_names(i,:)));
+    for i = 1:nshocks
+        epsilon(i,:) = oo.SmoothedShocks.(M_.exo_names{i})(1:gend);
     end
     epsilon=[epsilon zeros(nshocks,forecast_)];
 
@@ -170,6 +228,12 @@ for j=presample+1:nobs
         z(:,nshocks+1,i) = z(:,nshocks+2,i) - sum(z(:,1:nshocks,i),2);
     end
 
+    if with_epilogue
+        [z, epilogue_steady_state] = epilogue_shock_decomposition(z, M_, oo_);
+        if ~isfield(oo_,'shock_decomposition_info') || ~isfield(oo_.shock_decomposition_info,'epilogue_steady_state')
+            oo_.shock_decomposition_info.epilogue_steady_state = epilogue_steady_state;
+        end
+    end
     %% conditional shock decomp 1 step ahead
     z1 = zeros(endo_nbr,nshocks+2);
     z1(:,end) = Smoothed_Variables_deviation_from_mean(:,gend);
@@ -178,6 +242,15 @@ for j=presample+1:nobs
         z1(:,1:nshocks) = z1(:,1:nshocks) + B(inv_order_var,:).*repmat(epsilon(:,i)',endo_nbr,1);
         z1(:,nshocks+1) = z1(:,nshocks+2) - sum(z1(:,1:nshocks),2);
     end
+    if with_epilogue
+        clear ztmp0
+        ztmp0(:,1,:) = Smoothed_Variables_deviation_from_mean(:,1:gend-1);
+        ztmp0(:,2,:) = Smoothed_Variables_deviation_from_mean(:,1:gend-1);
+        ztmp = cat(3,cat(2,zeros(endo_nbr,nshocks,gend-1),ztmp0),z1);
+%         ztmp = cat(3,zeros(endo_nbr,nshocks+2,40),ztmp); % pad with zeros in presample
+        z1  = epilogue_shock_decomposition(ztmp, M_, oo_);
+        z1=squeeze(z1(:,:,end));
+    end
     %%
 
     %% conditional shock decomp k step ahead
@@ -201,14 +274,27 @@ for j=presample+1:nobs
             %             zn(:,1:nshocks,i) = zn(:,1:nshocks,i) + B(inv_order_var,:).*repmat(epsilon(:,i+gend-forecast_-1)',endo_nbr,1);
             zn(:,nshocks+1,i) = zn(:,nshocks+2,i) - sum(zn(:,1:nshocks,i),2);
         end
-        oo_.conditional_shock_decomposition.(['time_' int2str(j-forecast_)])=zn;
+        if with_epilogue
+            clear ztmp0
+            ztmp0(:,1,:) = Smoothed_Variables_deviation_from_mean(:,1:gend-forecast_-1);
+            ztmp0(:,2,:) = Smoothed_Variables_deviation_from_mean(:,1:gend-forecast_-1);
+            ztmp = cat(3,cat(2,zeros(endo_nbr,nshocks,gend-forecast_-1),ztmp0),zn);
+%             ztmp = cat(3,zeros(endo_nbr,nshocks+2,40),ztmp); % pad with zeros (st state) in presample
+            zn  = epilogue_shock_decomposition(ztmp, M_, oo_);
+            zn=squeeze(zn(:,:,end-forecast_:end));
+        end
+        if ismember(j-forecast_,save_realtime)
+            oo_.conditional_shock_decomposition.(['time_' int2str(j-forecast_)])=zn;
+        end
     end
     %%
 
     if init
         zreal(:,:,1:j) = z(:,:,1:j);
-    else
+    elseif j<nobs
         zreal(:,:,j) = z(:,:,gend);
+    else
+        zreal(:,:,j:end) = z(:,:,gend:end);
     end
     zcond(:,:,j) = z1;
     if ismember(j,save_realtime)
@@ -217,28 +303,39 @@ for j=presample+1:nobs
 
     if forecast_
         zfrcst(:,:,j+1) = z(:,:,gend+1);
-        oo_.realtime_forecast_shock_decomposition.(['time_' int2str(j)])=z(:,:,gend:end);
+        ootmp.realtime_forecast_shock_decomposition.(['time_' int2str(j)])=z(:,:,gend:end);
+        if ismember(j,save_realtime)
+            oo_.realtime_forecast_shock_decomposition.(['time_' int2str(j)]) = ...
+                ootmp.realtime_forecast_shock_decomposition.(['time_' int2str(j)]);
+        end
         if j>forecast_+presample
             %% realtime conditional shock decomp k step ahead
-            oo_.realtime_conditional_shock_decomposition.(['time_' int2str(j-forecast_)]) = ...
+            ootmp.realtime_conditional_shock_decomposition.(['time_' int2str(j-forecast_)]) = ...
                 zreal(:,:,j-forecast_:j) - ...
-                oo_.realtime_forecast_shock_decomposition.(['time_' int2str(j-forecast_)]);
-            oo_.realtime_conditional_shock_decomposition.(['time_' int2str(j-forecast_)])(:,end-1,:) = ...
-                oo_.realtime_conditional_shock_decomposition.(['time_' int2str(j-forecast_)])(:,end-1,:) + ...
-                oo_.realtime_forecast_shock_decomposition.(['time_' int2str(j-forecast_)])(:,end,:);
-            oo_.realtime_conditional_shock_decomposition.(['time_' int2str(j-forecast_)])(:,end,:) = ...
+                ootmp.realtime_forecast_shock_decomposition.(['time_' int2str(j-forecast_)]);
+            ootmp.realtime_conditional_shock_decomposition.(['time_' int2str(j-forecast_)])(:,end-1,:) = ...
+                ootmp.realtime_conditional_shock_decomposition.(['time_' int2str(j-forecast_)])(:,end-1,:) + ...
+                ootmp.realtime_forecast_shock_decomposition.(['time_' int2str(j-forecast_)])(:,end,:);
+            ootmp.realtime_conditional_shock_decomposition.(['time_' int2str(j-forecast_)])(:,end,:) = ...
                 zreal(:,end,j-forecast_:j);
-
+            if ismember(j-forecast_,save_realtime)
+                oo_.realtime_conditional_shock_decomposition.(['time_' int2str(j-forecast_)]) = ...
+                    ootmp.realtime_conditional_shock_decomposition.(['time_' int2str(j-forecast_)]);
+            end
             if j==nobs
                 for my_forecast_=(forecast_-1):-1:1
-                    oo_.realtime_conditional_shock_decomposition.(['time_' int2str(j-my_forecast_)]) = ...
+                    ootmp.realtime_conditional_shock_decomposition.(['time_' int2str(j-my_forecast_)]) = ...
                         zreal(:,:,j-my_forecast_:j) - ...
-                        oo_.realtime_forecast_shock_decomposition.(['time_' int2str(j-my_forecast_)])(:,:,1:my_forecast_+1);
-                    oo_.realtime_conditional_shock_decomposition.(['time_' int2str(j-my_forecast_)])(:,end-1,:) = ...
-                        oo_.realtime_conditional_shock_decomposition.(['time_' int2str(j-my_forecast_)])(:,end-1,:) + ...
-                        oo_.realtime_forecast_shock_decomposition.(['time_' int2str(j-my_forecast_)])(:,end,1:my_forecast_+1);
-                    oo_.realtime_conditional_shock_decomposition.(['time_' int2str(j-my_forecast_)])(:,end,:) = ...
+                        ootmp.realtime_forecast_shock_decomposition.(['time_' int2str(j-my_forecast_)])(:,:,1:my_forecast_+1);
+                    ootmp.realtime_conditional_shock_decomposition.(['time_' int2str(j-my_forecast_)])(:,end-1,:) = ...
+                        ootmp.realtime_conditional_shock_decomposition.(['time_' int2str(j-my_forecast_)])(:,end-1,:) + ...
+                        ootmp.realtime_forecast_shock_decomposition.(['time_' int2str(j-my_forecast_)])(:,end,1:my_forecast_+1);
+                    ootmp.realtime_conditional_shock_decomposition.(['time_' int2str(j-my_forecast_)])(:,end,:) = ...
                         zreal(:,end,j-my_forecast_:j);
+                    if ismember(j-my_forecast_,save_realtime)
+                        oo_.realtime_conditional_shock_decomposition.(['time_' int2str(j-my_forecast_)]) = ...
+                            ootmp.realtime_conditional_shock_decomposition.(['time_' int2str(j-my_forecast_)]);
+                    end
                 end
             end
 
