@@ -23,7 +23,7 @@ function [oo_,M_] = shock_decomposition(M_,oo_,options_,varlist,bayestopt_,estim
 % SPECIAL REQUIREMENTS
 %    none
 
-% Copyright (C) 2009-2017 Dynare Team
+% Copyright (C) 2009-2019 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -41,12 +41,24 @@ function [oo_,M_] = shock_decomposition(M_,oo_,options_,varlist,bayestopt_,estim
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
 % indices of endogenous variables
-if size(varlist,1) == 0
-    varlist = M_.endo_names(1:M_.orig_endo_nbr,:);
+
+if isfield(oo_,'shock_decomposition_info') && isfield(oo_.shock_decomposition_info,'i_var')
+    if isfield (oo_,'realtime_conditional_shock_decomposition') ...
+            || isfield (oo_,'realtime_forecast_shock_decomposition') ...
+            || isfield (oo_,'realtime_shock_decomposition') ...
+            || isfield (oo_,'conditional_shock_decomposition') ...
+            || isfield (oo_,'initval_decomposition')
+        error('shock_decomposition::squeezed shock decompositions are already stored in oo_')
+    end
+end
+with_epilogue = options_.shock_decomp.with_epilogue;
+
+if isempty(varlist)
+    varlist = M_.endo_names(1:M_.orig_endo_nbr);
 end
 
-[i_var,nvar,index_uniques] = varlist_indices(varlist,M_.endo_names);
-varlist=varlist(index_uniques,:);
+[~, ~,index_uniques] = varlist_indices(varlist, M_.endo_names);
+varlist = varlist(index_uniques);
 
 % number of variables
 endo_nbr = M_.endo_nbr;
@@ -72,7 +84,7 @@ end
 
 options_.selected_variables_only = 0; %make sure all variables are stored
 options_.plot_priors=0;
-[oo_, M_, junk1, junk2, Smoothed_Variables_deviation_from_mean] = evaluate_smoother(parameter_set, varlist, M_, oo_, options_, bayestopt_, estim_params_);
+[oo_, M_, ~, ~, Smoothed_Variables_deviation_from_mean] = evaluate_smoother(parameter_set, varlist, M_, oo_, options_, bayestopt_, estim_params_);
 
 % reduced form
 dr = oo_.dr;
@@ -87,10 +99,10 @@ A = dr.ghx;
 B = dr.ghu;
 
 % initialization
-gend = size(oo_.SmoothedShocks.(deblank(M_.exo_names(1,:))),1);
+gend = size(oo_.SmoothedShocks.(M_.exo_names{1}),1);
 epsilon=NaN(nshocks,gend);
 for i=1:nshocks
-    epsilon(i,:) = oo_.SmoothedShocks.(deblank(M_.exo_names(i,:)));
+    epsilon(i,:) = oo_.SmoothedShocks.(M_.exo_names{i});
 end
 
 z = zeros(endo_nbr,nshocks+2,gend);
@@ -120,8 +132,12 @@ for i=1:gend
     z(:,nshocks+1,i) = z(:,nshocks+2,i) - sum(z(:,1:nshocks,i),2);
 end
 
+if with_epilogue
+    [z, oo_.shock_decomposition_info.epilogue_steady_state] = epilogue_shock_decomposition(z, M_, oo_);
+end
+
 oo_.shock_decomposition = z;
 
 if ~options_.no_graph.shock_decomposition
-    plot_shock_decomposition(M_,oo_,options_,varlist);
-end
\ No newline at end of file
+    oo_ = plot_shock_decomposition(M_,oo_,options_,varlist);
+end
