@@ -1,6 +1,6 @@
-function info=stoch_simul(var_list)
+function [info, oo_, options_] = stoch_simul(M_, options_, oo_, var_list)
 
-% Copyright (C) 2001-2017 Dynare Team
+% Copyright (C) 2001-2020 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -17,13 +17,15 @@ function info=stoch_simul(var_list)
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
-global M_ options_ oo_ it_
-
 % Test if the order of approximation is nonzero (the preprocessor tests if order is non negative).
 if isequal(options_.order,0)
     error('stoch_simul:: The order of the Taylor approximation cannot be 0!')
 end
 
+if M_.exo_nbr==0
+    error('stoch_simul:: does not support having no varexo in the model. As a workaround you could define a dummy exogenous variable.')
+end
+
 test_for_deep_parameters_calibration(M_);
 
 dr = oo_.dr;
@@ -36,7 +38,7 @@ if options_.order == 1
     options_.replic = 1;
 end
 
-if M_.hessian_eq_zero && options_.order~=1
+if options_.order~=1 && M_.hessian_eq_zero
     options_.order = 1;
     warning('stoch_simul: using order = 1 because Hessian is equal to zero');
 end
@@ -45,7 +47,7 @@ if isempty(options_.qz_criterium)
     options_.qz_criterium = 1+1e-6;
 end
 
-if options_.partial_information == 1 || options_.ACES_solver == 1
+if options_.partial_information || options_.ACES_solver
     PI_PCL_solver = 1;
     if options_.order ~= 1
         warning('stoch_simul:: forcing order=1 since you are using partial_information or ACES solver')
@@ -57,12 +59,13 @@ end
 
 TeX = options_.TeX;
 
-if size(var_list,1) == 0
-    var_list = M_.endo_names(1:M_.orig_endo_nbr, :);
+if isempty(var_list)
+    var_list = M_.endo_names(1:M_.orig_endo_nbr);
 end
 
-[i_var,nvar,index_uniques] = varlist_indices(var_list,M_.endo_names);
-var_list=var_list(index_uniques,:);
+[i_var, nvar, index_uniques] = varlist_indices(var_list, M_.endo_names);
+var_list=var_list(index_uniques);
+oo_.var_list = var_list;
 
 iter_ = max(options_.periods,1);
 if M_.exo_nbr > 0
@@ -79,14 +82,14 @@ elseif options_.discretionary_policy
     if ~options_.linear
         error('discretionary_policy: only linear-quadratic problems can be solved');
     end
-    [oo_.dr,ys,info] = discretionary_policy_1(oo_,options_.instruments);
+    [~,info,M_,options_,oo_] = discretionary_policy_1(options_.instruments,M_,options_,oo_);
 else
     if options_.logged_steady_state %if steady state was previously logged, undo this
         oo_.dr.ys=exp(oo_.dr.ys);
         oo_.steady_state=exp(oo_.steady_state);
         options_.logged_steady_state=0;
     end
-    [oo_.dr,info,M_,options_,oo_] = resol(0,M_,options_,oo_);
+    [~,info,M_,options_,oo_] = resol(0,M_,options_,oo_);
 end
 
 if options_.loglinear && isfield(oo_.dr,'ys') && options_.logged_steady_state==0 %log steady state for correct display of decision rule
@@ -111,15 +114,28 @@ if ~options_.noprint
     disp(['  Number of jumpers:           ' int2str(M_.nsfwrd)])
     disp(['  Number of static variables:  ' int2str(M_.nstatic)])
     my_title='MATRIX OF COVARIANCE OF EXOGENOUS SHOCKS';
-    labels = deblank(M_.exo_names);
-    headers = char('Variables',labels);
-    lh = size(labels,2)+2;
-    dyntable(options_,my_title,headers,labels,M_.Sigma_e,lh,10,6);
+    labels = M_.exo_names;
+    headers = vertcat('Variables', labels);
+    lh = cellofchararraymaxlength(labels)+2;
+    dyntable(options_, my_title, headers, labels, M_.Sigma_e, lh, 10, 6);
     if options_.TeX
-        labels = deblank(M_.exo_names_tex);
-        headers = char('Variables',labels);
-        lh = size(labels,2)+2;
-        dyn_latex_table(M_,options_,my_title,'covar_ex_shocks',headers,labels,M_.Sigma_e,lh,10,6);
+        labels = M_.exo_names_tex;
+        headers = vertcat('Variables', labels);
+        lh = cellofchararraymaxlength(labels)+2;
+        dyn_latex_table(M_, options_, my_title, 'covar_ex_shocks', headers, labels, M_.Sigma_e, lh, 10, 6);
+    end
+    if ~all(M_.H==0)
+        my_title='MATRIX OF COVARIANCE OF MEASUREMENT ERRORS';
+        labels = cellfun(@(x) horzcat('SE_', x), options_.varobs, 'UniformOutput', false);
+        headers = vertcat('Variables', labels);
+        lh = cellofchararraymaxlength(labels)+2;
+        dyntable(options_, my_title, headers, labels, M_.H, lh, 10, 6);
+        if options_.TeX
+            labels = M_.exo_names_tex;
+            headers = vertcat('Variables', labels);
+            lh = cellofchararraymaxlength(labels)+2;
+            dyn_latex_table(M_, options_, my_title, 'covar_ME', headers, labels, M_.H, lh, 10, 6);
+        end
     end
     if options_.partial_information
         skipline()
@@ -127,15 +143,15 @@ if ~options_.noprint
         skipline()
 
         if isfield(options_,'varobs')&& ~isempty(options_.varobs)
-            PCL_varobs=char(options_.varobs);
+            PCL_varobs = options_.varobs;
             disp('OBSERVED VARIABLES')
         else
-            PCL_varobs=M_.endo_names;
+            PCL_varobs = M_.endo_names;
             disp(' VAROBS LIST NOT SPECIFIED')
             disp(' ASSUMED OBSERVED VARIABLES')
         end
-        for i=1:size(PCL_varobs,1)
-            disp(['    ' PCL_varobs(i,:)])
+        for i=1:length(PCL_varobs)
+            disp(['    ' PCL_varobs{i}])
         end
     end
     skipline()
@@ -165,13 +181,13 @@ if options_.periods > 0 && ~PI_PCL_solver
     [ys, oo_] = simult(y0,oo_.dr,M_,options_,oo_);
     oo_.endo_simul = ys;
     if ~options_.minimal_workspace
-        dyn2vec;
+        dyn2vec(M_, oo_, options_);
     end
 end
 
-if options_.nomoments == 0
+if ~options_.nomoments
     if PI_PCL_solver
-        PCL_Part_info_moments (0, PCL_varobs, oo_.dr, i_var);
+        PCL_Part_info_moments(0, PCL_varobs, oo_.dr, i_var);
     elseif options_.periods == 0
         % There is no code for theoretical moments at 3rd order
         if options_.order <= 2
@@ -184,19 +200,23 @@ end
 
 
 if options_.irf
-    var_listTeX = M_.endo_names_tex(i_var,:);
-
+    var_listTeX = M_.endo_names_tex(i_var);
+    if ~options_.nograph
+        if ~exist([M_.fname '/graphs'],'dir')
+            mkdir(M_.fname,'graphs');
+        end
+    end
     if TeX && any(strcmp('eps',cellstr(options_.graph_format)))
-        fidTeX = fopen([M_.fname '_IRF.tex'],'w');
+        fidTeX = fopen([M_.fname, '/graphs/' M_.fname '_IRF.tex'],'w');
         fprintf(fidTeX,'%% TeX eps-loader file generated by stoch_simul.m (Dynare).\n');
         fprintf(fidTeX,['%% ' datestr(now,0) '\n']);
         fprintf(fidTeX,' \n');
     end
     SS(M_.exo_names_orig_ord,M_.exo_names_orig_ord)=M_.Sigma_e+1e-14*eye(M_.exo_nbr);
     cs = transpose(chol(SS));
-    tit(M_.exo_names_orig_ord,:) = M_.exo_names;
+    tit(M_.exo_names_orig_ord) = M_.exo_names;
     if TeX
-        titTeX(M_.exo_names_orig_ord,:) = M_.exo_names_tex;
+        titTeX(M_.exo_names_orig_ord) = M_.exo_names_tex;
     end
     irf_shocks_indx = getIrfShocksIndx();
     for i=irf_shocks_indx
@@ -205,15 +225,15 @@ if options_.irf
                 y=PCL_Part_info_irf (0, PCL_varobs, i_var, M_, oo_.dr, options_.irf, i);
             else
                 if options_.order>1 && options_.relative_irf % normalize shock to 0.01 before IRF generation for GIRFs; multiply with 100 later
-                    y=irf(oo_.dr,cs(M_.exo_names_orig_ord,i)./cs(i,i)/100, options_.irf, options_.drop, ...
+                    y=irf(M_, options_, oo_.dr,cs(M_.exo_names_orig_ord,i)./cs(i,i)/100, options_.irf, options_.drop, ...
                           options_.replic, options_.order);
                 else %for linear model, rescaling is done later
-                    y=irf(oo_.dr,cs(M_.exo_names_orig_ord,i), options_.irf, options_.drop, ...
+                    y=irf(M_, options_, oo_.dr,cs(M_.exo_names_orig_ord,i), options_.irf, options_.drop, ...
                           options_.replic, options_.order);
                 end
             end
             if ~options_.noprint && any(any(isnan(y))) && ~options_.pruning && ~(options_.order==1)
-                fprintf('\nstoch_simul:: The simulations conducted for generating IRFs to %s were explosive.\n',M_.exo_names(i,:))
+                fprintf('\nstoch_simul:: The simulations conducted for generating IRFs to %s were explosive.\n', M_.exo_names{i})
                 fprintf('stoch_simul:: No IRFs will be displayed. Either reduce the shock size, \n')
                 fprintf('stoch_simul:: use pruning, or set the approximation order to 1.');
                 skipline(2);
@@ -229,41 +249,40 @@ if options_.irf
                 mylistTeX = [];
             end
             for j = 1:nvar
-                assignin('base',[deblank(M_.endo_names(i_var(j),:)) '_' deblank(M_.exo_names(i,:))],...
+                assignin('base',[M_.endo_names{i_var(j)} '_' M_.exo_names{i}],...
                          y(i_var(j),:)');
-                eval(['oo_.irfs.' deblank(M_.endo_names(i_var(j),:)) '_' ...
-                      deblank(M_.exo_names(i,:)) ' = y(i_var(j),:);']);
+                oo_.irfs.([M_.endo_names{i_var(j)} '_' M_.exo_names{i}]) = y(i_var(j),:);
                 if max(abs(y(i_var(j),:))) >= options_.impulse_responses.plot_threshold
                     irfs  = cat(1,irfs,y(i_var(j),:));
                     if isempty(mylist)
-                        mylist = deblank(var_list(j,:));
+                        mylist = var_list{j};
                     else
-                        mylist = char(mylist,deblank(var_list(j,:)));
+                        mylist = char(mylist, var_list{j});
                     end
                     if TeX
                         if isempty(mylistTeX)
-                            mylistTeX = deblank(var_listTeX(j,:));
+                            mylistTeX = var_listTeX{j};
                         else
-                            mylistTeX = char(mylistTeX,deblank(var_listTeX(j,:)));
+                            mylistTeX = char(mylistTeX, var_listTeX{j});
                         end
                     end
                 else
                     if options_.debug
-                        fprintf('stoch_simul:: The IRF of %s to %s is smaller than the irf_plot_threshold of %4.3f and will not be displayed.\n',deblank(M_.endo_names(i_var(j),:)),deblank(M_.exo_names(i,:)),options_.impulse_responses.plot_threshold)
+                        fprintf('stoch_simul:: The IRF of %s to %s is smaller than the irf_plot_threshold of %4.3f and will not be displayed.\n',M_.endo_names{i_var(j)},M_.exo_names{i},options_.impulse_responses.plot_threshold)
                     end
                 end
             end
-            if options_.nograph == 0
+            if ~options_.nograph
                 number_of_plots_to_draw = size(irfs,1);
                 [nbplt,nr,nc,lr,lc,nstar] = pltorg(number_of_plots_to_draw);
                 if nbplt == 0
                 elseif nbplt == 1
                     if options_.relative_irf
                         hh = dyn_figure(options_.nodisplay,'Name',['Relative response to' ...
-                                            ' orthogonalized shock to ' tit(i,:)]);
+                                            ' orthogonalized shock to ' tit{i}]);
                     else
                         hh = dyn_figure(options_.nodisplay,'Name',['Orthogonalized shock to' ...
-                                            ' ' tit(i,:)]);
+                                            ' ' tit{i}]);
                     end
                     for j = 1:number_of_plots_to_draw
                         subplot(nr,nc,j);
@@ -275,16 +294,16 @@ if options_.irf
                         remove_fractional_xticks;
                         title(deblank(mylist(j,:)),'Interpreter','none');
                     end
-                    dyn_saveas(hh,[M_.fname '_IRF_' deblank(tit(i,:))],options_.nodisplay,options_.graph_format);
+                    dyn_saveas(hh,[M_.fname, '/graphs/' M_.fname '_IRF_' tit{i}],options_.nodisplay,options_.graph_format);
                     if TeX && any(strcmp('eps',cellstr(options_.graph_format)))
                         fprintf(fidTeX,'\\begin{figure}[H]\n');
                         for j = 1:number_of_plots_to_draw
-                            fprintf(fidTeX,['\\psfrag{%s}[1][][0.5][0]{$%s$}\n'],deblank(mylist(j,:)),deblank(mylistTeX(j,:)));
+                            fprintf(fidTeX,'\\psfrag{%s}[1][][0.5][0]{$%s$}\n',deblank(mylist(j,:)),deblank(mylistTeX(j,:)));
                         end
                         fprintf(fidTeX,'\\centering \n');
-                        fprintf(fidTeX,'\\includegraphics[width=%2.2f\\textwidth]{%s_IRF_%s}\n',options_.figures.textwidth*min(j/nc,1),M_.fname,deblank(tit(i,:)));
-                        fprintf(fidTeX,'\\caption{Impulse response functions (orthogonalized shock to $%s$).}\n',titTeX(i,:));
-                        fprintf(fidTeX,'\\label{Fig:IRF:%s}\n',deblank(tit(i,:)));
+                        fprintf(fidTeX,'\\includegraphics[width=%2.2f\\textwidth]{%s_IRF_%s}\n',options_.figures.textwidth*min(j/nc,1),[M_.fname, '/graphs/' M_.fname],tit{i});
+                        fprintf(fidTeX,'\\caption{Impulse response functions (orthogonalized shock to $%s$).}\n',titTeX{i});
+                        fprintf(fidTeX,'\\label{Fig:IRF:%s}\n', tit{i});
                         fprintf(fidTeX,'\\end{figure}\n');
                         fprintf(fidTeX,' \n');
                     end
@@ -292,9 +311,9 @@ if options_.irf
                     for fig = 1:nbplt-1
                         if options_.relative_irf
                             hh = dyn_figure(options_.nodisplay,'Name',['Relative response to orthogonalized shock' ...
-                                                ' to ' tit(i,:) ' figure ' int2str(fig)]);
+                                                ' to ' tit{i} ' figure ' int2str(fig)]);
                         else
-                            hh = dyn_figure(options_.nodisplay,'Name',['Orthogonalized shock to ' tit(i,:) ...
+                            hh = dyn_figure(options_.nodisplay,'Name',['Orthogonalized shock to ' tit{i} ...
                                                 ' figure ' int2str(fig)]);
                         end
                         for plt = 1:nstar
@@ -307,27 +326,25 @@ if options_.irf
                             remove_fractional_xticks
                             title(deblank(mylist((fig-1)*nstar+plt,:)),'Interpreter','none');
                         end
-                        dyn_saveas(hh,[ M_.fname '_IRF_' deblank(tit(i,:)) int2str(fig)],options_.nodisplay,options_.graph_format);
+                        dyn_saveas(hh,[M_.fname, '/graphs/'  M_.fname '_IRF_' tit{i} int2str(fig)],options_.nodisplay,options_.graph_format);
                         if TeX && any(strcmp('eps',cellstr(options_.graph_format)))
                             fprintf(fidTeX,'\\begin{figure}[H]\n');
                             for j = 1:nstar
-                                fprintf(fidTeX,['\\psfrag{%s}[1][][0.5][0]{$%s$}\n'],deblank(mylist((fig-1)*nstar+j,:)),deblank(mylistTeX((fig-1)*nstar+j,:)));
+                                fprintf(fidTeX,'\\psfrag{%s}[1][][0.5][0]{$%s$}\n',deblank(mylist((fig-1)*nstar+j,:)),deblank(mylistTeX((fig-1)*nstar+j,:)));
                             end
                             fprintf(fidTeX,'\\centering \n');
-                            fprintf(fidTeX,'\\includegraphics[width=%2.2f\\textwidth]{%s_IRF_%s%s}\n',options_.figures.textwidth*min(plt/nc,1),M_.fname,deblank(tit(i,:)),int2str(fig));
+                            fprintf(fidTeX,'\\includegraphics[width=%2.2f\\textwidth]{%s_IRF_%s%s}\n',options_.figures.textwidth*min(plt/nc,1),[M_.fname, '/graphs/' M_.fname],tit{i},int2str(fig));
                             if options_.relative_irf
-                                fprintf(fidTeX,['\\caption{Relative impulse response' ...
-                                                ' functions (orthogonalized shock to $%s$).}'],deblank(titTeX(i,:)));
+                                fprintf(fidTeX,'\\caption{Relative impulse response functions (orthogonalized shock to $%s$).}', titTeX{i});
                             else
-                                fprintf(fidTeX,['\\caption{Impulse response functions' ...
-                                                ' (orthogonalized shock to $%s$).}'],deblank(titTeX(i,:)));
+                                fprintf(fidTeX,'\\caption{Impulse response functions (orthogonalized shock to $%s$).}', titTeX{i});
                             end
-                            fprintf(fidTeX,'\\label{Fig:IRF:%s:%s}\n',deblank(tit(i,:)),int2str(fig));
+                            fprintf(fidTeX,'\\label{Fig:IRF:%s:%s}\n', tit{i},int2str(fig));
                             fprintf(fidTeX,'\\end{figure}\n');
                             fprintf(fidTeX,' \n');
                         end
                     end
-                    hh = dyn_figure(options_.nodisplay,'Name',['Orthogonalized shock to ' tit(i,:) ' figure ' int2str(nbplt) '.']);
+                    hh = dyn_figure(options_.nodisplay,'Name',['Orthogonalized shock to ' tit{i} ' figure ' int2str(nbplt) '.']);
                     m = 0;
                     for plt = 1:number_of_plots_to_draw-(nbplt-1)*nstar
                         m = m+1;
@@ -340,22 +357,20 @@ if options_.irf
                         remove_fractional_xticks
                         title(deblank(mylist((nbplt-1)*nstar+plt,:)),'Interpreter','none');
                     end
-                    dyn_saveas(hh,[ M_.fname '_IRF_' deblank(tit(i,:)) int2str(nbplt) ],options_.nodisplay,options_.graph_format);
+                    dyn_saveas(hh,[M_.fname, '/graphs/' M_.fname '_IRF_' tit{i} int2str(nbplt) ],options_.nodisplay,options_.graph_format);
                     if TeX && any(strcmp('eps',cellstr(options_.graph_format)))
                         fprintf(fidTeX,'\\begin{figure}[H]\n');
                         for j = 1:m
-                            fprintf(fidTeX,['\\psfrag{%s}[1][][0.5][0]{$%s$}\n'],deblank(mylist((nbplt-1)*nstar+j,:)),deblank(mylistTeX((nbplt-1)*nstar+j,:)));
+                            fprintf(fidTeX,'\\psfrag{%s}[1][][0.5][0]{$%s$}\n',deblank(mylist((nbplt-1)*nstar+j,:)),deblank(mylistTeX((nbplt-1)*nstar+j,:)));
                         end
                         fprintf(fidTeX,'\\centering \n');
-                        fprintf(fidTeX,'\\includegraphics[width=%2.2f\\textwidth]{%s_IRF_%s%s}\n',options_.figures.textwidth*min(m/lc,1),M_.fname,deblank(tit(i,:)),int2str(nbplt));
+                        fprintf(fidTeX,'\\includegraphics[width=%2.2f\\textwidth]{%s_IRF_%s%s}\n',options_.figures.textwidth*min(m/lc,1),[M_.fname, '/graphs/' M_.fname],tit{i},int2str(nbplt));
                         if options_.relative_irf
-                            fprintf(fidTeX,['\\caption{Relative impulse response functions' ...
-                                            ' (orthogonalized shock to $%s$).}'],deblank(titTeX(i,:)));
+                            fprintf(fidTeX,'\\caption{Relative impulse response functions (orthogonalized shock to $%s$).}', titTeX{i});
                         else
-                            fprintf(fidTeX,['\\caption{Impulse response functions' ...
-                                            ' (orthogonalized shock to $%s$).}'],deblank(titTeX(i,:)));
+                            fprintf(fidTeX,'\\caption{Impulse response functions (orthogonalized shock to $%s$).}', titTeX{i});
                         end
-                        fprintf(fidTeX,'\\label{Fig:IRF:%s:%s}\n',deblank(tit(i,:)),int2str(nbplt));
+                        fprintf(fidTeX,'\\label{Fig:IRF:%s:%s}\n', tit{i},int2str(nbplt));
                         fprintf(fidTeX,'\\end{figure}\n');
                         fprintf(fidTeX,' \n');
                     end
@@ -370,7 +385,7 @@ if options_.irf
     end
 end
 
-if options_.SpectralDensity.trigger == 1
+if options_.SpectralDensity.trigger
     [oo_] = UnivariateSpectralDensity(M_,oo_,options_,var_list);
 end
 
