@@ -1,35 +1,30 @@
-function [dr,info] = stochastic_solvers(dr,task,M_,options_,oo_)
-% function [dr,info,M_,options_,oo_] = stochastic_solvers(dr,task,M_,options_,oo_)
-% computes the reduced form solution of a rational expectations model (first, second or third
+function [dr, info] = stochastic_solvers(dr, task, M_, options_, oo_)
+
+% Computes the reduced form solution of a rational expectations model (first, second or third
 % order approximation of the stochastic model around the deterministic steady state).
 %
 % INPUTS
-%   dr         [matlab structure] Decision rules for stochastic simulations.
-%   task       [integer]          if task = 0 then dr1 computes decision rules.
-%                                 if task = 1 then dr1 computes eigenvalues.
-%   M_         [matlab structure] Definition of the model.
-%   options_   [matlab structure] Global options.
-%   oo_        [matlab structure] Results
+% - dr         [struct]     Decision rules for stochastic simulations.
+% - task       [integer]    scalar, if task = 0 then decision rules are computed and if task = 1 then only eigenvales are computed.
+% - M_         [struct]     Definition of the model.
+% - options_   [struct]     Options.
+% - oo_        [struct]     Results
 %
 % OUTPUTS
-%   dr         [matlab structure] Decision rules for stochastic simulations.
-%   info       [integer]          info=1: the model doesn't define current variables uniquely
-%                                 info=2: problem in mjdgges.dll info(2) contains error code.
-%                                 info=3: BK order condition not satisfied info(2) contains "distance"
-%                                         absence of stable trajectory.
-%                                 info=4: BK order condition not satisfied info(2) contains "distance"
-%                                         indeterminacy.
-%                                 info=5: BK rank condition not satisfied.
-%                                 info=6: The jacobian matrix evaluated at the steady state is complex.
-%                                 info=9: k_order_pert was unable to compute the solution
-% ALGORITHM
-%   ...
-%
-% SPECIAL REQUIREMENTS
-%   none.
+% - dr         [struct]     Decision rules for stochastic simulations.
+% - info       [integer]    scalar, error code:
 %
+%                                 info=1 -> the model doesn't define current variables uniquely
+%                                 info=2 -> problem in mjdgges.dll info(2) contains error code.
+%                                 info=3 -> BK order condition not satisfied info(2) contains "distance"
+%                                           absence of stable trajectory.
+%                                 info=4 -> BK order condition not satisfied info(2) contains "distance"
+%                                           indeterminacy.
+%                                 info=5 -> BK rank condition not satisfied.
+%                                 info=6 -> The jacobian matrix evaluated at the steady state is complex.
+%                                 info=9 -> k_order_pert was unable to compute the solution
 
-% Copyright (C) 1996-2018 Dynare Team
+% Copyright (C) 1996-2019 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -53,7 +48,7 @@ if options_.linear
 end
 
 local_order = options_.order;
-if M_.hessian_eq_zero && local_order~=1
+if local_order~=1 && M_.hessian_eq_zero
     local_order = 1;
     warning('stochastic_solvers: using order = 1 because Hessian is equal to zero');
 end
@@ -61,7 +56,7 @@ if options_.order>2 && ~options_.k_order_solver
     error('You need to set k_order_solver for order>2')
 end
 
-if (options_.aim_solver == 1) && (local_order > 1)
+if options_.aim_solver && (local_order > 1)
     error('Option "aim_solver" is incompatible with order >= 2')
 end
 
@@ -107,7 +102,6 @@ exo_simul = [repmat(oo_.exo_steady_state',klen,1) repmat(oo_.exo_det_steady_stat
 iyv = M_.lead_lag_incidence';
 iyv = iyv(:);
 iyr0 = find(iyv) ;
-it_ = M_.maximum_lag + 1 ;
 
 if M_.exo_nbr == 0
     oo_.exo_steady_state = [] ;
@@ -117,22 +111,22 @@ it_ = M_.maximum_lag + 1;
 z = repmat(dr.ys,1,klen);
 if local_order == 1
     if (options_.bytecode)
-        [chck, junk, loc_dr] = bytecode('dynamic','evaluate', z,exo_simul, ...
-                                        M_.params, dr.ys, 1);
+        [chck, ~, loc_dr] = bytecode('dynamic','evaluate', z,exo_simul, ...
+                                     M_.params, dr.ys, 1);
         jacobia_ = [loc_dr.g1 loc_dr.g1_x loc_dr.g1_xd];
     else
-        [junk,jacobia_] = feval([M_.fname '_dynamic'],z(iyr0),exo_simul, ...
-                                M_.params, dr.ys, it_);
+        [~,jacobia_] = feval([M_.fname '.dynamic'],z(iyr0),exo_simul, ...
+                             M_.params, dr.ys, it_);
     end
 elseif local_order == 2
     if (options_.bytecode)
-        [chck, junk, loc_dr] = bytecode('dynamic','evaluate', z,exo_simul, ...
-                                        M_.params, dr.ys, 1);
+        [chck, ~, loc_dr] = bytecode('dynamic','evaluate', z,exo_simul, ...
+                                     M_.params, dr.ys, 1);
         jacobia_ = [loc_dr.g1 loc_dr.g1_x];
     else
-        [junk,jacobia_,hessian1] = feval([M_.fname '_dynamic'],z(iyr0),...
-                                         exo_simul, ...
-                                         M_.params, dr.ys, it_);
+        [~,jacobia_,hessian1] = feval([M_.fname '.dynamic'],z(iyr0),...
+                                      exo_simul, ...
+                                      M_.params, dr.ys, it_);
     end
     if options_.use_dll
         % In USE_DLL mode, the hessian is in the 3-column sparse representation
@@ -223,25 +217,26 @@ nz = nnz(M_.lead_lag_incidence);
 
 sdyn = M_.endo_nbr - nstatic;
 
-[junk,cols_b,cols_j] = find(M_.lead_lag_incidence(M_.maximum_endo_lag+1, ...
-                                                  order_var));
+[~,cols_b,cols_j] = find(M_.lead_lag_incidence(M_.maximum_endo_lag+1, ...
+                                               order_var));
 b = zeros(M_.endo_nbr,M_.endo_nbr);
 b(:,cols_b) = jacobia_(:,cols_j);
 
 if M_.maximum_endo_lead == 0
     % backward models: simplified code exist only at order == 1
     if local_order == 1
-        [k1,junk,k2] = find(kstate(:,4));
+        [k1,~,k2] = find(kstate(:,4));
         dr.ghx(:,k1) = -b\jacobia_(:,k2);
         if M_.exo_nbr
             dr.ghu =  -b\jacobia_(:,nz+1:end);
         end
         dr.eigval = eig(kalman_transition_matrix(dr,nstatic+(1:nspred),1:nspred,M_.exo_nbr));
         dr.full_rank = 1;
-        if any(abs(dr.eigval) > options_.qz_criterium)
+        dr.edim = nnz(abs(dr.eigval) > options_.qz_criterium);
+        dr.sdim = nd-dr.edim;
+        if dr.edim
             temp = sort(abs(dr.eigval));
-            nba = nnz(abs(dr.eigval) > options_.qz_criterium);
-            temp = temp(nd-nba+1:nd)-1-options_.qz_criterium;
+            temp = temp(dr.sdim+1:nd)-1-options_.qz_criterium;
             info(1) = 3;
             info(2) = temp'*temp;
         end
@@ -260,7 +255,7 @@ elseif options_.risky_steadystate
     options_.order = orig_order;
 else
     % If required, use AIM solver if not check only
-    if (options_.aim_solver == 1) && (task == 0)
+    if options_.aim_solver && (task == 0)
         [dr,info] = AIM_first_order_solver(jacobia_,M_,dr,options_.qz_criterium);
 
     else  % use original Dynare solver
@@ -273,7 +268,6 @@ else
     if local_order > 1
         % Second order
         dr = dyn_second_order_solver(jacobia_,hessian1,dr,M_,...
-                                     options_.threads.kronecker.A_times_B_kronecker_C,...
                                      options_.threads.kronecker.sparse_hessian_times_B_kronecker_C);
 
         % reordering second order derivatives, used for deterministic
