@@ -1,7 +1,8 @@
-function [hasPackage] = user_has_octave_forge_package(package)
+function [hasPackage] = user_has_octave_forge_package(package, min_version)
 % Checks for the availability of a given Octave Forge package
+% Optionally, a minimal version can be required for the package
 
-% Copyright (C) 2012 Dynare Team
+% Copyright (C) 2012-2019 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -18,13 +19,19 @@ function [hasPackage] = user_has_octave_forge_package(package)
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
-[desc,flag] = pkg('describe', package);
+[desc,flag] = pkg("describe", package);
 
-if isequal(flag{1,1}, 'Not installed')
+if isequal(flag{1,1}, "Not installed")
     hasPackage = 0;
 else
-    if isequal(flag{1,1}, 'Not loaded')
-        pkg('load', package);
-    end
-    hasPackage = 1;
-end
+    if isequal(flag{1,1}, "Not loaded")
+        pkg("load", package);
+    endif
+    if nargin > 1 && compare_versions(desc{1,1}.version, min_version, "<")
+        hasPackage = 0;
+    else
+        hasPackage = 1;
+    endif
+endif
+endfunction
+
