@@ -34,11 +34,7 @@ warning('on', 'backtrace');
 
 if isoctave
     warning('off', 'Octave:separator-insert');
-    if octave_ver_less_than('4.0')
-        warning('off', 'Octave:matlab-incompatible');
-    else
-        warning('off', 'Octave:language-extension');
-    end
+    warning('off', 'Octave:language-extension');
     warning('off', 'Octave:single-quote-string');
     warning('off', 'Octave:missing-semicolon');
     warning('off', 'Octave:empty-list-elements');
@@ -51,6 +47,7 @@ if isoctave
     warning('off', 'Octave:variable-switch-label');
     warning('off', 'Octave:fortran-indexing');
     warning('off', 'Octave:classdef-to-struct');
+    warning('off', 'Octave:legacy-function'); % For strmatch and isdir
 else
     % In MATLAB >= 7.7, don't display a warning if we use deprecated
     % interface to set seed of random number generators
