@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007-2017 Dynare Team
+ * Copyright © 2007-2019 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -16,16 +16,13 @@
  * You should have received a copy of the GNU General Public License
  * along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
  */
-#include <cstring>
+
 #include <cmath>
-#include <iostream>
-#include <fstream>
-#include <vector>
-#ifdef USE_OMP
-# include <omp.h>
-#endif
-#include "block_kalman_filter.h"
-using namespace std;
+#include <algorithm>
+#include <omp.h>
+
+#include "block_kalman_filter.hh"
+
 #define BLAS
 //#define CUBLAS
 
@@ -33,17 +30,18 @@ using namespace std;
 # include <cuda_runtime.h>
 # include <cublas_v2.h>
 #endif
+
 void
-mexDisp(mxArray *P)
+mexDisp(const mxArray *P)
 {
-  unsigned int n = mxGetN(P);
-  unsigned int m = mxGetM(P);
-  double *M = mxGetPr(P);
+  size_t n = mxGetN(P);
+  size_t m = mxGetM(P);
+  const double *M = mxGetPr(P);
   mexPrintf("%d x %d\n", m, n);
   mexEvalString("drawnow;");
-  for (unsigned int i = 0; i < m; i++)
+  for (size_t i = 0; i < m; i++)
     {
-      for (unsigned int j = 0; j < n; j++)
+      for (size_t j = 0; j < n; j++)
         mexPrintf(" %9.4f", M[i+ j * m]);
       mexPrintf("\n");
     }
@@ -51,7 +49,7 @@ mexDisp(mxArray *P)
 }
 
 void
-mexDisp(double *M, int m, int n)
+mexDisp(const double *M, int m, int n)
 {
   mexPrintf("%d x %d\n", m, n);
   mexEvalString("drawnow;");
@@ -63,6 +61,7 @@ mexDisp(double *M, int m, int n)
     }
   mexEvalString("drawnow;");
 }
+
 /*if block
   %nz_state_var = M_.nz_state_var;
   while notsteady && t<smpl
@@ -118,13 +117,12 @@ mexDisp(double *M, int m, int n)
 */
 
 bool
-not_all_abs_F_bellow_crit(double *F, int size, double crit)
+not_all_abs_F_bellow_crit(const double *F, int size, double crit)
 {
   int i = 0;
   while (i < size && abs(F[i]) < crit)
-    {
-      i++;
-    }
+    i++;
+
   if (i < size)
     return false;
   else
@@ -132,7 +130,7 @@ not_all_abs_F_bellow_crit(double *F, int size, double crit)
 }
 
 double
-det(double *F, int dim, lapack_int *ipiv)
+det(const double *F, int dim, const lapack_int *ipiv)
 {
   double det = 1.0;
   for (int i = 0; i < dim; i++)
@@ -143,7 +141,7 @@ det(double *F, int dim, lapack_int *ipiv)
   return det;
 }
 
-BlockKalmanFilter::BlockKalmanFilter(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[], double *P_mf[], double *v_pp[], double *K[], double *v_n[], double *a[], double *K_P[], double *P_t_t1[], double *tmp[], double *P[])
+BlockKalmanFilter::BlockKalmanFilter(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
 {
   if (nlhs > 3)
     DYN_MEX_FUNC_ERR_MSG_TXT("block_kalman_filter provides at most 3 output argument.");
@@ -171,10 +169,10 @@ BlockKalmanFilter::BlockKalmanFilter(int nlhs, mxArray *plhs[], int nrhs, const
       pP = mxDuplicateArray(prhs[7]);
       pY = mxDuplicateArray(prhs[8]);
       start = mxGetScalar(prhs[9]);
-      mfd = (double *) mxGetData(prhs[10]);
+      mfd = mxGetPr(prhs[10]);
       kalman_tol = mxGetScalar(prhs[11]);
       riccati_tol = mxGetScalar(prhs[12]);
-      nz_state_var = (double *) mxGetData(prhs[13]);
+      nz_state_var = mxGetPr(prhs[13]);
       n_diag = mxGetScalar(prhs[14]);
       pure_obs = mxGetScalar(prhs[15]);
     }
@@ -189,13 +187,13 @@ BlockKalmanFilter::BlockKalmanFilter(int nlhs, mxArray *plhs[], int nrhs, const
       pY = mxDuplicateArray(prhs[5]);
       start = mxGetScalar(prhs[6]);
       /*Defining the initials values*/
-      n   = mxGetN(pT);           // Number of state variables.
-      pp   = mxGetM(pY);          // Maximum number of observed variables.
-      smpl = mxGetN(pY);          // Sample size.          ;
-      mfd = (double *) mxGetData(prhs[7]);
+      n = mxGetN(pT); // Number of state variables.
+      pp = mxGetM(pY); // Maximum number of observed variables.
+      smpl = mxGetN(pY); // Sample size.          ;
+      mfd = mxGetPr(prhs[7]);
       kalman_tol = mxGetScalar(prhs[8]);
       riccati_tol = mxGetScalar(prhs[9]);
-      nz_state_var = (double *) mxGetData(prhs[10]);
+      nz_state_var = mxGetPr(prhs[10]);
       n_diag = mxGetScalar(prhs[11]);
       pure_obs = mxGetScalar(prhs[12]);
     }
@@ -203,12 +201,12 @@ BlockKalmanFilter::BlockKalmanFilter(int nlhs, mxArray *plhs[], int nrhs, const
   R = mxGetPr(pR);
   Q = mxGetPr(pQ);
   H = mxGetPr(pH);
-  *P = mxGetPr(pP);
+  P = mxGetPr(pP);
   Y = mxGetPr(pY);
 
-  n   = mxGetN(pT);           // Number of state variables.
-  pp   = mxGetM(pY);          // Maximum number of observed variables.
-  smpl = mxGetN(pY);          // Sample size.          ;
+  n = mxGetN(pT); // Number of state variables.
+  pp = mxGetM(pY); // Maximum number of observed variables.
+  smpl = mxGetN(pY); // Sample size.          ;
   n_state = n - pure_obs;
 
   /*mexPrintf("T\n");
@@ -219,35 +217,34 @@ BlockKalmanFilter::BlockKalmanFilter(int nlhs, mxArray *plhs[], int nrhs, const
   n_shocks = mxGetM(pQ);
 
   if (missing_observations)
-    if (mxGetNumberOfElements(pdata_index) != (unsigned int) smpl)
+    if (mxGetNumberOfElements(pdata_index) != static_cast<unsigned int>(smpl))
       DYN_MEX_FUNC_ERR_MSG_TXT("the number of element in the cell array passed to block_missing_observation_kalman_filter as first argument has to be equal to the smpl size");
 
-  i_nz_state_var = (int *) mxMalloc(n*sizeof(int));
+  i_nz_state_var = std::make_unique<int[]>(n);
   for (int i = 0; i < n; i++)
     i_nz_state_var[i] = nz_state_var[i];
 
-  pa = mxCreateDoubleMatrix(n, 1, mxREAL);         // State vector.
-  *a = mxGetPr(pa);
-  tmp_a = (double *) mxMalloc(n * sizeof(double));
-  dF = 0.0;                                            // det(F).
+  pa = mxCreateDoubleMatrix(n, 1, mxREAL); // State vector.
+  a = mxGetPr(pa);
+  tmp_a = std::make_unique<double[]>(n);
+  dF = 0.0; // det(F).
 
   p_tmp1 = mxCreateDoubleMatrix(n, n_shocks, mxREAL);
   tmp1 = mxGetPr(p_tmp1);
-  t = 0;                                               // Initialization of the time index.
-  plik  = mxCreateDoubleMatrix(smpl, 1, mxREAL);
+  t = 0; // Initialization of the time index.
+  plik = mxCreateDoubleMatrix(smpl, 1, mxREAL);
   lik = mxGetPr(plik);
-  Inf =  mxGetInf();
-  LIK  = 0.0;                                          // Default value of the log likelihood.
-  notsteady   = true;                                 // Steady state flag.
-  F_singular  = true;
-  *v_pp = (double *) mxMalloc(pp * sizeof(double));
-  *v_n = (double *) mxMalloc(n * sizeof(double));
-  mf = (int *) mxMalloc(pp * sizeof(int));
+  Inf = mxGetInf();
+  LIK = 0.0; // Default value of the log likelihood.
+  notsteady = true; // Steady state flag.
+  F_singular = true;
+  v_pp = std::make_unique<double[]>(pp);
+  v_n = std::make_unique<double[]>(n);
+  mf = std::make_unique<int[]>(pp);
   for (int i = 0; i < pp; i++)
     mf[i] = mfd[i] - 1;
-  pi = atan2((double) 0.0, (double) -1.0);
 
-  /*compute QQ = R*Q*transpose(R)*/                        // Variance of R times the vector of structural innovations.;
+  /*compute QQ = R*Q*transpose(R)*/ // Variance of R times the vector of structural innovations.;
   // tmp = R * Q;
   for (int i = 0; i < n; i++)
     for (int j = 0; j < n_shocks; j++)
@@ -273,143 +270,133 @@ BlockKalmanFilter::BlockKalmanFilter(int nlhs, mxArray *plhs[], int nrhs, const
 
   pv = mxCreateDoubleMatrix(pp, 1, mxREAL);
   v = mxGetPr(pv);
-  pF =  mxCreateDoubleMatrix(pp, pp, mxREAL);
+  pF = mxCreateDoubleMatrix(pp, pp, mxREAL);
   F = mxGetPr(pF);
-  piF =  mxCreateDoubleMatrix(pp, pp, mxREAL);
+  piF = mxCreateDoubleMatrix(pp, pp, mxREAL);
   iF = mxGetPr(piF);
   lw = pp * 4;
-  w = (double *) mxMalloc(lw * sizeof(double));
-  iw = (lapack_int *) mxMalloc(pp * sizeof(lapack_int));
-  ipiv = (lapack_int *) mxMalloc(pp * sizeof(lapack_int));
+  w = std::make_unique<double[]>(lw);
+  iw = std::make_unique<lapack_int[]>(pp);
+  ipiv = std::make_unique<lapack_int[]>(pp);
   info = 0;
 #if defined(BLAS) || defined(CUBLAS)
   p_tmp = mxCreateDoubleMatrix(n, n, mxREAL);
-  *tmp = mxGetPr(p_tmp);
+  tmp = mxGetPr(p_tmp);
   p_P_t_t1 = mxCreateDoubleMatrix(n, n, mxREAL);
-  *P_t_t1 = mxGetPr(p_P_t_t1);
+  P_t_t1 = mxGetPr(p_P_t_t1);
   pK = mxCreateDoubleMatrix(n, n, mxREAL);
-  *K = mxGetPr(pK);
+  K = mxGetPr(pK);
   p_K_P = mxCreateDoubleMatrix(n, n, mxREAL);
-  *K_P = mxGetPr(p_K_P);
-  oldK  = (double *) mxMalloc(n * n * sizeof(double));
-  *P_mf = (double *) mxMalloc(n * n * sizeof(double));
+  K_P = mxGetPr(p_K_P);
+  oldK = std::make_unique<double[]>(n * n);
+  P_mf = std::make_unique<double[]>(n * n);
   for (int i = 0; i < n  * n; i++)
     oldK[i] = Inf;
 #else
   p_tmp = mxCreateDoubleMatrix(n, n_state, mxREAL);
-  *tmp = mxGetPr(p_tmp);
+  tmp = mxGetPr(p_tmp);
   p_P_t_t1 = mxCreateDoubleMatrix(n_state, n_state, mxREAL);
-  *P_t_t1 = mxGetPr(p_P_t_t1);
+  P_t_t1 = mxGetPr(p_P_t_t1);
   pK = mxCreateDoubleMatrix(n, pp, mxREAL);
-  *K = mxGetPr(pK);
+  K = mxGetPr(pK);
   p_K_P = mxCreateDoubleMatrix(n_state, n_state, mxREAL);
-  *K_P = mxGetPr(p_K_P);
-  oldK  = (double *) mxMalloc(n * pp * sizeof(double));
-  *P_mf = (double *) mxMalloc(n * pp * sizeof(double));
+  K_P = mxGetPr(p_K_P);
+  oldK = std::make_unique<double[]>(n * pp);
+  P_mf = std::make_unique<double[]>(n * pp);
   for (int i = 0; i < n  * pp; i++)
     oldK[i] = Inf;
 #endif
 }
 
 void
-BlockKalmanFilter::block_kalman_filter_ss(double *P_mf, double *v_pp, double *K, double *v_n, double *a, double *K_P, double *P_t_t1, double *tmp, double *P)
+BlockKalmanFilter::block_kalman_filter_ss()
 {
   if (t+1 < smpl)
-    {
-      while (t < smpl)
-        {
-          //v = Y(:,t)-a(mf);
-          for (int i = 0; i < pp; i++)
-            v[i]  = Y[i + t * pp] - a[mf[i]];
+    while (t < smpl)
+      {
+        //v = Y(:,t)-a(mf);
+        for (int i = 0; i < pp; i++)
+          v[i] = Y[i + t * pp] - a[mf[i]];
 
-          //a = T*(a+K*v);
-          for (int i = pure_obs; i < n; i++)
-            {
-              double res = 0.0;
-              for (int j = 0; j < pp; j++)
-                res += K[j  * n + i] * v[j];
-              v_n[i] = res + a[i];
-            }
-          for (int i = 0; i < n; i++)
-            {
-              double res = 0.0;
-              for (int j = pure_obs; j < n; j++)
-                res += T[j  * n + i] * v_n[j];
-              a[i] = res;
-            }
+        //a = T*(a+K*v);
+        for (int i = pure_obs; i < n; i++)
+          {
+            double res = 0.0;
+            for (int j = 0; j < pp; j++)
+              res += K[j  * n + i] * v[j];
+            v_n[i] = res + a[i];
+          }
+        for (int i = 0; i < n; i++)
+          {
+            double res = 0.0;
+            for (int j = pure_obs; j < n; j++)
+              res += T[j  * n + i] * v_n[j];
+            a[i] = res;
+          }
 
-          //lik(t) = transpose(v)*iF*v;
-          for (int i = 0; i < pp; i++)
-            {
-              double res = 0.0;
-              for (int j = 0; j < pp; j++)
-                res += v[j] * iF[j * pp + i];
-              v_pp[i] = res;
-            }
-          double res = 0.0;
-          for (int i = 0; i < pp; i++)
-            res += v_pp[i] * v[i];
+        //lik(t) = transpose(v)*iF*v;
+        for (int i = 0; i < pp; i++)
+          {
+            double res = 0.0;
+            for (int j = 0; j < pp; j++)
+              res += v[j] * iF[j * pp + i];
+            v_pp[i] = res;
+          }
+        double res = 0.0;
+        for (int i = 0; i < pp; i++)
+          res += v_pp[i] * v[i];
 
-          lik[t] = (log(dF) + res + pp * log(2.0*pi))/2;
-          if (t + 1 > start)
-            LIK += lik[t];
+        lik[t] = (log(dF) + res + pp * log(2.0*M_PI))/2;
+        if (t + 1 > start)
+          LIK += lik[t];
 
-          t++;
-        }
-    }
+        t++;
+      }
 }
 
 bool
-BlockKalmanFilter::block_kalman_filter(int nlhs, mxArray *plhs[], double *P_mf, double *v_pp, double *K, double *v_n, double *a, double *K_P, double *P_t_t1, double *tmp, double *P)
+BlockKalmanFilter::block_kalman_filter(int nlhs, mxArray *plhs[])
 {
   while (notsteady && t < smpl)
     {
       if (missing_observations)
         {
-
           // retrieve the d_index
           pd_index = mxGetCell(pdata_index, t);
-          dd_index = (double *) mxGetData(pd_index);
+          dd_index = mxGetPr(pd_index);
           size_d_index = mxGetM(pd_index);
           d_index.resize(size_d_index);
           for (int i = 0; i < size_d_index; i++)
-            {
-              d_index[i] = ceil(dd_index[i]) - 1;
-            }
+            d_index[i] = ceil(dd_index[i]) - 1;
 
           //v = Y(:,t) - a(mf)
           int i_i = 0;
-          //#pragma omp parallel for shared(v, i_i, d_index) num_threads(atoi(getenv("DYNARE_NUM_THREADS")))
-          for (vector<int>::const_iterator i = d_index.begin(); i != d_index.end(); i++)
+          //#pragma omp parallel for shared(v, i_i, d_index)
+          for (auto i = d_index.begin(); i != d_index.end(); i++)
             {
               //mexPrintf("i_i=%d, omp_get_max_threads()=%d\n",i_i,omp_get_max_threads());
-              v[i_i]  = Y[*i + t * pp] - a[mf[*i]];
+              v[i_i] = Y[*i + t * pp] - a[mf[*i]];
               i_i++;
             }
 
           //F  = P(mf,mf) + H;
           i_i = 0;
           if (H_size == 1)
-            {
-              //#pragma omp parallel for shared(iF, F, i_i) num_threads(atoi(getenv("DYNARE_NUM_THREADS")))
-              for (vector<int>::const_iterator i = d_index.begin(); i != d_index.end(); i++, i_i++)
-                {
-                  int j_j = 0;
-                  for (vector<int>::const_iterator j = d_index.begin(); j != d_index.end(); j++, j_j++)
-                    iF[i_i + j_j * size_d_index] = F[i_i + j_j * size_d_index] = P[mf[*i] + mf[*j] * n] + H[0];
-                }
-            }
+            //#pragma omp parallel for shared(iF, F, i_i)
+            for (auto i = d_index.begin(); i != d_index.end(); i++, i_i++)
+              {
+                int j_j = 0;
+                for (auto j = d_index.begin(); j != d_index.end(); j++, j_j++)
+                  iF[i_i + j_j * size_d_index] = F[i_i + j_j * size_d_index] = P[mf[*i] + mf[*j] * n] + H[0];
+              }
           else
-            {
-              //#pragma omp parallel for shared(iF, F, P, H, mf, i_i) num_threads(atoi(getenv("DYNARE_NUM_THREADS")))
-              for (vector<int>::const_iterator i = d_index.begin(); i != d_index.end(); i++, i_i++)
-                {
-                  int j_j = 0;
-                  for (vector<int>::const_iterator j = d_index.begin(); j != d_index.end(); j++, j_j++)
-                    iF[i_i + j_j * size_d_index] = F[i_i + j_j * size_d_index] = P[mf[*i] + mf[*j] * n] + H[*i + *j * pp];
-                }
-            }
-
+            //#pragma omp parallel for shared(iF, F, P, H, mf, i_i)
+            for (auto i = d_index.begin(); i != d_index.end(); i++, i_i++)
+              {
+                int j_j = 0;
+                for (auto j = d_index.begin(); j != d_index.end(); j++, j_j++)
+                  iF[i_i + j_j * size_d_index] = F[i_i + j_j * size_d_index] = P[mf[*i] + mf[*j] * n] + H[*i + *j * pp];
+              }
         }
       else
         {
@@ -417,49 +404,43 @@ BlockKalmanFilter::block_kalman_filter(int nlhs, mxArray *plhs[], double *P_mf,
 
           //v = Y(:,t) - a(mf)
           for (int i = 0; i < pp; i++)
-            v[i]  = Y[i + t * pp] - a[mf[i]];
+            v[i] = Y[i + t * pp] - a[mf[i]];
 
           //F  = P(mf,mf) + H;
           if (H_size == 1)
-            {
-              for (int i = 0; i < pp; i++)
-                for (int j = 0; j < pp; j++)
-                  iF[i + j * pp] = F[i + j * pp] = P[mf[i] + mf[j] * n] + H[0];
-            }
+            for (int i = 0; i < pp; i++)
+              for (int j = 0; j < pp; j++)
+                iF[i + j * pp] = F[i + j * pp] = P[mf[i] + mf[j] * n] + H[0];
           else
-            {
-              for (int i = 0; i < pp; i++)
-                for (int j = 0; j < pp; j++)
-                  iF[i + j * pp] = F[i + j * pp] = P[mf[i] + mf[j] * n] + H[i + j * pp];
-            }
+            for (int i = 0; i < pp; i++)
+              for (int j = 0; j < pp; j++)
+                iF[i + j * pp] = F[i + j * pp] = P[mf[i] + mf[j] * n] + H[i + j * pp];
         }
 
       /* Computes the norm of iF */
-      double anorm = dlange("1", &size_d_index, &size_d_index, iF, &size_d_index, w);
+      double anorm = dlange("1", &size_d_index, &size_d_index, iF, &size_d_index, w.get());
       //mexPrintf("anorm = %f\n",anorm);
 
       /* Modifies F in place with a LU decomposition */
-      dgetrf(&size_d_index, &size_d_index, iF, &size_d_index, ipiv, &info);
+      dgetrf(&size_d_index, &size_d_index, iF, &size_d_index, ipiv.get(), &info);
       if (info != 0)
-        mexPrintf("dgetrf failure with error %d\n", (int) info);
+        mexPrintf("dgetrf failure with error %d\n", static_cast<int>(info));
 
       /* Computes the reciprocal norm */
-      dgecon("1", &size_d_index, iF, &size_d_index, &anorm, &rcond, w, iw, &info);
+      dgecon("1", &size_d_index, iF, &size_d_index, &anorm, &rcond, w.get(), iw.get(), &info);
       if (info != 0)
-        mexPrintf("dgecon failure with error %d\n", (int) info);
+        mexPrintf("dgecon failure with error %d\n", static_cast<int>(info));
 
       if (rcond < kalman_tol)
-        if (not_all_abs_F_bellow_crit(F, size_d_index * size_d_index, kalman_tol))   //~all(abs(F(:))<kalman_tol)
+        if (not_all_abs_F_bellow_crit(F, size_d_index * size_d_index, kalman_tol)) //~all(abs(F(:))<kalman_tol)
           {
             mexPrintf("error: F singular\n");
-            LIK  = Inf;
+            LIK = Inf;
             if (nlhs == 3)
-              {
-                for (int i = t; i < smpl; i++)
-                  lik[i] = Inf;
-              }
+              for (int i = t; i < smpl; i++)
+                lik[i] = Inf;
             // info = 0
-            return_results_and_clean(nlhs, plhs, &P_mf, &v_pp, &K, &K_P, &a, &K_P, &P_t_t1, &tmp, &P);
+            return_results_and_clean(nlhs, plhs);
             return false;
           }
         else
@@ -474,10 +455,10 @@ BlockKalmanFilter::block_kalman_filter(int nlhs, mxArray *plhs[], double *P_mf,
                   res += T[i + j *n] * a[j];
                 tmp_a[i] = res;
               }
-            memcpy(a, tmp_a, n * sizeof(double));
+            std::copy_n(tmp_a.get(), n, a);
 
             //P = T*P*transpose(T)+QQ;
-            memset(tmp, 0, n * n_state * sizeof(double));
+            std::fill_n(tmp, 0, n * n_state);
 
             for (int i = 0; i < n; i++)
               for (int j = pure_obs; j < n; j++)
@@ -485,20 +466,18 @@ BlockKalmanFilter::block_kalman_filter(int nlhs, mxArray *plhs[], double *P_mf,
                   int j1 = j - pure_obs;
                   int j1_n_state = j1 * n_state - pure_obs;
                   for (int k = pure_obs; k < i_nz_state_var[i]; k++)
-                    tmp[i + j1 * n ] += T[i + k * n] * P[k + j1_n_state];
+                    tmp[i + j1 * n] += T[i + k * n] * P[k + j1_n_state];
                 }
 
-            memset(P, 0, n * n * sizeof(double));
+            std::fill_n(P, 0, n * n);
             int n_n_obs = n * pure_obs;
             for (int i = 0; i < n; i++)
               for (int j = i; j < n; j++)
-                {
-                  for (int k = pure_obs; k < i_nz_state_var[j]; k++)
-                    {
-                      int k_n = k * n;
-                      P[i * n + j] += tmp[i + k_n - n_n_obs] * T[j + k_n];
-                    }
-                }
+                for (int k = pure_obs; k < i_nz_state_var[j]; k++)
+                  {
+                    int k_n = k * n;
+                    P[i * n + j] += tmp[i + k_n - n_n_obs] * T[j + k_n];
+                  }
 
             for (int i = 0; i < n; i++)
               {
@@ -513,18 +492,16 @@ BlockKalmanFilter::block_kalman_filter(int nlhs, mxArray *plhs[], double *P_mf,
           F_singular = false;
 
           //dF     = det(F);
-          dF     = det(iF, size_d_index, ipiv);
+          dF = det(iF, size_d_index, ipiv.get());
 
           //iF     = inv(F);
           //int lwork = 4/*2*/* pp;
-          dgetri(&size_d_index, iF, &size_d_index, ipiv, w, &lw, &info);
+          dgetri(&size_d_index, iF, &size_d_index, ipiv.get(), w.get(), &lw, &info);
           if (info != 0)
-            mexPrintf("dgetri failure with error %d\n", (int) info);
+            mexPrintf("dgetri failure with error %d\n", static_cast<int>(info));
 
           //lik(t) = log(dF)+transpose(v)*iF*v;
-#ifdef USE_OMP
-# pragma omp parallel for shared(v_pp) num_threads(atoi(getenv("DYNARE_NUM_THREADS")))
-#endif
+#pragma omp parallel for shared(v_pp)
           for (int i = 0; i < size_d_index; i++)
             {
               double res = 0.0;
@@ -536,35 +513,27 @@ BlockKalmanFilter::block_kalman_filter(int nlhs, mxArray *plhs[], double *P_mf,
           for (int i = 0; i < size_d_index; i++)
             res += v_pp[i] * v[i];
 
-          lik[t] = (log(dF) + res + size_d_index * log(2.0*pi))/2;
+          lik[t] = (log(dF) + res + size_d_index * log(2.0*M_PI))/2;
           if (t + 1 >= start)
             LIK += lik[t];
 
           if (missing_observations)
-            {
-              //K      = P(:,mf)*iF;
-#ifdef USE_OMP
-# pragma omp parallel for shared(P_mf) num_threads(atoi(getenv("DYNARE_NUM_THREADS")))
-#endif
-              for (int i = 0; i < n; i++)
-                {
-                  int j_j = 0;
-                  //for (int j = 0; j < pp; j++)
-                  for (vector<int>::const_iterator j = d_index.begin(); j != d_index.end(); j++, j_j++)
-                    P_mf[i + j_j * n] = P[i + mf[*j] * n];
-                }
-            }
+            //K      = P(:,mf)*iF;
+#pragma omp parallel for shared(P_mf)
+            for (int i = 0; i < n; i++)
+              {
+                int j_j = 0;
+                //for (int j = 0; j < pp; j++)
+                for (auto j = d_index.begin(); j != d_index.end(); j++, j_j++)
+                  P_mf[i + j_j * n] = P[i + mf[*j] * n];
+              }
           else
-            {
-              //K      = P(:,mf)*iF;
-              for (int i = 0; i < n; i++)
-                for (int j = 0; j < pp; j++)
-                  P_mf[i + j * n] = P[i + mf[j] * n];
-            }
+            //K      = P(:,mf)*iF;
+            for (int i = 0; i < n; i++)
+              for (int j = 0; j < pp; j++)
+                P_mf[i + j * n] = P[i + mf[j] * n];
 
-#ifdef USE_OMP
-# pragma omp parallel for shared(K) num_threads(atoi(getenv("DYNARE_NUM_THREADS")))
-#endif
+#pragma omp parallel for shared(K)
           for (int i = 0; i < n; i++)
             for (int j = 0; j < size_d_index; j++)
               {
@@ -576,9 +545,7 @@ BlockKalmanFilter::block_kalman_filter(int nlhs, mxArray *plhs[], double *P_mf,
               }
 
           //a      = T*(a+K*v);
-#ifdef USE_OMP
-# pragma omp parallel for shared(v_n) num_threads(atoi(getenv("DYNARE_NUM_THREADS")))
-#endif
+#pragma omp parallel for shared(v_n)
           for (int i = pure_obs; i < n; i++)
             {
               double res = 0.0;
@@ -587,9 +554,7 @@ BlockKalmanFilter::block_kalman_filter(int nlhs, mxArray *plhs[], double *P_mf,
               v_n[i] = res + a[i];
             }
 
-#ifdef USE_OMP
-# pragma omp parallel for shared(a) num_threads(atoi(getenv("DYNARE_NUM_THREADS")))
-#endif
+#pragma omp parallel for shared(a)
           for (int i = 0; i < n; i++)
             {
               double res = 0.0;
@@ -602,26 +567,20 @@ BlockKalmanFilter::block_kalman_filter(int nlhs, mxArray *plhs[], double *P_mf,
             {
               //P      = T*(P-K*P(mf,:))*transpose(T)+QQ;
               int i_i = 0;
-              //#pragma omp parallel for shared(P_mf) num_threads(atoi(getenv("DYNARE_NUM_THREADS")))
-              for (vector<int>::const_iterator i = d_index.begin(); i != d_index.end(); i++, i_i++)
+              //#pragma omp parallel for shared(P_mf)
+              for (auto i = d_index.begin(); i != d_index.end(); i++, i_i++)
                 for (int j = pure_obs; j < n; j++)
                   P_mf[i_i + j * size_d_index] = P[mf[*i] + j * n];
             }
           else
-            {
-              //P      = T*(P-K*P(mf,:))*transpose(T)+QQ;
-#ifdef USE_OMP
-# pragma omp parallel for shared(P_mf) num_threads(atoi(getenv("DYNARE_NUM_THREADS")))
-#endif
-              for (int i = 0; i < pp; i++)
-                for (int j = pure_obs; j < n; j++)
-                  P_mf[i + j * pp] = P[mf[i] + j * n];
-            }
+            //P      = T*(P-K*P(mf,:))*transpose(T)+QQ;
+#pragma omp parallel for shared(P_mf)
+            for (int i = 0; i < pp; i++)
+              for (int j = pure_obs; j < n; j++)
+                P_mf[i + j * pp] = P[mf[i] + j * n];
 
 #ifdef BLAS
-# ifdef USE_OMP
-#  pragma omp parallel for shared(K_P) num_threads(atoi(getenv("DYNARE_NUM_THREADS")))
-# endif
+# pragma omp parallel for shared(K_P)
           for (int i = 0; i < n; i++)
             for (int j = i; j < n; j++)
               {
@@ -638,9 +597,9 @@ BlockKalmanFilter::block_kalman_filter(int nlhs, mxArray *plhs[], double *P_mf,
                 unsigned int k = i * n + j;
                 P_t_t1[j * n + i] = P_t_t1[k] = P[k] - K_P[k];
               }
-          double one  = 1.0;
+          double one = 1.0;
           double zero = 0.0;
-          memcpy(P, QQ, n * n *sizeof(double));
+          std::copy_n(QQ, n * n, P);
           blas_int n_b = n;
           /*mexPrintf("sizeof(n_b)=%d, n_b=%d, sizeof(n)=%d, n=%d\n",sizeof(n_b),n_b,sizeof(n),n);
             mexEvalString("drawnow;");*/
@@ -672,7 +631,7 @@ BlockKalmanFilter::block_kalman_filter(int nlhs, mxArray *plhs[], double *P_mf,
               }
           mexPrintf("CudaBLAS\n");
           mexEvalString("drawnow;");
-          double one  = 1.0;
+          double one = 1.0;
           double zero = 0.0;
           cublasStatus_t status;
           cublasHandle_t handle;
@@ -685,27 +644,24 @@ BlockKalmanFilter::block_kalman_filter(int nlhs, mxArray *plhs[], double *P_mf,
           /*int device;
             cudaGetDevice(&device);*/
           int n2 = n * n;
-          double *d_A = 0;
-          double *d_B = 0;
-          double *d_C = 0;
-          double *d_D = 0;
+          double *d_A = nullptr, *d_B = nullptr, *d_C = nullptr, *d_D = nullptr;
           // Allocate device memory for the matrices
-          if (cudaMalloc((void **) &d_A, n2 * sizeof(double)) != cudaSuccess)
+          if (cudaMalloc(static_cast<void **>(&d_A), n2 * sizeof(double)) != cudaSuccess)
             {
               mexPrintf("!!!! device memory allocation error (allocate A)\n");
               return false;
             }
-          if (cudaMalloc((void **) &d_B, n2 * sizeof(d_B[0])) != cudaSuccess)
+          if (cudaMalloc(static_cast<void **>(&d_B), n2 * sizeof(d_B[0])) != cudaSuccess)
             {
               mexPrintf("!!!! device memory allocation error (allocate B)\n");
               return false;
             }
-          if (cudaMalloc((void **) &d_C, n2 * sizeof(d_C[0])) != cudaSuccess)
+          if (cudaMalloc(static_cast<void **>(&d_C), n2 * sizeof(d_C[0])) != cudaSuccess)
             {
               mexPrintf("!!!! device memory allocation error (allocate C)\n");
               return false;
             }
-          if (cudaMalloc((void **) &d_D, n2 * sizeof(d_D[0])) != cudaSuccess)
+          if (cudaMalloc(static_cast<void **>(&d_D), n2 * sizeof(d_D[0])) != cudaSuccess)
             {
               mexPrintf("!!!! device memory allocation error (allocate D)\n");
               return false;
@@ -762,9 +718,7 @@ BlockKalmanFilter::block_kalman_filter(int nlhs, mxArray *plhs[], double *P_mf,
             }
 
 # else
-#  ifdef USE_OMP
-#   pragma omp parallel for shared(K_P) num_threads(atoi(getenv("DYNARE_NUM_THREADS")))
-#  endif
+#  pragma omp parallel for shared(K_P)
           for (int i = pure_obs; i < n; i++)
             {
               unsigned int i1 = i - pure_obs;
@@ -779,9 +733,7 @@ BlockKalmanFilter::block_kalman_filter(int nlhs, mxArray *plhs[], double *P_mf,
                 }
             }
 
-#  ifdef USE_OMP
-#   pragma omp parallel for shared(P_t_t1) num_threads(atoi(getenv("DYNARE_NUM_THREADS")))
-#  endif
+#  pragma omp parallel for shared(P_t_t1)
           for (int i = pure_obs; i < n; i++)
             {
               unsigned int i1 = i - pure_obs;
@@ -793,11 +745,9 @@ BlockKalmanFilter::block_kalman_filter(int nlhs, mxArray *plhs[], double *P_mf,
                 }
             }
 
-          memset(tmp, 0, n * n_state * sizeof(double));
+          fill_n(tmp, 0, n * n_state);
 
-#  ifdef USE_OMP
-#   pragma omp parallel for shared(tmp) num_threads(atoi(getenv("DYNARE_NUM_THREADS")))
-#  endif
+#  pragma omp parallel for shared(tmp)
           for (int i = 0; i < n; i++)
             {
               int max_k = i_nz_state_var[i];
@@ -811,12 +761,10 @@ BlockKalmanFilter::block_kalman_filter(int nlhs, mxArray *plhs[], double *P_mf,
                 }
             }
 
-          memset(P, 0, n * n * sizeof(double));
+          fill_n(P, 0, n * n);
 
           int n_n_obs = -n * pure_obs;
-#  ifdef USE_OMP
-#   pragma omp parallel for shared(P) num_threads(atoi(getenv("DYNARE_NUM_THREADS")))
-#  endif
+#  pragma omp parallel for shared(P)
           for (int i = 0; i < n; i++)
             {
               for (int j = i; j < n; j++)
@@ -831,9 +779,7 @@ BlockKalmanFilter::block_kalman_filter(int nlhs, mxArray *plhs[], double *P_mf,
                 }
             }
 
-#  ifdef USE_OMP
-#   pragma omp parallel for shared(P) num_threads(atoi(getenv("DYNARE_NUM_THREADS")))
-#  endif
+#  pragma omp parallel for shared(P)
           for (int i = 0; i < n; i++)
             {
               for (int j = i; j < n; j++)
@@ -849,14 +795,13 @@ BlockKalmanFilter::block_kalman_filter(int nlhs, mxArray *plhs[], double *P_mf,
               for (int i = 0; i < n * size_d_index; i++)
                 {
                   double res = abs(K[i] - oldK[i]);
-                  if (res > max_abs)
-                    max_abs = res;
+                  max_abs = std::max(res, max_abs);
                 }
               notsteady = max_abs > riccati_tol;
 
               //oldK = K(:);
 
-              memcpy(oldK, K, n * pp * sizeof(double));
+              std::copy_n(K, n * pp, oldK.get());
             }
         }
       t++;
@@ -865,12 +810,12 @@ BlockKalmanFilter::block_kalman_filter(int nlhs, mxArray *plhs[], double *P_mf,
   if (F_singular)
     mexErrMsgTxt("The variance of the forecast error remains singular until the end of the sample\n");
   if (t < smpl)
-    block_kalman_filter_ss(P_mf, v_pp, K, K_P, a, K_P, P_t_t1, tmp, P);
+    block_kalman_filter_ss();
   return true;
 }
 
 void
-BlockKalmanFilter::return_results_and_clean(int nlhs, mxArray *plhs[], double *P_mf[], double *v_pp[], double *K[], double *v_n[], double *a[], double *K_P[], double *P_t_t1[], double *tmp[], double *P[])
+BlockKalmanFilter::return_results_and_clean(int nlhs, mxArray *plhs[])
 {
   plhs[0] = mxCreateDoubleScalar(0);
 
@@ -886,17 +831,6 @@ BlockKalmanFilter::return_results_and_clean(int nlhs, mxArray *plhs[], double *P
   else
     mxDestroyArray(plik);
 
-  mxFree(w);
-  mxFree(i_nz_state_var);
-  mxFree(tmp_a);
-  //mxFree(v_pp);
-  //mxFree(v_n);
-  mxFree(mf);
-  mxFree(iw);
-  mxFree(ipiv);
-  mxFree(oldK);
-  //mxFree(P_mf);
-
   mxDestroyArray(pa);
   mxDestroyArray(p_tmp);
   mxDestroyArray(pQQ);
@@ -911,8 +845,7 @@ BlockKalmanFilter::return_results_and_clean(int nlhs, mxArray *plhs[], double *P
 void
 mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
 {
-  double *P_mf, *v_pp, *v_n, *a, *K, *K_P, *P_t_t1, *tmp, *P;
-  BlockKalmanFilter block_kalman_filter(nlhs, plhs, nrhs, prhs, &P_mf, &v_pp, &K, &v_n, &a, &K_P, &P_t_t1, &tmp, &P);
-  if (block_kalman_filter.block_kalman_filter(nlhs, plhs, P_mf, v_pp, K, K_P, a, K_P, P_t_t1, tmp, P))
-    block_kalman_filter.return_results_and_clean(nlhs, plhs, &P_mf, &v_pp, &K, &K_P, &a, &K_P, &P_t_t1, &tmp, &P);
+  BlockKalmanFilter block_kalman_filter(nlhs, plhs, nrhs, prhs);
+  if (block_kalman_filter.block_kalman_filter(nlhs, plhs))
+    block_kalman_filter.return_results_and_clean(nlhs, plhs);
 }
