@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007-2017 Dynare Team
+ * Copyright © 2007-2017 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -118,9 +118,9 @@ Interpreter::evaluate_a_block(bool initialization)
         }
       break;
     case SOLVE_FORWARD_SIMPLE:
-      g1 = (double *) mxMalloc(size*size*sizeof(double));
+      g1 = static_cast<double *>(mxMalloc(size*size*sizeof(double)));
       test_mxMalloc(g1, __LINE__, __FILE__, __func__, size*size*sizeof(double));
-      r = (double *) mxMalloc(size*sizeof(double));
+      r = static_cast<double *>(mxMalloc(size*sizeof(double)));
       test_mxMalloc(r, __LINE__, __FILE__, __func__, size*sizeof(double));
       if (steady_state)
         {
@@ -160,7 +160,7 @@ Interpreter::evaluate_a_block(bool initialization)
 #ifdef DEBUG
       mexPrintf("in SOLVE_FORWARD_COMPLETE r = mxMalloc(%d*sizeof(double))\n", size);
 #endif
-      r = (double *) mxMalloc(size*sizeof(double));
+      r = static_cast<double *>(mxMalloc(size*sizeof(double)));
       test_mxMalloc(r, __LINE__, __FILE__, __func__, size*sizeof(double));
       if (steady_state)
         {
@@ -219,9 +219,9 @@ Interpreter::evaluate_a_block(bool initialization)
         }
       break;
     case SOLVE_BACKWARD_SIMPLE:
-      g1 = (double *) mxMalloc(size*size*sizeof(double));
+      g1 = static_cast<double *>(mxMalloc(size*size*sizeof(double)));
       test_mxMalloc(g1, __LINE__, __FILE__, __func__, size*size*sizeof(double));
-      r = (double *) mxMalloc(size*sizeof(double));
+      r = static_cast<double *>(mxMalloc(size*sizeof(double)));
       test_mxMalloc(r, __LINE__, __FILE__, __func__, size*sizeof(double));
       if (steady_state)
         {
@@ -258,7 +258,7 @@ Interpreter::evaluate_a_block(bool initialization)
           fixe_u(&u, u_count_int, u_count_int);
           Read_SparseMatrix(bin_base_name, size, 1, 0, 0, false, stack_solve_algo, solve_algo);
         }
-      r = (double *) mxMalloc(size*sizeof(double));
+      r = static_cast<double *>(mxMalloc(size*sizeof(double)));
       test_mxMalloc(r, __LINE__, __FILE__, __func__, size*sizeof(double));
       if (steady_state)
         {
@@ -296,7 +296,7 @@ Interpreter::evaluate_a_block(bool initialization)
           Read_SparseMatrix(bin_base_name, size, periods, y_kmin, y_kmax, true, stack_solve_algo, solve_algo);
         }
       u_count = u_count_int*(periods+y_kmax+y_kmin);
-      r = (double *) mxMalloc(size*sizeof(double));
+      r = static_cast<double *>(mxMalloc(size*sizeof(double)));
       test_mxMalloc(r, __LINE__, __FILE__, __func__, size*sizeof(double));
       begining = it_code;
       for (it_ = y_kmin; it_ < periods+y_kmin; it_++)
@@ -436,11 +436,11 @@ Interpreter::simulate_a_block(vector_table_conditional_local_type vector_table_c
           Read_SparseMatrix(bin_base_name, size, periods, y_kmin, y_kmax, true, stack_solve_algo, solve_algo);
         }
       u_count = u_count_int*(periods+y_kmax+y_kmin);
-      r = (double *) mxMalloc(size*sizeof(double));
+      r = static_cast<double *>(mxMalloc(size*sizeof(double)));
       test_mxMalloc(r, __LINE__, __FILE__, __func__, size*sizeof(double));
-      res = (double *) mxMalloc(size*periods*sizeof(double));
+      res = static_cast<double *>(mxMalloc(size*periods*sizeof(double)));
       test_mxMalloc(res, __LINE__, __FILE__, __func__, size*periods*sizeof(double));
-      y_save = (double *) mxMalloc(y_size*sizeof(double)*(periods+y_kmax+y_kmin));
+      y_save = static_cast<double *>(mxMalloc(y_size*sizeof(double)*(periods+y_kmax+y_kmin)));
       test_mxMalloc(y_save, __LINE__, __FILE__, __func__, y_size*sizeof(double)*(periods+y_kmax+y_kmin));
       start_code = it_code;
       iter = 0;
@@ -577,9 +577,9 @@ void
 Interpreter::ReadCodeFile(string file_name, CodeLoad &code)
 {
   if (steady_state)
-    file_name += "_static";
+    file_name += "/model/bytecode/static";
   else
-    file_name += "_dynamic";
+    file_name += "/model/bytecode/dynamic";
 
   //First read and store in memory the code
   code_liste = code.get_op_code(file_name);
@@ -587,10 +587,10 @@ Interpreter::ReadCodeFile(string file_name, CodeLoad &code)
   if (!code_liste.size())
     {
       ostringstream tmp;
-      tmp << " in compute_blocks, " << file_name.c_str() << " cannot be opened\n";
+      tmp << " in compute_blocks, " << file_name << ".cod cannot be opened\n";
       throw FatalExceptionHandling(tmp.str());
     }
-  if (block >= (int) code.get_block_number())
+  if (block >= static_cast<int>(code.get_block_number()))
     {
       ostringstream tmp;
       tmp << " in compute_blocks, input argument block = " << block+1 << " is greater than the number of blocks in the model (" << code.get_block_number() << " see M_.block_structure_stat.block)\n";
@@ -606,13 +606,13 @@ Interpreter::check_for_controlled_exo_validity(FBEGINBLOCK_ *fb, vector<s_plan>
   vector<int> endogenous = fb->get_endogenous();
   for (vector<s_plan>::iterator it = sconstrained_extended_path.begin(); it != sconstrained_extended_path.end(); it++)
     {
-      if ((find(endogenous.begin(), endogenous.end(), it->exo_num) != endogenous.end()) &&  (find(exogenous.begin(), exogenous.end(), it->var_num) == exogenous.end()))
+      if ((find(endogenous.begin(), endogenous.end(), it->exo_num) != endogenous.end()) && (find(exogenous.begin(), exogenous.end(), it->var_num) == exogenous.end()))
         {
           ostringstream tmp;
-          tmp << "\n the conditional forecast involving as constrained variable " << get_variable(eEndogenous, it->exo_num) << " and as endogenized exogenous " << get_variable(eExogenous, it->var_num) << " that do not appear in block=" << Block_Count+1 << ")\n You should not use block in model options\n";
+          tmp << "\n the conditional forecast involving as constrained variable " << get_variable(SymbolType::endogenous, it->exo_num) << " and as endogenized exogenous " << get_variable(SymbolType::exogenous, it->var_num) << " that do not appear in block=" << Block_Count+1 << ")\n You should not use block in model options\n";
           throw FatalExceptionHandling(tmp.str());
         }
-      else if ((find(endogenous.begin(), endogenous.end(), it->exo_num) != endogenous.end()) &&  (find(exogenous.begin(), exogenous.end(), it->var_num) != exogenous.end()) && ((fb->get_type() == EVALUATE_FORWARD) || (fb->get_type() != EVALUATE_BACKWARD)))
+      else if ((find(endogenous.begin(), endogenous.end(), it->exo_num) != endogenous.end()) && (find(exogenous.begin(), exogenous.end(), it->var_num) != exogenous.end()) && ((fb->get_type() == EVALUATE_FORWARD) || (fb->get_type() != EVALUATE_BACKWARD)))
         {
           ostringstream tmp;
           tmp << "\n the conditional forecast cannot be implemented for the block=" << Block_Count+1 << ") that has to be evaluated instead to be solved\n You should not use block in model options\n";
@@ -621,7 +621,7 @@ Interpreter::check_for_controlled_exo_validity(FBEGINBLOCK_ *fb, vector<s_plan>
       else if (find(previous_block_exogenous.begin(), previous_block_exogenous.end(), it->var_num) != previous_block_exogenous.end())
         {
           ostringstream tmp;
-          tmp << "\n the conditional forecast involves in the block " << Block_Count+1 << " the endogenized exogenous " << get_variable(eExogenous, it->var_num) << " that appear also in a previous block\n You should not use block in model options\n";
+          tmp << "\n the conditional forecast involves in the block " << Block_Count+1 << " the endogenized exogenous " << get_variable(SymbolType::exogenous, it->var_num) << " that appear also in a previous block\n You should not use block in model options\n";
           throw FatalExceptionHandling(tmp.str());
         }
     }
@@ -661,7 +661,7 @@ Interpreter::MainLoop(string bin_basename, CodeLoad code, bool evaluate, int blo
 #endif
           //it's a new block
           {
-            FBEGINBLOCK_ *fb = (FBEGINBLOCK_ *) it_code->second;
+            FBEGINBLOCK_ *fb = static_cast<FBEGINBLOCK_ *>(it_code->second);
             Block_Contain = fb->get_Block_Contain();
             it_code++;
             if (constrained)
@@ -752,12 +752,12 @@ Interpreter::MainLoop(string bin_basename, CodeLoad code, bool evaluate, int blo
           break;
         case FDIMT:
 #ifdef DEBUG
-          mexPrintf("FDIMT size=%d\n", ((FDIMT_ *) it_code->second)->get_size());
+          mexPrintf("FDIMT size=%d\n", static_cast<FDIMT_ *>(it_code->second)->get_size());
 #endif
-          var = ((FDIMT_ *) it_code->second)->get_size();
+          var = static_cast<FDIMT_ *>(it_code->second)->get_size();
           if (T)
             mxFree(T);
-          T = (double *) mxMalloc(var*(periods+y_kmin+y_kmax)*sizeof(double));
+          T = static_cast<double *>(mxMalloc(var*(periods+y_kmin+y_kmax)*sizeof(double)));
           test_mxMalloc(T, __LINE__, __FILE__, __func__, var*(periods+y_kmin+y_kmax)*sizeof(double));
           if (block >= 0)
             {
@@ -768,9 +768,9 @@ Interpreter::MainLoop(string bin_basename, CodeLoad code, bool evaluate, int blo
           break;
         case FDIMST:
 #ifdef DEBUG
-          mexPrintf("FDIMST size=%d\n", ((FDIMST_ *) it_code->second)->get_size());
+          mexPrintf("FDIMST size=%d\n", static_cast<FDIMST_ *>(it_code->second)->get_size());
 #endif
-          var = ((FDIMST_ *) it_code->second)->get_size();
+          var = static_cast<FDIMST_ *>(it_code->second)->get_size();
           if (T)
             mxFree(T);
           if (global_temporary_terms)
@@ -779,13 +779,13 @@ Interpreter::MainLoop(string bin_basename, CodeLoad code, bool evaluate, int blo
                 {
                   mexPrintf("GlobalTemporaryTerms is NULL\n"); mexEvalString("drawnow;");
                 }
-              if (var != (int) mxGetNumberOfElements(GlobalTemporaryTerms))
+              if (var != static_cast<int>(mxGetNumberOfElements(GlobalTemporaryTerms)))
                 GlobalTemporaryTerms = mxCreateDoubleMatrix(var, 1, mxREAL);
               T = mxGetPr(GlobalTemporaryTerms);
             }
           else
             {
-              T = (double *) mxMalloc(var*sizeof(double));
+              T = static_cast<double *>(mxMalloc(var*sizeof(double)));
               test_mxMalloc(T, __LINE__, __FILE__, __func__, var*sizeof(double));
             }
 
@@ -858,9 +858,9 @@ Interpreter::extended_path(string file_name, string bin_basename, bool evaluate,
     double *y_save = (double *) mxMalloc(size_of_direction);
     double *x_save = (double *) mxMalloc((periods + y_kmax + y_kmin) * col_x *sizeof(double));*/
   size_t size_of_direction = y_size*col_y*sizeof(double);
-  double *y_save = (double *) mxMalloc(size_of_direction);
+  double *y_save = static_cast<double *>(mxMalloc(size_of_direction));
   test_mxMalloc(y_save, __LINE__, __FILE__, __func__, size_of_direction);
-  double *x_save = (double *) mxMalloc(nb_row_x * col_x *sizeof(double));
+  double *x_save = static_cast<double *>(mxMalloc(nb_row_x * col_x *sizeof(double)));
   test_mxMalloc(x_save, __LINE__, __FILE__, __func__, nb_row_x * col_x *sizeof(double));
 
   vector_table_conditional_local_type vector_table_conditional_local;
@@ -921,9 +921,9 @@ Interpreter::extended_path(string file_name, string bin_basename, bool evaluate,
         MainLoop(bin_basename, code, evaluate, block, true, true, sconstrained_extended_path, vector_table_conditional_local);
       for (int j = 0; j < y_size; j++)
         {
-          y_save[j + (t + y_kmin) * y_size] = y[ j +  (y_kmin) * y_size];
+          y_save[j + (t + y_kmin) * y_size] = y[j + y_kmin * y_size];
           if (y_kmin > 0)
-            y[j ] = y[ j +  (y_kmin) * y_size];
+            y[j] = y[j + y_kmin * y_size];
         }
       for (int j = 0; j < col_x; j++)
         {
@@ -951,7 +951,7 @@ Interpreter::extended_path(string file_name, string bin_basename, bool evaluate,
     y_save[j + (k + y_kmin) * y_size] = y[ j +  ( k - (nb_periods-1) + y_kmin) * y_size];
     }*/
   for (int i = 0; i < y_size * col_y; i++)
-    y[i]  = y_save[i];
+    y[i] = y_save[i];
   for (int j = 0; j < col_x * nb_row_x; j++)
     x[j] = x_save[j];
   if (Init_Code->second)
