@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007-2017 Dynare Team
+ * Copyright © 2007-2017 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -75,7 +75,7 @@ Get_Argument(const mxArray *prhs)
   const mxArray *mxa = prhs;
   mwSize buflen = mwSize(mxGetM(mxa) * mxGetN(mxa) + 1);
   char *first_argument;
-  first_argument = (char *) mxCalloc(buflen, sizeof(char));
+  first_argument = static_cast<char *>(mxCalloc(buflen, sizeof(char)));
   size_t status = mxGetString(mxa, first_argument, buflen);
   if (status != 0)
     mexWarnMsgTxt("Not enough space. The first argument is truncated.");
@@ -208,7 +208,7 @@ GPU_Test_and_Info(cublasHandle_t *cublas_handle, cusparseHandle_t *cusparse_hand
   mexPrintf("> Driver version:\n");
   int cuda_version;
   cuda_error = cudaDriverGetVersion(&cuda_version);
-  if (cuda_error  != cudaSuccess)
+  if (cuda_error != cudaSuccess)
     {
       ostringstream tmp;
       tmp << " cudaGetVersion has failed\n";
@@ -249,7 +249,7 @@ GPU_close(cublasHandle_t cublas_handle, cusparseHandle_t cusparse_handle, cuspar
 string
 deblank(string x)
 {
-  for (int i = 0; i < (int) x.length(); i++)
+  for (int i = 0; i < static_cast<int>(x.length()); i++)
     if (x[i] == ' ')
       x.erase(i--, 1);
   return x;
@@ -297,7 +297,7 @@ Get_Arguments_and_global_variables(int nrhs,
                 col_y = mxGetN(prhs[i]);
                 break;
               case 1:
-                *xd =  mxGetPr(prhs[i]);
+                *xd = mxGetPr(prhs[i]);
                 row_x = mxGetM(prhs[i]);
                 col_x = mxGetN(prhs[i]);
                 break;
@@ -349,7 +349,7 @@ Get_Arguments_and_global_variables(int nrhs,
                     pos = pos1 + 1;
                   else
                     pos += 5;
-                  block =  atoi(Get_Argument(prhs[i]).substr(pos, string::npos).c_str())-1;
+                  block = atoi(Get_Argument(prhs[i]).substr(pos, string::npos).c_str())-1;
                 }
               else if (Get_Argument(prhs[i]).substr(0, 13) == "extended_path")
                 {
@@ -369,7 +369,7 @@ Get_Arguments_and_global_variables(int nrhs,
                     pos = pos1 + 1;
                   else
                     pos += 6;
-                  *pfplan_struct_name =  deblank(Get_Argument(prhs[i]).substr(pos, string::npos));
+                  *pfplan_struct_name = deblank(Get_Argument(prhs[i]).substr(pos, string::npos));
                 }
               else if (Get_Argument(prhs[i]).substr(0, 4) == "plan")
                 {
@@ -378,7 +378,7 @@ Get_Arguments_and_global_variables(int nrhs,
                     pos = pos1 + 1;
                   else
                     pos += 4;
-                  *plan_struct_name =  deblank(Get_Argument(prhs[i]).substr(pos, string::npos));
+                  *plan_struct_name = deblank(Get_Argument(prhs[i]).substr(pos, string::npos));
                 }
               else
                 {
@@ -582,7 +582,7 @@ main(int nrhs, const char *prhs[])
       int nb_controlled = 0;
       mxArray *options_cond_fcst_ = mxGetField(extended_path_struct, 0, "options_cond_fcst_");
       mxArray *controlled_varexo = NULL;
-      if (options_cond_fcst_  != NULL)
+      if (options_cond_fcst_ != NULL)
         {
           controlled_varexo = mxGetField(options_cond_fcst_, 0, "controlled_varexo");
           nb_controlled = mxGetM(controlled_varexo) * mxGetN(controlled_varexo);
@@ -624,7 +624,7 @@ main(int nrhs, const char *prhs[])
           double *specific_constrained_paths_ = mxGetPr(Array_constrained_paths_);
           double *specific_constrained_int_date_ = mxGetPr(mxGetCell(constrained_int_date_, i));
           int nb_local_periods = mxGetM(Array_constrained_paths_) * mxGetN(Array_constrained_paths_);
-          int *constrained_int_date = (int *) mxMalloc(nb_local_periods * sizeof(int));
+          int *constrained_int_date = static_cast<int *>(mxMalloc(nb_local_periods * sizeof(int)));
           error_msg.test_mxMalloc(constrained_int_date, __LINE__, __FILE__, __func__, nb_local_periods * sizeof(int));
           if (nb_periods < nb_local_periods)
             {
@@ -697,14 +697,14 @@ main(int nrhs, const char *prhs[])
       for (int i = 0; i < nb_periods; i++)
         {
           int buflen = mxGetNumberOfElements(mxGetCell(date_str, i)) + 1;
-          char *buf = (char *) mxCalloc(buflen, sizeof(char));
+          char *buf = static_cast<char *>(mxCalloc(buflen, sizeof(char)));
           int info = mxGetString(mxGetCell(date_str, i), buf, buflen);
           if (info)
             {
               string tmp = "Can not allocated memory to store the date_str in the extended path descriptor";
               DYN_MEX_FUNC_ERR_MSG_TXT(tmp.c_str());
             }
-          dates.push_back(string(buf));//string(Dates[i]);
+          dates.push_back(string(buf)); //string(Dates[i]);
           mxFree(buf);
         }
     }
@@ -719,19 +719,19 @@ main(int nrhs, const char *prhs[])
         }
       size_t n_plan = mxGetN(plan_struct);
       splan.resize(n_plan);
-      for (int i = 0; i < (int) n_plan; i++)
+      for (int i = 0; i < static_cast<int>(n_plan); i++)
         {
           splan[i].var = "";
           splan[i].exo = "";
           mxArray *tmp = mxGetField(plan_struct, i, "exo");
           if (tmp)
             {
-              char name [100];
+              char name[100];
               mxGetString(tmp, name, 100);
               splan[i].var = name;
-              SymbolType variable_type = eEndogenous;
+              SymbolType variable_type = SymbolType::endogenous;
               int exo_num = emsg.get_ID(name, &variable_type);
-              if (variable_type == eExogenous || variable_type == eExogenousDet)
+              if (variable_type == SymbolType::exogenous || variable_type == SymbolType::exogenousDet)
                 splan[i].var_num = exo_num;
               else
                 {
@@ -744,12 +744,12 @@ main(int nrhs, const char *prhs[])
           tmp = mxGetField(plan_struct, i, "var");
           if (tmp)
             {
-              char name [100];
+              char name[100];
               mxGetString(tmp, name, 100);
               splan[i].exo = name;
               SymbolType variable_type;
               int exo_num = emsg.get_ID(name, &variable_type);
-              if (variable_type == eEndogenous)
+              if (variable_type == SymbolType::endogenous)
                 splan[i].exo_num = exo_num;
               else
                 {
@@ -765,7 +765,7 @@ main(int nrhs, const char *prhs[])
               size_t num_shocks = mxGetM(tmp);
               (splan[i]).per_value.resize(num_shocks);
               double *per_value = mxGetPr(tmp);
-              for (int j = 0; j < (int) num_shocks; j++)
+              for (int j = 0; j < static_cast<int>(num_shocks); j++)
                 (splan[i]).per_value[j] = make_pair(ceil(per_value[j]), per_value[j + num_shocks]);
             }
         }
@@ -778,7 +778,7 @@ main(int nrhs, const char *prhs[])
             mexPrintf(" plan fliping var=%s (%d) exo=%s (%d) for the following periods and with the following values:\n", it->var.c_str(), it->var_num, it->exo.c_str(), it->exo_num);
           else
             mexPrintf(" plan shocks on var=%s for the following periods and with the following values:\n", it->var.c_str());
-          for (vector<pair<int, double> >::iterator it1 = it->per_value.begin(); it1 != it->per_value.end(); it1++)
+          for (vector<pair<int, double>>::iterator it1 = it->per_value.begin(); it1 != it->per_value.end(); it1++)
             {
               mexPrintf("  %3d %10.5f\n", it1->first, it1->second);
             }
@@ -797,19 +797,19 @@ main(int nrhs, const char *prhs[])
         }
       size_t n_plan = mxGetN(pfplan_struct);
       spfplan.resize(n_plan);
-      for (int i = 0; i < (int) n_plan; i++)
+      for (int i = 0; i < static_cast<int>(n_plan); i++)
         {
           spfplan[i].var = "";
           spfplan[i].exo = "";
           mxArray *tmp = mxGetField(pfplan_struct, i, "var");
           if (tmp)
             {
-              char name [100];
+              char name[100];
               mxGetString(tmp, name, 100);
               spfplan[i].var = name;
-              SymbolType variable_type = eEndogenous;
+              SymbolType variable_type = SymbolType::endogenous;
               int exo_num = emsg.get_ID(name, &variable_type);
-              if (variable_type == eExogenous || variable_type == eExogenousDet)
+              if (variable_type == SymbolType::exogenous || variable_type == SymbolType::exogenousDet)
                 splan[i].var_num = exo_num;
               else
                 {
@@ -822,12 +822,12 @@ main(int nrhs, const char *prhs[])
           tmp = mxGetField(pfplan_struct, i, "exo");
           if (tmp)
             {
-              char name [100];
+              char name[100];
               mxGetString(tmp, name, 100);
               spfplan[i].exo = name;
               SymbolType variable_type;
               int exo_num = emsg.get_ID(name, &variable_type);
-              if (variable_type == eEndogenous)
+              if (variable_type == SymbolType::endogenous)
                 spfplan[i].exo_num = exo_num;
               else
                 {
@@ -843,7 +843,7 @@ main(int nrhs, const char *prhs[])
               size_t num_shocks = mxGetM(tmp);
               double *per_value = mxGetPr(tmp);
               (spfplan[i]).per_value.resize(num_shocks);
-              for (int j = 0; j < (int) num_shocks; j++)
+              for (int j = 0; j < static_cast<int>(num_shocks); j++)
                 spfplan[i].per_value[j] = make_pair(ceil(per_value[j]), per_value[j+ num_shocks]);
             }
         }
@@ -856,7 +856,7 @@ main(int nrhs, const char *prhs[])
             mexPrintf(" plan flipping var=%s (%d) exo=%s (%d) for the following periods and with the following values:\n", it->var.c_str(), it->var_num, it->exo.c_str(), it->exo_num);
           else
             mexPrintf(" plan shocks on var=%s (%d) for the following periods and with the following values:\n", it->var.c_str(), it->var_num);
-          for (vector<pair<int, double> >::iterator it1 = it->per_value.begin(); it1 != it->per_value.end(); it1++)
+          for (vector<pair<int, double>>::iterator it1 = it->per_value.begin(); it1 != it->per_value.end(); it1++)
             {
               mexPrintf("  %3d %10.5f\n", it1->first, it1->second);
             }
@@ -1029,7 +1029,7 @@ main(int nrhs, const char *prhs[])
     DYN_MEX_FUNC_ERR_MSG_TXT("fname is not a field of M_");
   size_t buflen = mxGetM(mxa) * mxGetN(mxa) + 1;
   char *fname;
-  fname = (char *) mxCalloc(buflen+1, sizeof(char));
+  fname = static_cast<char *>(mxCalloc(buflen+1, sizeof(char)));
   size_t status = mxGetString(mxa, fname, int (buflen));
   fname[buflen] = ' ';
   if (status != 0)
@@ -1051,15 +1051,15 @@ main(int nrhs, const char *prhs[])
     DYN_MEX_FUNC_ERR_MSG_TXT("bytecode has not been compiled with CUDA option. Bytecode Can't use options_.stack_solve_algo=7\n");
 #endif
   size_t size_of_direction = col_y*row_y*sizeof(double);
-  double *y = (double *) mxMalloc(size_of_direction);
+  double *y = static_cast<double *>(mxMalloc(size_of_direction));
   error_msg.test_mxMalloc(y, __LINE__, __FILE__, __func__, size_of_direction);
-  double *ya = (double *) mxMalloc(size_of_direction);
+  double *ya = static_cast<double *>(mxMalloc(size_of_direction));
   error_msg.test_mxMalloc(ya, __LINE__, __FILE__, __func__, size_of_direction);
-  direction = (double *) mxMalloc(size_of_direction);
+  direction = static_cast<double *>(mxMalloc(size_of_direction));
   error_msg.test_mxMalloc(direction, __LINE__, __FILE__, __func__, size_of_direction);
   memset(direction, 0, size_of_direction);
   /*mexPrintf("col_x : %d, row_x : %d\n",col_x, row_x);*/
-  double *x = (double *) mxMalloc(col_x*row_x*sizeof(double));
+  double *x = static_cast<double *>(mxMalloc(col_x*row_x*sizeof(double)));
   error_msg.test_mxMalloc(x, __LINE__, __FILE__, __func__, col_x*row_x*sizeof(double));
   for (i = 0; i < row_x*col_x; i++)
     {
@@ -1067,7 +1067,7 @@ main(int nrhs, const char *prhs[])
     }
   for (i = 0; i < row_y*col_y; i++)
     {
-      y[i]  = double (yd[i]);
+      y[i] = double (yd[i]);
       ya[i] = double (yd[i]);
     }
   size_t y_size = row_y;
@@ -1184,7 +1184,7 @@ main(int nrhs, const char *prhs[])
                       jacob_exo_field_number = 1;
                       jacob_exo_det_field_number = 2;
                       jacob_other_endo_field_number = 3;
-                      mwSize dims[1] = {(mwSize) nb_blocks };
+                      mwSize dims[1] = {static_cast<mwSize>(nb_blocks) };
                       plhs[2] = mxCreateStructArray(1, dims, 4, field_names);
                     }
                   else if (!mxIsStruct(block_structur))
