@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2017 Dynare Team
+## Copyright (C) 2009-2019 Dynare Team
 ##
 ## This file is part of Dynare.
 ##
@@ -22,7 +22,7 @@
 ## Dynare does a 'clear -all').
 
 top_test_dir = getenv('TOP_TEST_DIR');
-addpath(top_test_dir);
+addpath([top_test_dir filesep 'utils']);
 addpath([top_test_dir filesep '..' filesep 'matlab']);
 
 ## Test Dynare Version
@@ -43,22 +43,20 @@ cd([top_test_dir filesep 'block_bytecode']);
 tic;
 for blockFlag = 0:1
     for bytecodeFlag = 0:1
-        ## Recall that solve_algo=7 and stack_solve_algo=2 are not supported
-        ## under Octave
         default_solve_algo = 2;
         default_stack_solve_algo = 0;
         if !blockFlag && !bytecodeFlag
             solve_algos = 0:4;
             stack_solve_algos = [0 6];
         elseif blockFlag && !bytecodeFlag
-            solve_algos = [0:4 6 8];
-            stack_solve_algos = [0 1 3 4];
+            solve_algos = [0:4 6:8];
+            stack_solve_algos = 0:4;
         else
-            solve_algos = [0:6 8];
-            stack_solve_algos = [0 1 3:5];
+            solve_algos = 0:8;
+            stack_solve_algos = 0:5;
         endif
 
-        sleep(1) # Workaround for strange race condition related to the _static.m file
+        pause(1) # Workaround for strange race condition related to the _static.m file
 
         for i = 1:length(solve_algos)
             num_block_tests = num_block_tests + 1;
